/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ayApieKu);
  numBytes += sLine_init(&sLine_lUDjJSmq);
  numBytes += sLine_init(&sLine_l8B68t8B);
  numBytes += sLine_init(&sLine_ETO9yjkT);
  numBytes += sLine_init(&sLine_iI0olTEu);
  numBytes += sBiquad_init(&sBiquad_s_uRmc8XGT);
  numBytes += sLine_init(&sLine_xohDbwQV);
  numBytes += sLine_init(&sLine_1y4j8Cph);
  numBytes += sLine_init(&sLine_zqvbervj);
  numBytes += sLine_init(&sLine_Y5qkYfl5);
  numBytes += sLine_init(&sLine_WWBDcxBK);
  numBytes += sBiquad_init(&sBiquad_s_aVoSyGlB);
  numBytes += sLine_init(&sLine_iEPtty3z);
  numBytes += sLine_init(&sLine_n6zZvCIp);
  numBytes += sLine_init(&sLine_PBxqXwcr);
  numBytes += sLine_init(&sLine_ikt9MQMh);
  numBytes += sLine_init(&sLine_zGyLsTVV);
  numBytes += sLine_init(&sLine_6bnwoxYT);
  numBytes += sBiquad_init(&sBiquad_s_9OKeEXUN);
  numBytes += sLine_init(&sLine_RIhWAM9X);
  numBytes += sLine_init(&sLine_7gXC7jlf);
  numBytes += sLine_init(&sLine_U5E6FdQs);
  numBytes += sLine_init(&sLine_550dF0eh);
  numBytes += sLine_init(&sLine_7lteTkDZ);
  numBytes += sLine_init(&sLine_CzW9DeAH);
  numBytes += sBiquad_init(&sBiquad_s_HBgbk1YU);
  numBytes += sLine_init(&sLine_nfcq5dyA);
  numBytes += sLine_init(&sLine_U05SbMx5);
  numBytes += sLine_init(&sLine_dnzNNUNZ);
  numBytes += sLine_init(&sLine_DNCZBZUu);
  numBytes += sLine_init(&sLine_uvay57G2);
  numBytes += sBiquad_init(&sBiquad_s_SBZP6Eg4);
  numBytes += sLine_init(&sLine_lN086ia0);
  numBytes += sLine_init(&sLine_yuRKCjBd);
  numBytes += sLine_init(&sLine_dHWZrHS3);
  numBytes += sLine_init(&sLine_CdYcOfes);
  numBytes += sLine_init(&sLine_6yeLxdPO);
  numBytes += sLine_init(&sLine_UJjBoeOw);
  numBytes += sBiquad_init(&sBiquad_s_M1nFXiGZ);
  numBytes += sLine_init(&sLine_MOZ4xePk);
  numBytes += sLine_init(&sLine_yVSRhsjI);
  numBytes += sLine_init(&sLine_BF41kSTJ);
  numBytes += sLine_init(&sLine_zZHQPpp9);
  numBytes += sLine_init(&sLine_kn3Jy30w);
  numBytes += sLine_init(&sLine_F7RRw1P1);
  numBytes += sLine_init(&sLine_PuyMLyvc);
  numBytes += sLine_init(&sLine_mKxtp814);
  numBytes += sLine_init(&sLine_rpFfDlhd);
  numBytes += sLine_init(&sLine_P13NYAyJ);
  numBytes += sLine_init(&sLine_uM6usdJm);
  numBytes += sLine_init(&sLine_jle1DMzk);
  numBytes += sLine_init(&sLine_zVhAAhTZ);
  numBytes += sLine_init(&sLine_n554y7lO);
  numBytes += sLine_init(&sLine_WrgAvrwU);
  numBytes += sEnv_init(&sEnv_zLDVwawI, 512, 256);
  numBytes += sEnv_init(&sEnv_2EiBb1eu, 512, 256);
  numBytes += sLine_init(&sLine_sq5qjv7d);
  numBytes += sLine_init(&sLine_YWzoMHmf);
  numBytes += sLine_init(&sLine_loqEuMpz);
  numBytes += sLine_init(&sLine_YVgf8AWf);
  numBytes += sLine_init(&sLine_HXKJy1pH);
  numBytes += sLine_init(&sLine_dvkEuKQR);
  numBytes += sLine_init(&sLine_Bve1KrZg);
  numBytes += sLine_init(&sLine_znuoyzzm);
  numBytes += sLine_init(&sLine_Ibunc3Qs);
  numBytes += sLine_init(&sLine_9AePYHWf);
  numBytes += sLine_init(&sLine_iyNutQ0q);
  numBytes += sLine_init(&sLine_6DHhF9e0);
  numBytes += sLine_init(&sLine_0I8k0jgu);
  numBytes += sLine_init(&sLine_xzxMSL8N);
  numBytes += sLine_init(&sLine_JSCHm5Xo);
  numBytes += sLine_init(&sLine_89CneFbQ);
  numBytes += sLine_init(&sLine_6arohPpk);
  numBytes += sLine_init(&sLine_qshJ9co9);
  numBytes += sEnv_init(&sEnv_7NeQ0RBN, 512, 256);
  numBytes += sEnv_init(&sEnv_1QlvBTcf, 512, 256);
  numBytes += sLine_init(&sLine_oLlIb9UZ);
  numBytes += sLine_init(&sLine_UTqZcKrj);
  numBytes += sLine_init(&sLine_6Eh65mx0);
  numBytes += sLine_init(&sLine_Jg0EXJWU);
  numBytes += sLine_init(&sLine_zKknb96U);
  numBytes += sLine_init(&sLine_32UeUc6W);
  numBytes += sLine_init(&sLine_sKiXTPn8);
  numBytes += sLine_init(&sLine_Ic5AmThW);
  numBytes += sLine_init(&sLine_oZSL2aM7);
  numBytes += sLine_init(&sLine_cQhjgn19);
  numBytes += sLine_init(&sLine_cYP4wZkU);
  numBytes += sLine_init(&sLine_dDG5ncca);
  numBytes += sLine_init(&sLine_pKo7AR0N);
  numBytes += sLine_init(&sLine_rIeDG1HR);
  numBytes += sLine_init(&sLine_bVhgf0RF);
  numBytes += sLine_init(&sLine_iAQHkcJh);
  numBytes += sLine_init(&sLine_ZMsTmAVF);
  numBytes += sLine_init(&sLine_X02XD68H);
  numBytes += sLine_init(&sLine_CuTqOQqe);
  numBytes += sLine_init(&sLine_697RZfxs);
  numBytes += sEnv_init(&sEnv_SY12gz7f, 512, 256);
  numBytes += sEnv_init(&sEnv_jDExts0p, 512, 256);
  numBytes += sLine_init(&sLine_vHCDWKqO);
  numBytes += sLine_init(&sLine_Utq8XKz3);
  numBytes += sLine_init(&sLine_KdpQ0IPK);
  numBytes += sLine_init(&sLine_437reUKh);
  numBytes += sLine_init(&sLine_atFpJ6pP);
  numBytes += sLine_init(&sLine_5qxvIXRp);
  numBytes += sLine_init(&sLine_b2XZguzf);
  numBytes += sLine_init(&sLine_F7H8akTa);
  numBytes += sLine_init(&sLine_Y5Xq0spG);
  numBytes += sLine_init(&sLine_7oT9XRIn);
  numBytes += sLine_init(&sLine_3GMQoHhD);
  numBytes += sLine_init(&sLine_ZNBt1xzZ);
  numBytes += sLine_init(&sLine_Do1PprZl);
  numBytes += sLine_init(&sLine_TGAgCWH6);
  numBytes += sLine_init(&sLine_gMhx1TNK);
  numBytes += sLine_init(&sLine_80Q0YBJ3);
  numBytes += sLine_init(&sLine_iu3UFZLb);
  numBytes += sLine_init(&sLine_jdwCWkUT);
  numBytes += sEnv_init(&sEnv_PAZXA9GP, 512, 256);
  numBytes += sEnv_init(&sEnv_XylMPm8y, 512, 256);
  numBytes += sLine_init(&sLine_DkBbnTK8);
  numBytes += sLine_init(&sLine_doLlf3wp);
  numBytes += sLine_init(&sLine_7ln59XO8);
  numBytes += sLine_init(&sLine_2DoQoPeQ);
  numBytes += sLine_init(&sLine_buHo4FCx);
  numBytes += sLine_init(&sLine_4xynoio9);
  numBytes += sLine_init(&sLine_cW0vTDwM);
  numBytes += sLine_init(&sLine_pyETpYpH);
  numBytes += sLine_init(&sLine_nqp06mEX);
  numBytes += sLine_init(&sLine_9wZ9S0QN);
  numBytes += sLine_init(&sLine_oIDw1F9X);
  numBytes += sLine_init(&sLine_vgvj2WU1);
  numBytes += sLine_init(&sLine_Da93oSHm);
  numBytes += sLine_init(&sLine_rBKIB9gT);
  numBytes += sLine_init(&sLine_kU9ftPuY);
  numBytes += sLine_init(&sLine_UzpjxxIJ);
  numBytes += sLine_init(&sLine_yr8CGxwx);
  numBytes += sLine_init(&sLine_r0v8DbXH);
  numBytes += sLine_init(&sLine_rFxrUNpS);
  numBytes += sLine_init(&sLine_6P7mfQci);
  numBytes += sEnv_init(&sEnv_1QBcg3pU, 512, 256);
  numBytes += sEnv_init(&sEnv_TFbjhG3z, 512, 256);
  numBytes += sLine_init(&sLine_95PxunAK);
  numBytes += sLine_init(&sLine_qQrJurmf);
  numBytes += sLine_init(&sLine_gkCK2LX5);
  numBytes += sLine_init(&sLine_WrZv58pH);
  numBytes += sLine_init(&sLine_R7kXE3MS);
  numBytes += sLine_init(&sLine_SyPZQEyl);
  numBytes += sLine_init(&sLine_KmM3g40A);
  numBytes += sLine_init(&sLine_xlfmz2An);
  numBytes += sLine_init(&sLine_aFAtuYXI);
  numBytes += sLine_init(&sLine_6fPUhATE);
  numBytes += sLine_init(&sLine_Ez22xjdk);
  numBytes += sLine_init(&sLine_e2AL18ww);
  numBytes += sLine_init(&sLine_Qm79nA72);
  numBytes += sLine_init(&sLine_ZhEO0GXK);
  numBytes += sLine_init(&sLine_3Pp4NNHh);
  numBytes += sLine_init(&sLine_yykr1ZQH);
  numBytes += sLine_init(&sLine_PMGWo95G);
  numBytes += sLine_init(&sLine_7Zk3RFVL);
  numBytes += sEnv_init(&sEnv_am78oFU1, 512, 256);
  numBytes += sEnv_init(&sEnv_7NH7aC1M, 512, 256);
  numBytes += sLine_init(&sLine_fXOzPx4w);
  numBytes += sLine_init(&sLine_Uf5HUkoa);
  numBytes += sLine_init(&sLine_JBLV9CLU);
  numBytes += sLine_init(&sLine_0YDPudcp);
  numBytes += sLine_init(&sLine_HJjVRkiU);
  numBytes += sLine_init(&sLine_7JAayOZY);
  numBytes += cVar_init_f(&cVar_8NvKOekR, 0.0f);
  numBytes += cVar_init_f(&cVar_Rj7tnILw, 0.0f);
  numBytes += cVar_init_f(&cVar_SzHITrZK, 0.0f);
  numBytes += cVar_init_f(&cVar_lu4dtifa, 0.0f);
  numBytes += cVar_init_f(&cVar_kTPEs7MR, 0.0f);
  numBytes += cVar_init_f(&cVar_53JS3zDW, 1.0f);
  numBytes += cVar_init_f(&cVar_ytGTKzt9, 0.0f);
  numBytes += cVar_init_f(&cVar_QwGLpB3R, 0.0f);
  numBytes += cVar_init_f(&cVar_sKs6u6eT, 0.0f);
  numBytes += cVar_init_f(&cVar_CfMjb1eN, 0.0f);
  numBytes += cSlice_init(&cSlice_cZM1cUcd, 1, -1);
  numBytes += cVar_init_f(&cVar_aizPkQ2h, 1337.0f);
  numBytes += cVar_init_f(&cVar_QBPEFqVU, 0.0f);
  numBytes += cIf_init(&cIf_oGyEvBUb, false);
  numBytes += cIf_init(&cIf_rSTNFccD, false);
  numBytes += cBinop_init(&cBinop_lvaKz2yj, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DKLu1uYt, false);
  numBytes += cBinop_init(&cBinop_HjsNfDEc, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_gC2rf9jC, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ALVqgkfz, 0.0f);
  numBytes += cIf_init(&cIf_RgKcQbrB, false);
  numBytes += cIf_init(&cIf_IVf5pl6Q, false);
  numBytes += cBinop_init(&cBinop_AhCYT0ja, 0.0f); // __pow
  numBytes += cIf_init(&cIf_uOldcJ48, false);
  numBytes += cBinop_init(&cBinop_0xKvbs7N, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_MocW3bOL, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_X80tSDVU, 0.0f);
  numBytes += cIf_init(&cIf_KXkli56L, false);
  numBytes += cIf_init(&cIf_VSyCMBlT, false);
  numBytes += cBinop_init(&cBinop_rJOV6E8x, 0.0f); // __pow
  numBytes += cIf_init(&cIf_d2D1O0d9, false);
  numBytes += cBinop_init(&cBinop_HnCeECUw, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VZPskSdY, -15.0f); // __eq
  numBytes += cIf_init(&cIf_qYnCawNq, false);
  numBytes += cSlice_init(&cSlice_PRz8NkSQ, 1, -1);
  numBytes += cVar_init_f(&cVar_dAF5xBQi, 0.0f);
  numBytes += cSlice_init(&cSlice_F5ZOgDk1, 1, -1);
  numBytes += cVar_init_f(&cVar_WznNAspb, 0.0f);
  numBytes += cSlice_init(&cSlice_9Vk8xCgl, 1, -1);
  numBytes += cVar_init_f(&cVar_GJ9sgMP8, 0.0f);
  numBytes += cSlice_init(&cSlice_MWry48aL, 1, -1);
  numBytes += cVar_init_f(&cVar_Os5iHlIt, 0.313f);
  numBytes += cBinop_init(&cBinop_mEgWvA9J, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_nge7z9kc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_JgYBi15p, 0.0f);
  numBytes += cVar_init_f(&cVar_DM5sWt8z, 1337.0f);
  numBytes += cVar_init_f(&cVar_az8SRAdK, 0.3f);
  numBytes += cBinop_init(&cBinop_aNvHMafX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jH6kahWl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6Oud6f9t, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tOCbAxPN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_u2Z4LIw7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RI5hGEGg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xxojmwed, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_oSHbBtMk, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_EyyIIWFh, 0.0f);
  numBytes += cVar_init_f(&cVar_4n4Y7sWJ, 1337.0f);
  numBytes += cVar_init_f(&cVar_iyiQgUnb, 0.313f);
  numBytes += cBinop_init(&cBinop_U6ff0ysv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_APqgrrQy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Dp2PKis8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_woEak4vV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tiTioiN0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F0zmBinA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Ng2aJq0s, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_05HkEo0C, 0.0f);
  numBytes += cVar_init_f(&cVar_8AI1R92x, 1037.0f);
  numBytes += cVar_init_f(&cVar_noEZXqHX, 0.4f);
  numBytes += cBinop_init(&cBinop_mYHftNk3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cY0GPyvh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L9DeRa21, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UhJZna0T, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4pWlCmqV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5AIzWXVK, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_AlCF8yvj, 1, -1);
  numBytes += cVar_init_f(&cVar_bO7p9w1z, 1337.0f);
  numBytes += cVar_init_f(&cVar_dFZpZODC, 0.0f);
  numBytes += cIf_init(&cIf_RoJS1Kjh, false);
  numBytes += cIf_init(&cIf_u7aPSAFM, false);
  numBytes += cBinop_init(&cBinop_klgRdAkx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_gloxXiQJ, false);
  numBytes += cBinop_init(&cBinop_pNWMceNh, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_QhU7tjxU, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Wv1TC9M9, 0.0f);
  numBytes += cIf_init(&cIf_q9PBEfkE, false);
  numBytes += cIf_init(&cIf_vmAjqAhL, false);
  numBytes += cBinop_init(&cBinop_NPD2f97h, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZsvDyQl6, false);
  numBytes += cBinop_init(&cBinop_ZmYSIVrV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_A0qE57y7, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_j41z6TJb, 0.0f);
  numBytes += cIf_init(&cIf_UqDkXHPh, false);
  numBytes += cIf_init(&cIf_04XEfUos, false);
  numBytes += cBinop_init(&cBinop_rKVdooRh, 0.0f); // __pow
  numBytes += cIf_init(&cIf_n6BuTNzN, false);
  numBytes += cBinop_init(&cBinop_zBLG5JGK, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_IHFFcpnf, -15.0f); // __eq
  numBytes += cIf_init(&cIf_dpokoevc, false);
  numBytes += cSlice_init(&cSlice_bmoSefMZ, 1, -1);
  numBytes += cVar_init_f(&cVar_50HOvzLN, 0.0f);
  numBytes += cSlice_init(&cSlice_wPe6MG9z, 1, -1);
  numBytes += cVar_init_f(&cVar_Cbtsgrgo, 0.0f);
  numBytes += cSlice_init(&cSlice_Gsupy6dS, 1, -1);
  numBytes += cVar_init_f(&cVar_tXzMOoz1, 0.0f);
  numBytes += cSlice_init(&cSlice_duwlGE2J, 1, -1);
  numBytes += cVar_init_f(&cVar_GbyKatKx, 0.313f);
  numBytes += cBinop_init(&cBinop_HU3geF5U, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_PuyeGTXo, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KfKVpB3S, 0.0f);
  numBytes += cVar_init_f(&cVar_GGcuH3NB, 1337.0f);
  numBytes += cVar_init_f(&cVar_FEYAi0QI, 0.3f);
  numBytes += cBinop_init(&cBinop_4MZrDiWE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_75h0nd2X, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tejFcQoK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c9OINyta, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fDYTFAfY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xDw6R0ZO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XvEr3AsI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_h1IxUpkE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_3PqFWEof, 0.0f);
  numBytes += cVar_init_f(&cVar_PuaQXFkZ, 1337.0f);
  numBytes += cVar_init_f(&cVar_Is0IZBwU, 0.313f);
  numBytes += cBinop_init(&cBinop_4EizQNac, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cIwSZAyo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YZs7aklj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dshOuqKc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8J1LJLiA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nm6e6TBy, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_3cnAnNYc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_U3rnv4KT, 0.0f);
  numBytes += cVar_init_f(&cVar_TR4ESsf3, 1037.0f);
  numBytes += cVar_init_f(&cVar_svxUjjZC, 0.4f);
  numBytes += cBinop_init(&cBinop_wXCBmd3J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vuHXfueU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mIGca3Zq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x8DmopJF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AMa40GUk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AMnVdkoe, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_AvF35KdU, 5705.6f);
  numBytes += cVar_init_f(&cVar_TmQPRGEz, 313.3f);
  numBytes += cBinop_init(&cBinop_p5HSGv0e, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_qR0ZoNLf, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_eOjBl4MF, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_F0bogV4d, 1, -1);
  numBytes += cVar_init_f(&cVar_8taAqVNy, 0.5f);
  numBytes += cVar_init_f(&cVar_FbmKAo3V, 0.0f);
  numBytes += cVar_init_f(&cVar_tdcizj8Q, 0.0f);
  numBytes += cIf_init(&cIf_Q8t7MFeq, false);
  numBytes += cIf_init(&cIf_8JVccpgK, false);
  numBytes += cDelay_init(this, &cDelay_B2c6sZEy, 10.0f);
  numBytes += cIf_init(&cIf_jqWP4TaU, false);
  numBytes += cIf_init(&cIf_66KN49sO, false);
  numBytes += cDelay_init(this, &cDelay_lt1K6Oq8, 10.0f);
  numBytes += cIf_init(&cIf_ya5BiKHW, false);
  numBytes += cIf_init(&cIf_gwRPFGbh, false);
  numBytes += cDelay_init(this, &cDelay_gjYWfhJD, 10.0f);
  numBytes += cIf_init(&cIf_N0eO9JxQ, false);
  numBytes += cIf_init(&cIf_KumoGIbb, false);
  numBytes += cDelay_init(this, &cDelay_QHgyXBRc, 10.0f);
  numBytes += cIf_init(&cIf_8wqEEAWf, false);
  numBytes += cIf_init(&cIf_8n6Ar0zd, false);
  numBytes += cDelay_init(this, &cDelay_2B41LkN1, 10.0f);
  numBytes += cIf_init(&cIf_fCcuUyjP, false);
  numBytes += cIf_init(&cIf_yhEjJnZ2, false);
  numBytes += cDelay_init(this, &cDelay_TCB62GxI, 10.0f);
  numBytes += cIf_init(&cIf_12Y21FE5, false);
  numBytes += cIf_init(&cIf_ccb0KF52, false);
  numBytes += cDelay_init(this, &cDelay_AKMq3mJO, 10.0f);
  numBytes += cIf_init(&cIf_UFvWeG5V, false);
  numBytes += cIf_init(&cIf_uVXwVoEr, false);
  numBytes += cDelay_init(this, &cDelay_Bq3ycesv, 10.0f);
  numBytes += cIf_init(&cIf_nlzsEzgB, false);
  numBytes += cIf_init(&cIf_2Fe4MFCE, false);
  numBytes += cDelay_init(this, &cDelay_nQUEuVFi, 10.0f);
  numBytes += cIf_init(&cIf_ZqQ7wp0S, false);
  numBytes += cIf_init(&cIf_G4iQ9Qd5, false);
  numBytes += cDelay_init(this, &cDelay_dsBjtt49, 10.0f);
  numBytes += cIf_init(&cIf_sQhm5gsP, false);
  numBytes += cIf_init(&cIf_Hrq8GsV5, false);
  numBytes += cDelay_init(this, &cDelay_uLdYUEZf, 10.0f);
  numBytes += cIf_init(&cIf_X6IkASV9, false);
  numBytes += cIf_init(&cIf_bqoERYQS, false);
  numBytes += cDelay_init(this, &cDelay_lFv572Bp, 10.0f);
  numBytes += sVarf_init(&sVarf_Q45kJCCv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bjAF79oO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l2890Zd7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KO5Qp3pN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zTwf50ZM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eCE2XnOx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SbPsEZpX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ozp2IWgs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_BJRwzgNO, 0.0f);
  numBytes += cSlice_init(&cSlice_Fu7YuB9N, 1, -1);
  numBytes += cVar_init_f(&cVar_dvWYryum, 1.0f);
  numBytes += cSlice_init(&cSlice_fhs44sRu, 1, -1);
  numBytes += cVar_init_f(&cVar_dTjDptag, 0.0f);
  numBytes += cSlice_init(&cSlice_0pPuG6wO, 1, -1);
  numBytes += cVar_init_f(&cVar_xm7S5azb, 512.0f);
  numBytes += cSlice_init(&cSlice_XxgfxTPk, 1, -1);
  numBytes += cVar_init_f(&cVar_QZ3Q5RES, 1.0f);
  numBytes += cSlice_init(&cSlice_TixoLtwW, 1, -1);
  numBytes += cVar_init_f(&cVar_VZq7JZsw, 1.0f);
  numBytes += cDelay_init(this, &cDelay_dDSOvZKx, 20.0f);
  numBytes += cVar_init_f(&cVar_vtTJSks5, 0.0f);
  numBytes += cIf_init(&cIf_xwmhBxjC, false);
  numBytes += cIf_init(&cIf_fs05aNuX, false);
  numBytes += cBinop_init(&cBinop_28FNxgcY, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_20OMpLjw, 1, -1);
  numBytes += cVar_init_f(&cVar_4MzSIZa0, 0.0f);
  numBytes += sVarf_init(&sVarf_50LEMYyZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QWSyCe6O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tnxpbdWh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h0oc3PYz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OBqgJQWe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dVQUAEdX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_enUw6KZa, 0.0f);
  numBytes += cVar_init_f(&cVar_EjEnVDol, 0.0f);
  numBytes += cIf_init(&cIf_bOVnMnce, false);
  numBytes += cIf_init(&cIf_WrZSx7fe, false);
  numBytes += cDelay_init(this, &cDelay_7A1lmN7d, 10.0f);
  numBytes += cIf_init(&cIf_vnJ29WXb, false);
  numBytes += cIf_init(&cIf_bV7uiKWD, false);
  numBytes += cDelay_init(this, &cDelay_D1lmdYOh, 10.0f);
  numBytes += cIf_init(&cIf_0Ta0qrRq, false);
  numBytes += cIf_init(&cIf_tpYcyjps, false);
  numBytes += cDelay_init(this, &cDelay_hgPXD9jK, 10.0f);
  numBytes += cIf_init(&cIf_G3qvllkm, false);
  numBytes += cIf_init(&cIf_bC6xrJhD, false);
  numBytes += cDelay_init(this, &cDelay_17zpDdeE, 10.0f);
  numBytes += cIf_init(&cIf_N22xcEWq, false);
  numBytes += cIf_init(&cIf_YLWWRlYN, false);
  numBytes += cDelay_init(this, &cDelay_bZ5zY2Qt, 10.0f);
  numBytes += cIf_init(&cIf_yDlX55ds, false);
  numBytes += cIf_init(&cIf_EpydXbxY, false);
  numBytes += cDelay_init(this, &cDelay_h0KpvwXn, 10.0f);
  numBytes += cIf_init(&cIf_sBvBkQsn, false);
  numBytes += cIf_init(&cIf_eyZxRV3s, false);
  numBytes += cDelay_init(this, &cDelay_AwfHFXeZ, 10.0f);
  numBytes += cIf_init(&cIf_PoRoGLvE, false);
  numBytes += cIf_init(&cIf_yPKIx9Wm, false);
  numBytes += cDelay_init(this, &cDelay_fji8EhzB, 10.0f);
  numBytes += cIf_init(&cIf_c6PU8Khx, false);
  numBytes += cIf_init(&cIf_juHI2nm0, false);
  numBytes += cDelay_init(this, &cDelay_oblwzla2, 10.0f);
  numBytes += cIf_init(&cIf_og6zGwPR, false);
  numBytes += cIf_init(&cIf_rDzwZV32, false);
  numBytes += cDelay_init(this, &cDelay_cnF3yr31, 10.0f);
  numBytes += cIf_init(&cIf_7uWzJWJa, false);
  numBytes += cIf_init(&cIf_RoLpwPaP, false);
  numBytes += cDelay_init(this, &cDelay_KuoejI63, 10.0f);
  numBytes += cIf_init(&cIf_9Gw7bdyk, false);
  numBytes += cIf_init(&cIf_aEbampFM, false);
  numBytes += cDelay_init(this, &cDelay_pT5yQww9, 10.0f);
  numBytes += sVarf_init(&sVarf_2r2qQAjT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OOAaHO6O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nAWvkhkv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RMcZQvMa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F6zvLZjz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EwKfidce, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C9kwicCv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FXeniP7C, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_YX3muswt, 0.0f);
  numBytes += cSlice_init(&cSlice_N68sRGwp, 1, -1);
  numBytes += cVar_init_f(&cVar_q501eY8O, 1.0f);
  numBytes += cSlice_init(&cSlice_sjr8Mvc3, 1, -1);
  numBytes += cVar_init_f(&cVar_qVEpltkO, 0.0f);
  numBytes += cSlice_init(&cSlice_zjATFap3, 1, -1);
  numBytes += cVar_init_f(&cVar_pBDKKbjp, 512.0f);
  numBytes += cSlice_init(&cSlice_brAKNH7o, 1, -1);
  numBytes += cVar_init_f(&cVar_HQspAra7, 1.0f);
  numBytes += cSlice_init(&cSlice_fvDGUM59, 1, -1);
  numBytes += cVar_init_f(&cVar_ORCXS8oy, 1.0f);
  numBytes += cDelay_init(this, &cDelay_WFS9R8EI, 20.0f);
  numBytes += cVar_init_f(&cVar_d27ZQFHS, 0.0f);
  numBytes += cIf_init(&cIf_cd7L11GN, false);
  numBytes += cIf_init(&cIf_wqaifqTy, false);
  numBytes += cBinop_init(&cBinop_mzEbEjix, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_WP6zTl7u, 1, -1);
  numBytes += cVar_init_f(&cVar_Sk6q1OTi, 0.0f);
  numBytes += sVarf_init(&sVarf_yfnU8CAn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nL7pcOuO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iAfgFm5v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_75GxLX80, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jhav0PDR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rtl8YiPz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VupZvNqo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vjOPjWEM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YY0WGtwG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EYJ9wNj2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_rlZkuS3G, 0.0f);
  numBytes += cVar_init_f(&cVar_n9rCAxEB, 0.0f);
  numBytes += cVar_init_f(&cVar_2HcDxVFE, 0.0f);
  numBytes += cVar_init_f(&cVar_I3OOVIaW, 0.0f);
  numBytes += cVar_init_f(&cVar_OsXpFhd2, 0.0f);
  numBytes += cVar_init_f(&cVar_pzEDCEt2, 1.0f);
  numBytes += cSlice_init(&cSlice_HulEsavT, 1, -1);
  numBytes += cVar_init_f(&cVar_mJTSq7eC, 0.5f);
  numBytes += cVar_init_f(&cVar_DivKFkWk, 0.0f);
  numBytes += cVar_init_f(&cVar_snTdr4ob, 0.0f);
  numBytes += cIf_init(&cIf_uPt5QEQY, false);
  numBytes += cIf_init(&cIf_KVxR44GY, false);
  numBytes += cDelay_init(this, &cDelay_vO6BPrfb, 10.0f);
  numBytes += cIf_init(&cIf_yHMpvhNy, false);
  numBytes += cIf_init(&cIf_jHtTczmD, false);
  numBytes += cDelay_init(this, &cDelay_HXHMLiOn, 10.0f);
  numBytes += cIf_init(&cIf_Ejh7ZZzV, false);
  numBytes += cIf_init(&cIf_sGDjgbYv, false);
  numBytes += cDelay_init(this, &cDelay_A4SrYndN, 10.0f);
  numBytes += cIf_init(&cIf_NMqhUPCG, false);
  numBytes += cIf_init(&cIf_akOIqdjY, false);
  numBytes += cDelay_init(this, &cDelay_biV0Mux5, 10.0f);
  numBytes += cIf_init(&cIf_vtwNaqwV, false);
  numBytes += cIf_init(&cIf_kWvryE5h, false);
  numBytes += cDelay_init(this, &cDelay_ZjNE1O1w, 10.0f);
  numBytes += cIf_init(&cIf_C3UP4FmA, false);
  numBytes += cIf_init(&cIf_Yni61l0w, false);
  numBytes += cDelay_init(this, &cDelay_uLh6eh11, 10.0f);
  numBytes += cIf_init(&cIf_X86bD3fz, false);
  numBytes += cIf_init(&cIf_jHuKTI4S, false);
  numBytes += cDelay_init(this, &cDelay_EfbF7VAb, 10.0f);
  numBytes += cIf_init(&cIf_CcdGaDaZ, false);
  numBytes += cIf_init(&cIf_IAekMEoh, false);
  numBytes += cDelay_init(this, &cDelay_Q3XB1HAI, 10.0f);
  numBytes += cIf_init(&cIf_z5Aqd6hE, false);
  numBytes += cIf_init(&cIf_NFN8BZFs, false);
  numBytes += cDelay_init(this, &cDelay_B2Q3FB6b, 10.0f);
  numBytes += cIf_init(&cIf_piGntQ2L, false);
  numBytes += cIf_init(&cIf_MKS0TGMr, false);
  numBytes += cDelay_init(this, &cDelay_Ida2N7ti, 10.0f);
  numBytes += cIf_init(&cIf_Ttlv18N8, false);
  numBytes += cIf_init(&cIf_AYohgUe9, false);
  numBytes += cDelay_init(this, &cDelay_8valU1d6, 10.0f);
  numBytes += cIf_init(&cIf_1zVIXUnh, false);
  numBytes += cIf_init(&cIf_vxCF7Kn8, false);
  numBytes += cDelay_init(this, &cDelay_V04NALlZ, 10.0f);
  numBytes += sVarf_init(&sVarf_zqZXaHUR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Td4pZ0Rm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qOwvPoMt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_siUzsR6r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a8qd7ng3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Jyv6I5uE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XX2LUsSp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Icpne3Te, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_kIyjiGlB, 0.0f);
  numBytes += cSlice_init(&cSlice_ToJ5aCid, 1, -1);
  numBytes += cVar_init_f(&cVar_6GDTp1m1, 1.0f);
  numBytes += cSlice_init(&cSlice_PFnVmDPE, 1, -1);
  numBytes += cVar_init_f(&cVar_FuMcJKOC, 0.0f);
  numBytes += cSlice_init(&cSlice_oCAcLKFw, 1, -1);
  numBytes += cVar_init_f(&cVar_qaqTNx04, 512.0f);
  numBytes += cSlice_init(&cSlice_MIdRCAp6, 1, -1);
  numBytes += cVar_init_f(&cVar_W3zFU6iE, 1.0f);
  numBytes += cSlice_init(&cSlice_qc1hboAC, 1, -1);
  numBytes += cVar_init_f(&cVar_Gu1m2UCX, 1.0f);
  numBytes += cDelay_init(this, &cDelay_AjlnmyPR, 20.0f);
  numBytes += cVar_init_f(&cVar_TUIrSszk, 0.0f);
  numBytes += cIf_init(&cIf_B8M11LBj, false);
  numBytes += cIf_init(&cIf_UFHq4qPp, false);
  numBytes += cBinop_init(&cBinop_02RJcUZr, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_FkyCQCSw, 1, -1);
  numBytes += cVar_init_f(&cVar_PhlwJ69w, 0.0f);
  numBytes += sVarf_init(&sVarf_tYPJErS7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OuVyq88U, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UR8sAgZx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qvUW9Wdu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5SuDooBV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ANYCtJq9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_89b6V4Wx, 0.0f);
  numBytes += cVar_init_f(&cVar_XbMoisTd, 0.0f);
  numBytes += cIf_init(&cIf_AzUlpyxe, false);
  numBytes += cIf_init(&cIf_SCkafVnG, false);
  numBytes += cDelay_init(this, &cDelay_8GAgr6qd, 10.0f);
  numBytes += cIf_init(&cIf_3XAObkMf, false);
  numBytes += cIf_init(&cIf_MiWOVS7B, false);
  numBytes += cDelay_init(this, &cDelay_k3R776qk, 10.0f);
  numBytes += cIf_init(&cIf_LPONnUTF, false);
  numBytes += cIf_init(&cIf_7TErtxiP, false);
  numBytes += cDelay_init(this, &cDelay_5afVokx6, 10.0f);
  numBytes += cIf_init(&cIf_ZinwuPV5, false);
  numBytes += cIf_init(&cIf_g0xdyBcb, false);
  numBytes += cDelay_init(this, &cDelay_gj9bWYue, 10.0f);
  numBytes += cIf_init(&cIf_RCqhnOAB, false);
  numBytes += cIf_init(&cIf_w3Ln88PI, false);
  numBytes += cDelay_init(this, &cDelay_GKd435pd, 10.0f);
  numBytes += cIf_init(&cIf_Mpp3WoPD, false);
  numBytes += cIf_init(&cIf_zFZCiVMe, false);
  numBytes += cDelay_init(this, &cDelay_gH8mFP4R, 10.0f);
  numBytes += cIf_init(&cIf_7Om71J8w, false);
  numBytes += cIf_init(&cIf_Hboh3g4M, false);
  numBytes += cDelay_init(this, &cDelay_46OPqJmy, 10.0f);
  numBytes += cIf_init(&cIf_zHkNqilJ, false);
  numBytes += cIf_init(&cIf_DQsxCCjn, false);
  numBytes += cDelay_init(this, &cDelay_7id9Xx5O, 10.0f);
  numBytes += cIf_init(&cIf_jojNwumh, false);
  numBytes += cIf_init(&cIf_heKdytTq, false);
  numBytes += cDelay_init(this, &cDelay_6cKYspO4, 10.0f);
  numBytes += cIf_init(&cIf_7RBHWbAu, false);
  numBytes += cIf_init(&cIf_NVN54kNd, false);
  numBytes += cDelay_init(this, &cDelay_9tM7tZ03, 10.0f);
  numBytes += cIf_init(&cIf_6I3rAhzR, false);
  numBytes += cIf_init(&cIf_QMFw6dlk, false);
  numBytes += cDelay_init(this, &cDelay_SGb8ycfX, 10.0f);
  numBytes += cIf_init(&cIf_xdQhgdfq, false);
  numBytes += cIf_init(&cIf_gMtWYIDo, false);
  numBytes += cDelay_init(this, &cDelay_D5LZnr1W, 10.0f);
  numBytes += sVarf_init(&sVarf_QAMBTnU6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DHQGoa2O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nNsyOa4G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AXffnBrl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rbu64Xef, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yTyuMD4G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BTO3pYZK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V36EK0ba, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_90rJ79IU, 0.0f);
  numBytes += cSlice_init(&cSlice_8ewa7VB8, 1, -1);
  numBytes += cVar_init_f(&cVar_uwYqbbN4, 1.0f);
  numBytes += cSlice_init(&cSlice_rugARe6l, 1, -1);
  numBytes += cVar_init_f(&cVar_REKvqRRl, 0.0f);
  numBytes += cSlice_init(&cSlice_LxGPuC3s, 1, -1);
  numBytes += cVar_init_f(&cVar_xv8A8Grq, 512.0f);
  numBytes += cSlice_init(&cSlice_oqzrv2vl, 1, -1);
  numBytes += cVar_init_f(&cVar_N8eL02bx, 1.0f);
  numBytes += cSlice_init(&cSlice_BhPMzkRq, 1, -1);
  numBytes += cVar_init_f(&cVar_ke7xYud5, 1.0f);
  numBytes += cDelay_init(this, &cDelay_lpu53rD1, 20.0f);
  numBytes += cVar_init_f(&cVar_RwBd3ku2, 0.0f);
  numBytes += cIf_init(&cIf_ldvHUE9L, false);
  numBytes += cIf_init(&cIf_gtt8wOds, false);
  numBytes += cBinop_init(&cBinop_xKJN6Ejj, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_24bE5T0C, 1, -1);
  numBytes += cVar_init_f(&cVar_hAcrP4WY, 0.0f);
  numBytes += sVarf_init(&sVarf_1tks8Tst, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oRYPx20p, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mSH68Jqp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gv4EUtEp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RNma2y45, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KOBn2P4M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AiS3EJXr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2SDKpvzf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wp0OiIyx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_47IR97SS, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_LdjpvYvg, 0.0f);
  numBytes += cVar_init_f(&cVar_iqlRrcji, 0.0f);
  numBytes += cVar_init_f(&cVar_Wdw2jHaN, 0.0f);
  numBytes += cVar_init_f(&cVar_hWNSCJco, 0.0f);
  numBytes += cVar_init_f(&cVar_2i8GwX2F, 0.0f);
  numBytes += cVar_init_f(&cVar_IQWrYaQd, 1.0f);
  numBytes += cSlice_init(&cSlice_wgyOGuEn, 1, -1);
  numBytes += cVar_init_f(&cVar_ArfHi8Ey, 0.5f);
  numBytes += cVar_init_f(&cVar_jVQghEQ2, 0.0f);
  numBytes += cVar_init_f(&cVar_tSRXPz1d, 0.0f);
  numBytes += cIf_init(&cIf_Em2wy5aO, false);
  numBytes += cIf_init(&cIf_9fsqlxVg, false);
  numBytes += cDelay_init(this, &cDelay_M1uCR1Xm, 10.0f);
  numBytes += cIf_init(&cIf_Ymf6y1MA, false);
  numBytes += cIf_init(&cIf_yH0hhCbn, false);
  numBytes += cDelay_init(this, &cDelay_wUXERC2F, 10.0f);
  numBytes += cIf_init(&cIf_pDH9y4BZ, false);
  numBytes += cIf_init(&cIf_AqGvQFFL, false);
  numBytes += cDelay_init(this, &cDelay_drNeuftk, 10.0f);
  numBytes += cIf_init(&cIf_zkX1zJ5Y, false);
  numBytes += cIf_init(&cIf_Vde1sDDt, false);
  numBytes += cDelay_init(this, &cDelay_gU2NxYap, 10.0f);
  numBytes += cIf_init(&cIf_5LIVuSfd, false);
  numBytes += cIf_init(&cIf_X3jaBvrm, false);
  numBytes += cDelay_init(this, &cDelay_HX6rg2ow, 10.0f);
  numBytes += cIf_init(&cIf_TKNKFF3Z, false);
  numBytes += cIf_init(&cIf_lQHjloqM, false);
  numBytes += cDelay_init(this, &cDelay_1ipi8gPz, 10.0f);
  numBytes += cIf_init(&cIf_UvoeNYll, false);
  numBytes += cIf_init(&cIf_K4dAnCDH, false);
  numBytes += cDelay_init(this, &cDelay_tSHdi8Y9, 10.0f);
  numBytes += cIf_init(&cIf_g360a9vd, false);
  numBytes += cIf_init(&cIf_3ifF4GQY, false);
  numBytes += cDelay_init(this, &cDelay_jQQcnsmm, 10.0f);
  numBytes += cIf_init(&cIf_o3kUmM3S, false);
  numBytes += cIf_init(&cIf_4wo8OVbk, false);
  numBytes += cDelay_init(this, &cDelay_ceC0FJRM, 10.0f);
  numBytes += cIf_init(&cIf_LuumfMPp, false);
  numBytes += cIf_init(&cIf_IAjHy3SN, false);
  numBytes += cDelay_init(this, &cDelay_PQOiacAI, 10.0f);
  numBytes += cIf_init(&cIf_Fqa6cMTn, false);
  numBytes += cIf_init(&cIf_bjezbu1Q, false);
  numBytes += cDelay_init(this, &cDelay_zOlK1iqD, 10.0f);
  numBytes += cIf_init(&cIf_ZiWxzy49, false);
  numBytes += cIf_init(&cIf_IzmKMtMK, false);
  numBytes += cDelay_init(this, &cDelay_SyMEleSh, 10.0f);
  numBytes += sVarf_init(&sVarf_C71EU4To, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CPKBLQfW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9jhqEF0X, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_luDdDSJ5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wd96BNMy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yyJG1VRu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NXPIpnWB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GQnqSyJp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_clFUn20z, 0.0f);
  numBytes += cSlice_init(&cSlice_sp4rDjxW, 1, -1);
  numBytes += cVar_init_f(&cVar_Y6Cyzolu, 1.0f);
  numBytes += cSlice_init(&cSlice_llxxVGOx, 1, -1);
  numBytes += cVar_init_f(&cVar_36Qywm8i, 0.0f);
  numBytes += cSlice_init(&cSlice_DQNMqJgL, 1, -1);
  numBytes += cVar_init_f(&cVar_lBRYDJNz, 512.0f);
  numBytes += cSlice_init(&cSlice_XN4TNroN, 1, -1);
  numBytes += cVar_init_f(&cVar_KrzHOY0J, 1.0f);
  numBytes += cSlice_init(&cSlice_Utr1U9PW, 1, -1);
  numBytes += cVar_init_f(&cVar_dG1Pl05v, 1.0f);
  numBytes += cDelay_init(this, &cDelay_ZXLH5e2B, 20.0f);
  numBytes += cVar_init_f(&cVar_KXJ5mdLL, 0.0f);
  numBytes += cIf_init(&cIf_68cGjj1T, false);
  numBytes += cIf_init(&cIf_Lgeb0mml, false);
  numBytes += cBinop_init(&cBinop_2gptacAZ, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_85IR79SJ, 1, -1);
  numBytes += cVar_init_f(&cVar_qETx4TzV, 0.0f);
  numBytes += sVarf_init(&sVarf_XtqL9cxe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yVEpq6Jm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wlz8mmQV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uMR7n2Jd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L3x9Fygo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g66fSCwY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3KWxYa8p, 0.0f);
  numBytes += cVar_init_f(&cVar_T0QXT5jr, 0.0f);
  numBytes += cIf_init(&cIf_PoQg9oCA, false);
  numBytes += cIf_init(&cIf_2SOtnocG, false);
  numBytes += cDelay_init(this, &cDelay_kVXYQ1KM, 10.0f);
  numBytes += cIf_init(&cIf_gVmiUfLs, false);
  numBytes += cIf_init(&cIf_r2WLkzHs, false);
  numBytes += cDelay_init(this, &cDelay_Sj8ft5Ti, 10.0f);
  numBytes += cIf_init(&cIf_e3qAjpJB, false);
  numBytes += cIf_init(&cIf_D2wISGkY, false);
  numBytes += cDelay_init(this, &cDelay_zHz4YEOp, 10.0f);
  numBytes += cIf_init(&cIf_76m4CZmK, false);
  numBytes += cIf_init(&cIf_0pW6Dw8C, false);
  numBytes += cDelay_init(this, &cDelay_9GCz53Vk, 10.0f);
  numBytes += cIf_init(&cIf_CnOczbCh, false);
  numBytes += cIf_init(&cIf_haDR28jZ, false);
  numBytes += cDelay_init(this, &cDelay_1tqBEOTD, 10.0f);
  numBytes += cIf_init(&cIf_KMOMdVlY, false);
  numBytes += cIf_init(&cIf_qa6iQ6nZ, false);
  numBytes += cDelay_init(this, &cDelay_RMDoZxwy, 10.0f);
  numBytes += cIf_init(&cIf_soko0hyJ, false);
  numBytes += cIf_init(&cIf_MmYyPUpd, false);
  numBytes += cDelay_init(this, &cDelay_jNAhdrUi, 10.0f);
  numBytes += cIf_init(&cIf_Qg1c0y36, false);
  numBytes += cIf_init(&cIf_qpjEca76, false);
  numBytes += cDelay_init(this, &cDelay_BJ0Knutl, 10.0f);
  numBytes += cIf_init(&cIf_4JupDeD3, false);
  numBytes += cIf_init(&cIf_KUFekH4e, false);
  numBytes += cDelay_init(this, &cDelay_WPGm4PSA, 10.0f);
  numBytes += cIf_init(&cIf_6w7k0BOX, false);
  numBytes += cIf_init(&cIf_5qLtIPAc, false);
  numBytes += cDelay_init(this, &cDelay_fcyueZm4, 10.0f);
  numBytes += cIf_init(&cIf_VTPhv9xT, false);
  numBytes += cIf_init(&cIf_x7iqEpLs, false);
  numBytes += cDelay_init(this, &cDelay_LPrCAiM2, 10.0f);
  numBytes += cIf_init(&cIf_t6NheE4b, false);
  numBytes += cIf_init(&cIf_Fg2p5bL7, false);
  numBytes += cDelay_init(this, &cDelay_jAtHT5yu, 10.0f);
  numBytes += sVarf_init(&sVarf_ukaCxpYc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0ZPMBoJe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eg1SbnCq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_n0s6OokT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Uj5YDesa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wxfCBmyg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jH1K6mkb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aHAATtvX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JtRoF6eR, 0.0f);
  numBytes += cSlice_init(&cSlice_KRKfSQrL, 1, -1);
  numBytes += cVar_init_f(&cVar_81rYNbBm, 1.0f);
  numBytes += cSlice_init(&cSlice_1aXn90TA, 1, -1);
  numBytes += cVar_init_f(&cVar_TwowjwL1, 0.0f);
  numBytes += cSlice_init(&cSlice_fSpBy3ez, 1, -1);
  numBytes += cVar_init_f(&cVar_IEaZF1VE, 512.0f);
  numBytes += cSlice_init(&cSlice_fS8zk4m8, 1, -1);
  numBytes += cVar_init_f(&cVar_xQbgujgR, 1.0f);
  numBytes += cSlice_init(&cSlice_6xfV5Hkf, 1, -1);
  numBytes += cVar_init_f(&cVar_7w8vrf15, 1.0f);
  numBytes += cDelay_init(this, &cDelay_e0IumkXG, 20.0f);
  numBytes += cVar_init_f(&cVar_CYcsRqY6, 0.0f);
  numBytes += cIf_init(&cIf_XOynIrxU, false);
  numBytes += cIf_init(&cIf_1OA9KRIg, false);
  numBytes += cBinop_init(&cBinop_u1tRBHau, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_bDWlfh7w, 1, -1);
  numBytes += cVar_init_f(&cVar_TvmPJYyt, 0.0f);
  numBytes += sVarf_init(&sVarf_klPe766a, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cOO93iTB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fVF1sr7r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_i0vUTWHg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4XohRoIu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CxV9Bpih, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CCIMiDbo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l9vVpzN8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tD7oLOOT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fwaiC3uD, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gSuMmycC, 0.0f);
  numBytes += cVar_init_f(&cVar_4NoTwRjY, 0.0f);
  numBytes += cVar_init_f(&cVar_VSJpsS1r, 0.0f);
  numBytes += sVarf_init(&sVarf_DidFDnnm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fYWHKLOz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1DYFrgL8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gocDjaQM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nYxPqOEp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GcmRvqIU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w9vwsohY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tPQBK6Km, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1tlJIfWc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LtC0oEv0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ByEgYfh3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sqQn8ecp, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_zLDVwawI);
  sEnv_free(&sEnv_2EiBb1eu);
  sEnv_free(&sEnv_7NeQ0RBN);
  sEnv_free(&sEnv_1QlvBTcf);
  sEnv_free(&sEnv_SY12gz7f);
  sEnv_free(&sEnv_jDExts0p);
  sEnv_free(&sEnv_PAZXA9GP);
  sEnv_free(&sEnv_XylMPm8y);
  sEnv_free(&sEnv_1QBcg3pU);
  sEnv_free(&sEnv_TFbjhG3z);
  sEnv_free(&sEnv_am78oFU1);
  sEnv_free(&sEnv_7NH7aC1M);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WihTFts6_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_welPhHc7_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TAsTJ6uD_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kTFovQnp_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_umElZp4C_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HrHk6NE1_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4HqatXBZ_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P4MWbL15_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_emutieEj_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_POeaQoMb_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lBpe9NoW_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BJWFa9I6_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KQjTqT27_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6SaRBhfc_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GnvnXkOX_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WQBUMIjb_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_enOpdziU_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qI6taklH_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qTNV0fpb_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6FwuQIh6_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VZyxN0OD_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YBwnbZBw_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8A1DkR4f_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ateQRDU2_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hm1bD9EA_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dgmJgGDd_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3exjPP8U_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mt4To4KZ_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EqsVVIWQ_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t7NMMFfu_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r4wcbIHY_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6j2sUdt3_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kK5hO7Do_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hWcSwQO3_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GMqP0qgT_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yo2nmLMS_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SxfKmrve_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r7NYxABa_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_71wOtNgn_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0uf40Jbe_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D4PeYYu1_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3HQORtNP_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cGdcctZZ_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8NrX67hD_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3MpGAlJ1_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S3Otx0UB_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ySVft9Ey_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DbKsnBaJ_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qXjiyziH_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6wrxq3f4_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qICl5MWp_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x9wWIMNR_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mQKzNcTI_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LAffqNx9_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dv9YKxQ8_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PiVvO9R2_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H5heWyZC_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JcCwX2OS_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dXLND0jC_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KRUHAEVX_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XXxaVavE_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jqUfix2y_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cWYD5d16_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lRqht7Jz_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DiC3Wy4s_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DAoh08TB_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RgT6FIuu_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qXeag0Eq_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hlT5SKJd_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ATJlbvfV_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NLc7I43P_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AU8ErtJN_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6lDKUyeM_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RJv65QbJ_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3FxnoMMP_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PsPIY5QE_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vE4xyyPE_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bxi2PiIc_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3nzgPwBj_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vFlTtgEH_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7GgI84L1_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_teMssqs3_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nB5GHuTr_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QrVXDLKo_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5ZCHUIlT_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KuSxU9nE_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F64CTdUi_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c5aygQwE_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O3mDvtjo_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hU4Rr4oa_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fOgXJmk6_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZLIzro8W_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1CmJRCoM_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_8NvKOekR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KkPZXhA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Rj7tnILw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oxY1cdip_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_SzHITrZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sWmgvwB1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_lu4dtifa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uMkvWHVb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_kTPEs7MR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hFamjJwd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_53JS3zDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pugkoe0o_sendMessage);
  cMsg_gE76WJnt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Pugkoe0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_53JS3zDW, 1, m, &cVar_53JS3zDW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QTvqbgbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cz1L0RHW_sendMessage(_c, 0, m);
  cMsg_My9zdjmz_sendMessage(_c, 0, m);
  cMsg_IcoIc7Dv_sendMessage(_c, 0, m);
  cMsg_5Szkwunz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ytGTKzt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NCG9OzV7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_QwGLpB3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ov6s04bQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_sKs6u6eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4CusQt90_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CfMjb1eN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_liAlzato_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pi9mQV9H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3QPmz4Eo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BLFz5NMv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4Miitpm2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cZM1cUcd, 0, m, &cSlice_cZM1cUcd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2y9UnZQQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_cZM1cUcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Y2puwe2e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Y2puwe2e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_aizPkQ2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y2puwe2e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Y2puwe2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mt4To4KZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_QBPEFqVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_I8KB4G0j_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_oGyEvBUb, 0, m, &cIf_oGyEvBUb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_oGyEvBUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1FAIrVTX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rSTNFccD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZwfG6Fju_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_I9GRBIgC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_Bdn4ltpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lvaKz2yj, HV_BINOP_POW, 0, m, &cBinop_lvaKz2yj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lvaKz2yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DKLu1uYt, 0, m, &cIf_DKLu1uYt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VBwB7YD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GsIKGjYk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7BdiYGXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2PqVDlsP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iVTRShgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rSTNFccD, 0, m, &cIf_rSTNFccD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2PqVDlsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rSTNFccD, 1, m, &cIf_rSTNFccD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I9GRBIgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VBwB7YD7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZwfG6Fju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DKLu1uYt, 0, m, &cIf_DKLu1uYt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GsIKGjYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lvaKz2yj, HV_BINOP_POW, 1, m, &cBinop_lvaKz2yj_sendMessage);
  cMsg_Bdn4ltpI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_DKLu1uYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qttpOXUv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_I8KB4G0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oGyEvBUb, 1, m, &cIf_oGyEvBUb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1FAIrVTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YkkkKetx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d0x9JKW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1rUeJFvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7BdiYGXq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iVTRShgx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HjsNfDEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DKLu1uYt, 1, m, &cIf_DKLu1uYt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gC2rf9jC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PYXBHkX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PYXBHkX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_qttpOXUv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_i3CaA54G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_1rUeJFvP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YkkkKetx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gC2rf9jC, HV_BINOP_EQ, 1, m, &cBinop_gC2rf9jC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d0x9JKW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HjsNfDEc, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HjsNfDEc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_43xgU0i1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QBPEFqVU, 0, m, &cVar_QBPEFqVU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KqNGLFCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HjsNfDEc, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HjsNfDEc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ij0Beeya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gC2rf9jC, HV_BINOP_EQ, 0, m, &cBinop_gC2rf9jC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PoE5qZwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i3CaA54G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ALVqgkfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9sLN0cnK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_RgKcQbrB, 0, m, &cIf_RgKcQbrB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_RgKcQbrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jjdLtxaG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IVf5pl6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_oTsyvWLs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_PaSSdTyR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_C74QT9Go_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AhCYT0ja, HV_BINOP_POW, 0, m, &cBinop_AhCYT0ja_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AhCYT0ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uOldcJ48, 0, m, &cIf_uOldcJ48_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HVSncHa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_bPpXVyHg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HsIyG1QG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jBgX9hBb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BWC0CJ5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IVf5pl6Q, 0, m, &cIf_IVf5pl6Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jBgX9hBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IVf5pl6Q, 1, m, &cIf_IVf5pl6Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PaSSdTyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HVSncHa5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oTsyvWLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_uOldcJ48, 0, m, &cIf_uOldcJ48_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bPpXVyHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AhCYT0ja, HV_BINOP_POW, 1, m, &cBinop_AhCYT0ja_sendMessage);
  cMsg_C74QT9Go_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_uOldcJ48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1oeyzM14_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kGDDKqHA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_9sLN0cnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RgKcQbrB, 1, m, &cIf_RgKcQbrB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jjdLtxaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WQrsDLk7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yUVUw5yu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UojryCQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HsIyG1QG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BWC0CJ5I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0xKvbs7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uOldcJ48, 1, m, &cIf_uOldcJ48_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MocW3bOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L80PiFvE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_L80PiFvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1oeyzM14_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kGDDKqHA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pG4bifRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_UojryCQG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WQrsDLk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MocW3bOL, HV_BINOP_EQ, 1, m, &cBinop_MocW3bOL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yUVUw5yu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0xKvbs7N, HV_BINOP_GREATER_THAN, 1, m, &cBinop_0xKvbs7N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fT0N9KpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MocW3bOL, HV_BINOP_EQ, 0, m, &cBinop_MocW3bOL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zovLmI5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ALVqgkfz, 0, m, &cVar_ALVqgkfz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HXcE0kEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0xKvbs7N, HV_BINOP_GREATER_THAN, 0, m, &cBinop_0xKvbs7N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ArEUJKEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pG4bifRS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_X80tSDVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VKdiLn8U_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_KXkli56L, 0, m, &cIf_KXkli56L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_KXkli56L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OIS47Rvq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VSyCMBlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_lSM0NyFR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7SC8dUnb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_nxgGoH8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rJOV6E8x, HV_BINOP_POW, 0, m, &cBinop_rJOV6E8x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rJOV6E8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d2D1O0d9, 0, m, &cIf_d2D1O0d9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iBO7X6fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_rsLqG22G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B83cf8xv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_z3eh3wdo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_su3v1SdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VSyCMBlT, 0, m, &cIf_VSyCMBlT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z3eh3wdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VSyCMBlT, 1, m, &cIf_VSyCMBlT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7SC8dUnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_iBO7X6fw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lSM0NyFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_d2D1O0d9, 0, m, &cIf_d2D1O0d9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rsLqG22G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rJOV6E8x, HV_BINOP_POW, 1, m, &cBinop_rJOV6E8x_sendMessage);
  cMsg_nxgGoH8U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_d2D1O0d9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_B62pCZUD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_VKdiLn8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KXkli56L, 1, m, &cIf_KXkli56L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OIS47Rvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E4cInGoM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wUU2yvJX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BQem5j7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B83cf8xv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_su3v1SdT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HnCeECUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d2D1O0d9, 1, m, &cIf_d2D1O0d9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VZPskSdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sJM5CUUU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sJM5CUUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_B62pCZUD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pbbN5HoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_BQem5j7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E4cInGoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VZPskSdY, HV_BINOP_EQ, 1, m, &cBinop_VZPskSdY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wUU2yvJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HnCeECUw, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HnCeECUw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UI1rFsSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VZPskSdY, HV_BINOP_EQ, 0, m, &cBinop_VZPskSdY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XLLE4kN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pbbN5HoM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qFxaHwxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X80tSDVU, 0, m, &cVar_X80tSDVU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SRhcmby3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HnCeECUw, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HnCeECUw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_qYnCawNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hPFWKn61_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Kf8Myr32_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PRz8NkSQ, 0, m, &cSlice_PRz8NkSQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UnI47xlU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PRz8NkSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wfs3NZ6M_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wfs3NZ6M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dAF5xBQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wfs3NZ6M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wfs3NZ6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dgmJgGDd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UnI47xlU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_F5ZOgDk1, 0, m, &cSlice_F5ZOgDk1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4Miitpm2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_F5ZOgDk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wb1lIQZr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wb1lIQZr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WznNAspb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wb1lIQZr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wb1lIQZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t7NMMFfu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2y9UnZQQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9Vk8xCgl, 0, m, &cSlice_9Vk8xCgl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_h3OQzWMl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9Vk8xCgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_neXsONBL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_neXsONBL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GJ9sgMP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_neXsONBL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_neXsONBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3exjPP8U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_h3OQzWMl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MWry48aL, 0, m, &cSlice_MWry48aL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MWry48aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AvmAXdWD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AvmAXdWD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Os5iHlIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AvmAXdWD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AvmAXdWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EqsVVIWQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fZI0IbXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ayApieKu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_czohwFdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lUDjJSmq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3q9MdRv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_l8B68t8B, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fW4TehmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ETO9yjkT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qnVJBcAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iI0olTEu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fJIUFuFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uT8uZiVa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_uT8uZiVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mEgWvA9J, HV_BINOP_DIVIDE, 1, m, &cBinop_mEgWvA9J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pX0jYaYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Ydm0zjR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KY1mL5Fr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rFhC2P2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Ydm0zjR7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KY1mL5Fr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mEgWvA9J, HV_BINOP_DIVIDE, 0, m, &cBinop_mEgWvA9J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pX0jYaYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rFhC2P2U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mEgWvA9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nge7z9kc, HV_BINOP_MULTIPLY, 1, m, &cBinop_nge7z9kc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nge7z9kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Avcomoo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OfLQEOeb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_PzUcoTW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4hULz9so_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_HrXXI4zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Govo1Fns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1UlT0tsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ZDfJVerT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZDfJVerT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nge7z9kc, HV_BINOP_MULTIPLY, 0, m, &cBinop_nge7z9kc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GLw5QUAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_mR2U4AP3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mR2U4AP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vZbRuq5e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_U7OUdc2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JgYBi15p, 1, m, &cVar_JgYBi15p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_JgYBi15p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aIZmoKer_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pEQe4oWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jH6kahWl, HV_BINOP_MULTIPLY, 1, m, &cBinop_jH6kahWl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vTJYPo76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pEQe4oWV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_87Z4zErr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Q32ZaozN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Q32ZaozN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Oud6f9t, HV_BINOP_MULTIPLY, 1, m, &cBinop_6Oud6f9t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KXi7t2b8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tOCbAxPN, HV_BINOP_MULTIPLY, 1, m, &cBinop_tOCbAxPN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3KpAmYkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KXi7t2b8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kwi5ZvuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u2Z4LIw7, HV_BINOP_MULTIPLY, 1, m, &cBinop_u2Z4LIw7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HS99XgrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Mth9WUAM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mth9WUAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RI5hGEGg, HV_BINOP_MULTIPLY, 1, m, &cBinop_RI5hGEGg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_DM5sWt8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JlIrrAPH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_1UlT0tsc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wdNzIAfY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_az8SRAdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GLw5QUAc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OfLQEOeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_HrXXI4zr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6Avcomoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_PzUcoTW2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_4hULz9so_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kK5hO7Do_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Govo1Fns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6j2sUdt3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_98oxgMc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r4wcbIHY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vZbRuq5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hl94LfrL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hl94LfrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aNvHMafX, HV_BINOP_MULTIPLY, 1, m, &cBinop_aNvHMafX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aNvHMafX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5NTDorRm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5NTDorRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_98oxgMc0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aIZmoKer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_CgLUo60F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CgLUo60F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdJFxhnq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YQGFACuq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f3uKz4no_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fRTokaz0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xpAis3JK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OQ2LwESC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jH6kahWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fZI0IbXY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_6Oud6f9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_czohwFdc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tOCbAxPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3q9MdRv3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_u2Z4LIw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fW4TehmZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RI5hGEGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qnVJBcAX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_du2dkrRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_az8SRAdK, 1, m, &cVar_az8SRAdK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6Rkd0Ow6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DM5sWt8z, 0, m, &cVar_DM5sWt8z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YQGFACuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RI5hGEGg, HV_BINOP_MULTIPLY, 0, m, &cBinop_RI5hGEGg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JdJFxhnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_fRTokaz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tOCbAxPN, HV_BINOP_MULTIPLY, 0, m, &cBinop_tOCbAxPN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OQ2LwESC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jH6kahWl, HV_BINOP_MULTIPLY, 0, m, &cBinop_jH6kahWl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f3uKz4no_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u2Z4LIw7, HV_BINOP_MULTIPLY, 0, m, &cBinop_u2Z4LIw7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xpAis3JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Oud6f9t, HV_BINOP_MULTIPLY, 0, m, &cBinop_6Oud6f9t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wdNzIAfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JgYBi15p, 0, m, &cVar_JgYBi15p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JlIrrAPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_az8SRAdK, 0, m, &cVar_az8SRAdK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cJ6jK02v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1y4j8Cph, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kufH6IhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zqvbervj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_smSg81Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y5qkYfl5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jGOqRpUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WWBDcxBK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6fiV1Nvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7a5mWUdt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_7a5mWUdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xxojmwed, HV_BINOP_DIVIDE, 1, m, &cBinop_xxojmwed_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kWExeQVP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_bW45KNgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_12VIdN0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZY4jMbbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_bW45KNgl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_12VIdN0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xxojmwed, HV_BINOP_DIVIDE, 0, m, &cBinop_xxojmwed_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kWExeQVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZY4jMbbl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xxojmwed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oSHbBtMk, HV_BINOP_MULTIPLY, 1, m, &cBinop_oSHbBtMk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oSHbBtMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vaiswJ8Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OOmOzhkp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_hOGhEqNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jimVdXg0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_lFPbuDPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jix2hrwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RPfZMic3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_00qwYUGg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_00qwYUGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oSHbBtMk, HV_BINOP_MULTIPLY, 0, m, &cBinop_oSHbBtMk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HMTCz0kY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_FdyO82FB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FdyO82FB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IYp3QKZU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0z6rCDg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dp2PKis8, HV_BINOP_MULTIPLY, 1, m, &cBinop_Dp2PKis8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3o24Pne7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EyyIIWFh, 1, m, &cVar_EyyIIWFh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bt5ywcYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_woEak4vV, HV_BINOP_MULTIPLY, 1, m, &cBinop_woEak4vV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VX7YoxKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_94Ij4vXD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_94Ij4vXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tiTioiN0, HV_BINOP_MULTIPLY, 1, m, &cBinop_tiTioiN0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_EyyIIWFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q3wtFCh4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4n4Y7sWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lP8dRlk4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_RPfZMic3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BlcCVTft_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_iyiQgUnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HMTCz0kY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vaiswJ8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_hOGhEqNd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OOmOzhkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_lFPbuDPy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_jimVdXg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yo2nmLMS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jix2hrwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GMqP0qgT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HaIfs1DZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hWcSwQO3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IYp3QKZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ixQTwU0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ixQTwU0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U6ff0ysv, HV_BINOP_MULTIPLY, 1, m, &cBinop_U6ff0ysv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U6ff0ysv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_23oKow6w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_23oKow6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HaIfs1DZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Q3wtFCh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_W7XQ3b0E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W7XQ3b0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V0rLceOJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yIOPgKNs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KKl8zAbE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tN96kC4S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_APqgrrQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cJ6jK02v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Dp2PKis8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kufH6IhO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_woEak4vV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_smSg81Po_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tiTioiN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jGOqRpUb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_sNeQOot4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4n4Y7sWJ, 0, m, &cVar_4n4Y7sWJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2sI7uZzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iyiQgUnb, 1, m, &cVar_iyiQgUnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BlcCVTft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EyyIIWFh, 0, m, &cVar_EyyIIWFh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lP8dRlk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iyiQgUnb, 0, m, &cVar_iyiQgUnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KKl8zAbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dp2PKis8, HV_BINOP_MULTIPLY, 0, m, &cBinop_Dp2PKis8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yIOPgKNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_woEak4vV, HV_BINOP_MULTIPLY, 0, m, &cBinop_woEak4vV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V0rLceOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tiTioiN0, HV_BINOP_MULTIPLY, 0, m, &cBinop_tiTioiN0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tN96kC4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_APqgrrQy, HV_BINOP_MULTIPLY, 0, m, &cBinop_APqgrrQy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wnYxA7FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n6zZvCIp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TP46Y0e4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PBxqXwcr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hvYh6hlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ikt9MQMh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WaMbUJgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zGyLsTVV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yGHwHFDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6bnwoxYT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_G52416Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0WTOaRIf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_0WTOaRIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F0zmBinA, HV_BINOP_DIVIDE, 1, m, &cBinop_F0zmBinA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JhoTRNwI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_7cSJHSoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_UETn6nvf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vdz0ZT3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7cSJHSoc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UETn6nvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F0zmBinA, HV_BINOP_DIVIDE, 0, m, &cBinop_F0zmBinA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JhoTRNwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vdz0ZT3G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_F0zmBinA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ng2aJq0s, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ng2aJq0s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ng2aJq0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8EKy8J4t_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5BZdEdwr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_IaTOsBZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SUFekmb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_SMEbBwJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d3j9siQO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_fG2cAnSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_JqnlNCL8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JqnlNCL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ng2aJq0s, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ng2aJq0s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KqTr0flW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dc6ZBoXn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dc6ZBoXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HQZNP1Mh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Z02e580b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cY0GPyvh, HV_BINOP_MULTIPLY, 1, m, &cBinop_cY0GPyvh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7H190g7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HI9JLRWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HI9JLRWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Z02e580b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KexEmbPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4tmYZ6nm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4tmYZ6nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9DeRa21, HV_BINOP_MULTIPLY, 1, m, &cBinop_L9DeRa21_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8ha2oQyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UhJZna0T, HV_BINOP_MULTIPLY, 1, m, &cBinop_UhJZna0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rhDI9HPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_co9gd38Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_co9gd38Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8ha2oQyh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Tdzr2pzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_05HkEo0C, 1, m, &cVar_05HkEo0C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e8Ai0OS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pWlCmqV, HV_BINOP_MULTIPLY, 1, m, &cBinop_4pWlCmqV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hpQCwn3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tE9pVoJ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tE9pVoJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5AIzWXVK, HV_BINOP_MULTIPLY, 1, m, &cBinop_5AIzWXVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_05HkEo0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dnR6rwwy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8AI1R92x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7zQk4n0a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_fG2cAnSq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dzkot3SC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_noEZXqHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_KqTr0flW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8EKy8J4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_IaTOsBZL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5BZdEdwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SMEbBwJs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_SUFekmb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_71wOtNgn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_d3j9siQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r7NYxABa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UFqKEGWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SxfKmrve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HQZNP1Mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HpGU0hlT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HpGU0hlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mYHftNk3, HV_BINOP_MULTIPLY, 1, m, &cBinop_mYHftNk3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mYHftNk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Du8tgw76_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Du8tgw76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UFqKEGWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dnR6rwwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wGy2j85P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wGy2j85P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qmwh5h9i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8u6NdTNm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IFkKNz8U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EUbh9VaE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y138WHBJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4IZYgIbG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cY0GPyvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wnYxA7FX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_L9DeRa21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TP46Y0e4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_UhJZna0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hvYh6hlq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4pWlCmqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WaMbUJgW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5AIzWXVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yGHwHFDr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zYGc23rF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8AI1R92x, 0, m, &cVar_8AI1R92x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i7MRl5wL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_noEZXqHX, 1, m, &cVar_noEZXqHX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qmwh5h9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_IFkKNz8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pWlCmqV, HV_BINOP_MULTIPLY, 0, m, &cBinop_4pWlCmqV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EUbh9VaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UhJZna0T, HV_BINOP_MULTIPLY, 0, m, &cBinop_UhJZna0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4IZYgIbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cY0GPyvh, HV_BINOP_MULTIPLY, 0, m, &cBinop_cY0GPyvh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8u6NdTNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5AIzWXVK, HV_BINOP_MULTIPLY, 0, m, &cBinop_5AIzWXVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y138WHBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9DeRa21, HV_BINOP_MULTIPLY, 0, m, &cBinop_L9DeRa21_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7zQk4n0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_noEZXqHX, 0, m, &cVar_noEZXqHX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dzkot3SC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_05HkEo0C, 0, m, &cVar_05HkEo0C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bd0q3DL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qYnCawNq, 1, m, &cIf_qYnCawNq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TeTEhMS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_hPFWKn61_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_6mIYPjYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TeTEhMS8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Pr2bIlmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qYnCawNq, 0, m, &cIf_qYnCawNq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qttpOXUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xohDbwQV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hPFWKn61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iEPtty3z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_B62pCZUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RIhWAM9X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kGDDKqHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Pr2bIlmU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1oeyzM14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bd0q3DL9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6mIYPjYf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GN8mrlxa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AlCF8yvj, 0, m, &cSlice_AlCF8yvj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_R8xflupK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_AlCF8yvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LUhS631J_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LUhS631J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_bO7p9w1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LUhS631J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LUhS631J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3HQORtNP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dFZpZODC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yr73b0R1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_RoJS1Kjh, 0, m, &cIf_RoJS1Kjh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_RoJS1Kjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UMfL0tfg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_u7aPSAFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_hWiI3i3S_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_f0e5SCY3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_8D2hSKxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_klgRdAkx, HV_BINOP_POW, 0, m, &cBinop_klgRdAkx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_klgRdAkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gloxXiQJ, 0, m, &cIf_gloxXiQJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4VzsbRMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_WVOtrun0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X4apmtdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ykoajT8M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8QdQPZEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u7aPSAFM, 0, m, &cIf_u7aPSAFM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ykoajT8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u7aPSAFM, 1, m, &cIf_u7aPSAFM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f0e5SCY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4VzsbRMt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hWiI3i3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_gloxXiQJ, 0, m, &cIf_gloxXiQJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WVOtrun0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_klgRdAkx, HV_BINOP_POW, 1, m, &cBinop_klgRdAkx_sendMessage);
  cMsg_8D2hSKxc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_gloxXiQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VNWa2ovB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_yr73b0R1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RoJS1Kjh, 1, m, &cIf_RoJS1Kjh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UMfL0tfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V6p3ZnxB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nJGGAol3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Po5v6MW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X4apmtdd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8QdQPZEQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pNWMceNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gloxXiQJ, 1, m, &cIf_gloxXiQJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QhU7tjxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NUYeaaJr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NUYeaaJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_VNWa2ovB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LSKjxAVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Po5v6MW9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nJGGAol3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pNWMceNh, HV_BINOP_GREATER_THAN, 1, m, &cBinop_pNWMceNh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V6p3ZnxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhU7tjxU, HV_BINOP_EQ, 1, m, &cBinop_QhU7tjxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XPjz8yv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pNWMceNh, HV_BINOP_GREATER_THAN, 0, m, &cBinop_pNWMceNh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UINoh1ET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LSKjxAVf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_iQLfteUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dFZpZODC, 0, m, &cVar_dFZpZODC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nAvAeG6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhU7tjxU, HV_BINOP_EQ, 0, m, &cBinop_QhU7tjxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Wv1TC9M9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EDxtzY8o_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_q9PBEfkE, 0, m, &cIf_q9PBEfkE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_q9PBEfkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9HxFgAnm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vmAjqAhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tGPfuH8e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_YRMF9PAm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_JP5bZFkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NPD2f97h, HV_BINOP_POW, 0, m, &cBinop_NPD2f97h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NPD2f97h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZsvDyQl6, 0, m, &cIf_ZsvDyQl6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6zj65gzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_eilyn0k4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g5Q1hMf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZDQYPDOe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Aq5FPUR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vmAjqAhL, 0, m, &cIf_vmAjqAhL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZDQYPDOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vmAjqAhL, 1, m, &cIf_vmAjqAhL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YRMF9PAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6zj65gzC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tGPfuH8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZsvDyQl6, 0, m, &cIf_ZsvDyQl6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eilyn0k4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NPD2f97h, HV_BINOP_POW, 1, m, &cBinop_NPD2f97h_sendMessage);
  cMsg_JP5bZFkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_ZsvDyQl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ulss6gDW_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VsZzD90c_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_EDxtzY8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q9PBEfkE, 1, m, &cIf_q9PBEfkE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9HxFgAnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cjrDy5tM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WN0E2M6h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OwDFewkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g5Q1hMf5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Aq5FPUR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZmYSIVrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZsvDyQl6, 1, m, &cIf_ZsvDyQl6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A0qE57y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9BfqYAdM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9BfqYAdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ulss6gDW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VsZzD90c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Tk0Zb6QB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_OwDFewkS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WN0E2M6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmYSIVrV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZmYSIVrV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cjrDy5tM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A0qE57y7, HV_BINOP_EQ, 1, m, &cBinop_A0qE57y7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q1M4cVeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A0qE57y7, HV_BINOP_EQ, 0, m, &cBinop_A0qE57y7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AOBPN6HH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmYSIVrV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZmYSIVrV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_agqlc0Gm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tk0Zb6QB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_FsVjRQeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wv1TC9M9, 0, m, &cVar_Wv1TC9M9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_j41z6TJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3qwf3V3o_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_UqDkXHPh, 0, m, &cIf_UqDkXHPh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_UqDkXHPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KJZ07ZXE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_04XEfUos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_0rsVf7bT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NuHprxVx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_cir0vFKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rKVdooRh, HV_BINOP_POW, 0, m, &cBinop_rKVdooRh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rKVdooRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n6BuTNzN, 0, m, &cIf_n6BuTNzN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mZ9gzyZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9wWKXU4W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CIy68Lah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_04XEfUos, 0, m, &cIf_04XEfUos_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j7ePUJY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fapl3UbE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fapl3UbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_04XEfUos, 1, m, &cIf_04XEfUos_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NuHprxVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mZ9gzyZ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0rsVf7bT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_n6BuTNzN, 0, m, &cIf_n6BuTNzN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9wWKXU4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rKVdooRh, HV_BINOP_POW, 1, m, &cBinop_rKVdooRh_sendMessage);
  cMsg_cir0vFKE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_n6BuTNzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BMNACnMr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_3qwf3V3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UqDkXHPh, 1, m, &cIf_UqDkXHPh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KJZ07ZXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J6oXBCV0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HlCUCR9q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2S0rwj7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j7ePUJY3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CIy68Lah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zBLG5JGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n6BuTNzN, 1, m, &cIf_n6BuTNzN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IHFFcpnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KFEg6UBC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KFEg6UBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_BMNACnMr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OKli61sT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_2S0rwj7f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J6oXBCV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IHFFcpnf, HV_BINOP_EQ, 1, m, &cBinop_IHFFcpnf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HlCUCR9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zBLG5JGK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_zBLG5JGK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XnCSI7cH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IHFFcpnf, HV_BINOP_EQ, 0, m, &cBinop_IHFFcpnf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sMsudVsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OKli61sT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_z7EWzndC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j41z6TJb, 0, m, &cVar_j41z6TJb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FgNmXPQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zBLG5JGK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_zBLG5JGK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_dpokoevc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4KPG1LEi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_13U97vWa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bmoSefMZ, 0, m, &cSlice_bmoSefMZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yrcfTrrh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bmoSefMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JVF3cIqB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JVF3cIqB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_50HOvzLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JVF3cIqB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JVF3cIqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0uf40Jbe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yrcfTrrh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wPe6MG9z, 0, m, &cSlice_wPe6MG9z_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GN8mrlxa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_wPe6MG9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f9g4xlD0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f9g4xlD0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Cbtsgrgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f9g4xlD0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_f9g4xlD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8NrX67hD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_R8xflupK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Gsupy6dS, 0, m, &cSlice_Gsupy6dS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pK7ch0GN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Gsupy6dS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_91GUufS7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_91GUufS7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_tXzMOoz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_91GUufS7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_91GUufS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_D4PeYYu1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pK7ch0GN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_duwlGE2J, 0, m, &cSlice_duwlGE2J_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_duwlGE2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Jw0ht6Q9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Jw0ht6Q9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GbyKatKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Jw0ht6Q9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Jw0ht6Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cGdcctZZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4FxFTOSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7gXC7jlf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UJZEtJho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U5E6FdQs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9LIFLlwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_550dF0eh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kEjQ9jJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7lteTkDZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mNSnB6wA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CzW9DeAH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_piD7pUiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vzCfDmoy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_vzCfDmoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HU3geF5U, HV_BINOP_DIVIDE, 1, m, &cBinop_HU3geF5U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e1t7ktXk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_sPRUoGxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_LLIIfboy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pYRrJgyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_sPRUoGxh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LLIIfboy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HU3geF5U, HV_BINOP_DIVIDE, 0, m, &cBinop_HU3geF5U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e1t7ktXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pYRrJgyx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HU3geF5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PuyeGTXo, HV_BINOP_MULTIPLY, 1, m, &cBinop_PuyeGTXo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PuyeGTXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eEu6bP6C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xhhKSXKz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_0Aw21Sjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i5cXTL5s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_pZUox78e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xFZEMXA2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_XNHkzEWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ZXWl7U2M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZXWl7U2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PuyeGTXo, HV_BINOP_MULTIPLY, 0, m, &cBinop_PuyeGTXo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Xuzhe8PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_aQayhLn8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aQayhLn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iUrYWJFR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_siSGGGIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KfKVpB3S, 1, m, &cVar_KfKVpB3S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_KfKVpB3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EdANzHIh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uyCvakgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_75h0nd2X, HV_BINOP_MULTIPLY, 1, m, &cBinop_75h0nd2X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EqoqIpOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uyCvakgZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vohm1Zt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6VXssPoA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6VXssPoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tejFcQoK, HV_BINOP_MULTIPLY, 1, m, &cBinop_tejFcQoK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K2sWGAfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9OINyta, HV_BINOP_MULTIPLY, 1, m, &cBinop_c9OINyta_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sV8e1ZWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_K2sWGAfM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RhLgmLkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fDYTFAfY, HV_BINOP_MULTIPLY, 1, m, &cBinop_fDYTFAfY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PQglZpkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8uRBImHi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8uRBImHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xDw6R0ZO, HV_BINOP_MULTIPLY, 1, m, &cBinop_xDw6R0ZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_GGcuH3NB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JRxEbYRY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XNHkzEWg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AoBXFdEk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_FEYAi0QI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Xuzhe8PD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xhhKSXKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_pZUox78e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eEu6bP6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0Aw21Sjf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_i5cXTL5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ySVft9Ey_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xFZEMXA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S3Otx0UB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ag7zGOcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3MpGAlJ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iUrYWJFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7HNiH7eD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7HNiH7eD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4MZrDiWE, HV_BINOP_MULTIPLY, 1, m, &cBinop_4MZrDiWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4MZrDiWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1zFuIbV2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1zFuIbV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ag7zGOcJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EdANzHIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_a5WRG4Un_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a5WRG4Un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AN16WFO5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zWjIGADf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ybW68xtd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CaIOhUcA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0QhPZe12_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZmrSGkmx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_75h0nd2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4FxFTOSg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tejFcQoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UJZEtJho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_c9OINyta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9LIFLlwp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_fDYTFAfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kEjQ9jJg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xDw6R0ZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mNSnB6wA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pTFyLsu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GGcuH3NB, 0, m, &cVar_GGcuH3NB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kQ2NaNV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FEYAi0QI, 1, m, &cVar_FEYAi0QI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CaIOhUcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9OINyta, HV_BINOP_MULTIPLY, 0, m, &cBinop_c9OINyta_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0QhPZe12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tejFcQoK, HV_BINOP_MULTIPLY, 0, m, &cBinop_tejFcQoK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ybW68xtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fDYTFAfY, HV_BINOP_MULTIPLY, 0, m, &cBinop_fDYTFAfY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zWjIGADf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xDw6R0ZO, HV_BINOP_MULTIPLY, 0, m, &cBinop_xDw6R0ZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZmrSGkmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_75h0nd2X, HV_BINOP_MULTIPLY, 0, m, &cBinop_75h0nd2X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AN16WFO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_JRxEbYRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FEYAi0QI, 0, m, &cVar_FEYAi0QI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AoBXFdEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KfKVpB3S, 0, m, &cVar_KfKVpB3S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_t46nPMfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U05SbMx5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rIFHSXLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dnzNNUNZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TxDeekrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DNCZBZUu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_D96tBDYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uvay57G2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zOBqV0ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jh02Xf2Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_jh02Xf2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XvEr3AsI, HV_BINOP_DIVIDE, 1, m, &cBinop_XvEr3AsI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T3BrIHdL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_zAHG03J8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_UHc6Cr3i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LiK1ybH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zAHG03J8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UHc6Cr3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XvEr3AsI, HV_BINOP_DIVIDE, 0, m, &cBinop_XvEr3AsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T3BrIHdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LiK1ybH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_XvEr3AsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h1IxUpkE, HV_BINOP_MULTIPLY, 1, m, &cBinop_h1IxUpkE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_h1IxUpkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lm6AwZd4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TJpFMS5b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_wUXmuK2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HpfDdPoc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_6OfgEOUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YRNKKObj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WOWrSQBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ndsYYrg1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ndsYYrg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h1IxUpkE, HV_BINOP_MULTIPLY, 0, m, &cBinop_h1IxUpkE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MCDyGmZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_VWRsQNMA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VWRsQNMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7yLjDyMa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_atlDbwJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YZs7aklj, HV_BINOP_MULTIPLY, 1, m, &cBinop_YZs7aklj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y5RDWCpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3PqFWEof, 1, m, &cVar_3PqFWEof_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f29TLK8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dshOuqKc, HV_BINOP_MULTIPLY, 1, m, &cBinop_dshOuqKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C4uIzk3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TsF9ay6K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TsF9ay6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8J1LJLiA, HV_BINOP_MULTIPLY, 1, m, &cBinop_8J1LJLiA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_3PqFWEof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dLwiGEEd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_PuaQXFkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VKE2oSJL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_WOWrSQBC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZzqFhU0x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Is0IZBwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_MCDyGmZG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Lm6AwZd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_wUXmuK2m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TJpFMS5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_6OfgEOUU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_HpfDdPoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6wrxq3f4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YRNKKObj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qXjiyziH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JIcuOtJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DbKsnBaJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7yLjDyMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QiWfxswR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QiWfxswR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4EizQNac, HV_BINOP_MULTIPLY, 1, m, &cBinop_4EizQNac_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4EizQNac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6elQMj7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6elQMj7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JIcuOtJX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dLwiGEEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lYlXh4Xf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lYlXh4Xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iETGa93z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4qfv5XBF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bJlaZvxn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vthQjxZs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cIwSZAyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t46nPMfF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_YZs7aklj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rIFHSXLl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dshOuqKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TxDeekrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8J1LJLiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D96tBDYA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2wBeVxZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PuaQXFkZ, 0, m, &cVar_PuaQXFkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3bfcHafv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Is0IZBwU, 1, m, &cVar_Is0IZBwU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZzqFhU0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3PqFWEof, 0, m, &cVar_3PqFWEof_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VKE2oSJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Is0IZBwU, 0, m, &cVar_Is0IZBwU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bJlaZvxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YZs7aklj, HV_BINOP_MULTIPLY, 0, m, &cBinop_YZs7aklj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vthQjxZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIwSZAyo, HV_BINOP_MULTIPLY, 0, m, &cBinop_cIwSZAyo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4qfv5XBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dshOuqKc, HV_BINOP_MULTIPLY, 0, m, &cBinop_dshOuqKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iETGa93z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8J1LJLiA, HV_BINOP_MULTIPLY, 0, m, &cBinop_8J1LJLiA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OtvJ0Smm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yuRKCjBd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EICUNYXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dHWZrHS3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oai3tad5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CdYcOfes, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QZLkOpgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6yeLxdPO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Xwj1acuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UJjBoeOw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_N8bgB8tD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oDgiQAmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_oDgiQAmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nm6e6TBy, HV_BINOP_DIVIDE, 1, m, &cBinop_nm6e6TBy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OxFEL7mv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ouqvBzPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_VBWvAkt0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Rqk6fGgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ouqvBzPb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VBWvAkt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nm6e6TBy, HV_BINOP_DIVIDE, 0, m, &cBinop_nm6e6TBy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OxFEL7mv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rqk6fGgc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_nm6e6TBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3cnAnNYc, HV_BINOP_MULTIPLY, 1, m, &cBinop_3cnAnNYc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3cnAnNYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JB29Wp33_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2pY3OYM6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_dnpMWOPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XwTuL98x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_axeBaepx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f4ziLTPq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_AVNuMhpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HDvFZOd2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HDvFZOd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3cnAnNYc, HV_BINOP_MULTIPLY, 0, m, &cBinop_3cnAnNYc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yORZvcWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Uvm6lHST_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Uvm6lHST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tWSpge3O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_938JXz9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vuHXfueU, HV_BINOP_MULTIPLY, 1, m, &cBinop_vuHXfueU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I9DWt267_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bP27khVz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bP27khVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_938JXz9Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JpSp1cLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8tjyJC7s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8tjyJC7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mIGca3Zq, HV_BINOP_MULTIPLY, 1, m, &cBinop_mIGca3Zq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W4qw7Wjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x8DmopJF, HV_BINOP_MULTIPLY, 1, m, &cBinop_x8DmopJF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fs0OFSuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MOaOYRNb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MOaOYRNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_W4qw7Wjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_egJQ0q6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U3rnv4KT, 1, m, &cVar_U3rnv4KT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LLi0Pd94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AMa40GUk, HV_BINOP_MULTIPLY, 1, m, &cBinop_AMa40GUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_blgrVszH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oUvqlEf1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oUvqlEf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AMnVdkoe, HV_BINOP_MULTIPLY, 1, m, &cBinop_AMnVdkoe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_U3rnv4KT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QsSKQcPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_TR4ESsf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BkbE0BDH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_AVNuMhpY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pakjdhwi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_svxUjjZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_yORZvcWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JB29Wp33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_dnpMWOPO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2pY3OYM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_axeBaepx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_XwTuL98x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mQKzNcTI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_f4ziLTPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_x9wWIMNR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_CH16zNoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qICl5MWp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tWSpge3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OUksxJV5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OUksxJV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wXCBmd3J, HV_BINOP_MULTIPLY, 1, m, &cBinop_wXCBmd3J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wXCBmd3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gBm0QB3N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gBm0QB3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CH16zNoV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QsSKQcPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VS0AkuDK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VS0AkuDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VCCLxkBb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0hjhnZMI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V7Flr3zd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xSu29wSO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kcuR8Ua8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T3cLgcaS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vuHXfueU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OtvJ0Smm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mIGca3Zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EICUNYXz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_x8DmopJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oai3tad5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_AMa40GUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QZLkOpgx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_AMnVdkoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xwj1acuI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Tl9ulMOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_svxUjjZC, 1, m, &cVar_svxUjjZC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l72oohLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TR4ESsf3, 0, m, &cVar_TR4ESsf3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V7Flr3zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AMa40GUk, HV_BINOP_MULTIPLY, 0, m, &cBinop_AMa40GUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xSu29wSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x8DmopJF, HV_BINOP_MULTIPLY, 0, m, &cBinop_x8DmopJF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VCCLxkBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_0hjhnZMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AMnVdkoe, HV_BINOP_MULTIPLY, 0, m, &cBinop_AMnVdkoe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kcuR8Ua8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mIGca3Zq, HV_BINOP_MULTIPLY, 0, m, &cBinop_mIGca3Zq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T3cLgcaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vuHXfueU, HV_BINOP_MULTIPLY, 0, m, &cBinop_vuHXfueU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pakjdhwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U3rnv4KT, 0, m, &cVar_U3rnv4KT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BkbE0BDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_svxUjjZC, 0, m, &cVar_svxUjjZC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WjQ83YYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dpokoevc, 1, m, &cIf_dpokoevc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_splanATm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_4KPG1LEi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8zxgMVI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_splanATm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_fJjMhha3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dpokoevc, 0, m, &cIf_dpokoevc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VNWa2ovB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nfcq5dyA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4KPG1LEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lN086ia0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BMNACnMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MOZ4xePk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ulss6gDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WjQ83YYg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8zxgMVI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VsZzD90c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_fJjMhha3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_AvF35KdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qR0ZoNLf, HV_BINOP_DIVIDE, 0, m, &cBinop_qR0ZoNLf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_TmQPRGEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p5HSGv0e, HV_BINOP_DIVIDE, 1, m, &cBinop_p5HSGv0e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qR0ZoNLf, HV_BINOP_DIVIDE, 1, m, &cBinop_qR0ZoNLf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_2zpAdaH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eOjBl4MF, HV_BINOP_DIVIDE, 0, m, &cBinop_eOjBl4MF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_9Ob8nElz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eOjBl4MF, HV_BINOP_DIVIDE, 1, m, &cBinop_eOjBl4MF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BLFz5NMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p5HSGv0e, HV_BINOP_DIVIDE, 0, m, &cBinop_p5HSGv0e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3QPmz4Eo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AvF35KdU, 0, m, &cVar_AvF35KdU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pi9mQV9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TmQPRGEz, 0, m, &cVar_TmQPRGEz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p5HSGv0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_2zpAdaH9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qR0ZoNLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_9Ob8nElz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eOjBl4MF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_iOk5laIY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_dkNzrv8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_JL4p0LfF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zBeyaUB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_E5hVZFfd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iOk5laIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zBeyaUB1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E5hVZFfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_dkNzrv8z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JL4p0LfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N29eJUQQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PTpEc3R3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_F0bogV4d, 0, m, &cSlice_F0bogV4d_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_F0bogV4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VWQAV49N_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VWQAV49N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_8taAqVNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VWQAV49N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_VWQAV49N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LAffqNx9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BPVJ75He_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8iyFB2Io_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8iyFB2Io_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_44LoGX1O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_44LoGX1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FXsgInou_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FXsgInou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SoLrwyA3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RH9xZSpY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RH9xZSpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bNaS01Hy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SoLrwyA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_V9Tnhc3O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V9Tnhc3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XSc4238J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bNaS01Hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_V4CSEJZI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V4CSEJZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_10mItlj7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XSc4238J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0w6Zy8n3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_10mItlj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0qbmcFxY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0w6Zy8n3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BF41kSTJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0qbmcFxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yVSRhsjI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_FbmKAo3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wiz8oCLn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_tdcizj8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d8JlXwEF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eajETg8t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kWRODyfx_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VHsTyop0_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LDmPQbfR_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xW62y8wK_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ppxSENwD_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HHhaYbZW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_kWRODyfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F4BBTS8V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VHsTyop0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D3KRlDrg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_LDmPQbfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F8rdYyfI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_xW62y8wK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nqfzoeVR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ppxSENwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h4uIy9xi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_HHhaYbZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dynPr3Qj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Q8t7MFeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ePfBP9os_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8JVccpgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2lXqdbBo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BqXEo5eN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vAujnw4Z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vAujnw4Z_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_B2c6sZEy, 1, m, &cDelay_B2c6sZEy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DdwiIidn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_B2c6sZEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B2c6sZEy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Q8t7MFeq, 0, m, &cIf_Q8t7MFeq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vAujnw4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_B2c6sZEy, 0, m, &cDelay_B2c6sZEy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DdwiIidn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B2c6sZEy, 0, m, &cDelay_B2c6sZEy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m0LzDyNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1rPPcGws_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k0QjV4YX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lJKYLPba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GC8D9k05_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y3ssLpj4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y3ssLpj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BqXEo5eN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GC8D9k05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q8t7MFeq, 1, m, &cIf_Q8t7MFeq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1rPPcGws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8JVccpgK, 1, m, &cIf_8JVccpgK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k0QjV4YX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8JVccpgK, 0, m, &cIf_8JVccpgK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2lXqdbBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PuyMLyvc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ePfBP9os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PuyMLyvc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jqWP4TaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rQCmQkyU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_66KN49sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FPlo1xCR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_F84vp6fL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_okUd2TRx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_okUd2TRx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lt1K6Oq8, 1, m, &cDelay_lt1K6Oq8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rARYarsL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lt1K6Oq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lt1K6Oq8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jqWP4TaU, 0, m, &cIf_jqWP4TaU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_okUd2TRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lt1K6Oq8, 0, m, &cDelay_lt1K6Oq8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rARYarsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lt1K6Oq8, 0, m, &cDelay_lt1K6Oq8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oG0xzaqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rVel6YPa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dDs8OOPM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r4l8CwVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ab9mYB9S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_abaRTcvA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ab9mYB9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jqWP4TaU, 1, m, &cIf_jqWP4TaU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_abaRTcvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_F84vp6fL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dDs8OOPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_66KN49sO, 0, m, &cIf_66KN49sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rVel6YPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_66KN49sO, 1, m, &cIf_66KN49sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FPlo1xCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P13NYAyJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rQCmQkyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P13NYAyJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ya5BiKHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yT1Cewhv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gwRPFGbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oMxEYiZH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gzeRlMXy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_h1p09Agq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_h1p09Agq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gjYWfhJD, 1, m, &cDelay_gjYWfhJD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EqQsXhJ9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gjYWfhJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gjYWfhJD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ya5BiKHW, 0, m, &cIf_ya5BiKHW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h1p09Agq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gjYWfhJD, 0, m, &cDelay_gjYWfhJD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EqQsXhJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gjYWfhJD, 0, m, &cDelay_gjYWfhJD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qiBDS6jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZvhfZ4tg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9hLvCBFw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hFL1EDpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0zmTEMXl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9NoHpXrj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9NoHpXrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gzeRlMXy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0zmTEMXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ya5BiKHW, 1, m, &cIf_ya5BiKHW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9hLvCBFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gwRPFGbh, 0, m, &cIf_gwRPFGbh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZvhfZ4tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gwRPFGbh, 1, m, &cIf_gwRPFGbh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oMxEYiZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zVhAAhTZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yT1Cewhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zVhAAhTZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_N0eO9JxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7jclAhMa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KumoGIbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_S0rimvhw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZmzjWHx6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HCjyFYBR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HCjyFYBR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QHgyXBRc, 1, m, &cDelay_QHgyXBRc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yGaPfX1m_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QHgyXBRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QHgyXBRc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_N0eO9JxQ, 0, m, &cIf_N0eO9JxQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HCjyFYBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QHgyXBRc, 0, m, &cDelay_QHgyXBRc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yGaPfX1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QHgyXBRc, 0, m, &cDelay_QHgyXBRc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sLOPDhxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6QqULDy7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3tZRrDup_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DuuGy1XR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f04TaU9q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zApyMjzc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zApyMjzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZmzjWHx6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_f04TaU9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N0eO9JxQ, 1, m, &cIf_N0eO9JxQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6QqULDy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KumoGIbb, 1, m, &cIf_KumoGIbb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3tZRrDup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KumoGIbb, 0, m, &cIf_KumoGIbb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_S0rimvhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mKxtp814, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7jclAhMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mKxtp814, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8wqEEAWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6eisjk8u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8n6Ar0zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JlyBD85Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VRYIIFzi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7mMDCZr5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7mMDCZr5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2B41LkN1, 1, m, &cDelay_2B41LkN1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yBxFz7bP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2B41LkN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2B41LkN1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8wqEEAWf, 0, m, &cIf_8wqEEAWf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7mMDCZr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2B41LkN1, 0, m, &cDelay_2B41LkN1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yBxFz7bP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2B41LkN1, 0, m, &cDelay_2B41LkN1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QqLwVuT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YJqWzXRU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WrFVq0ZJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xc69lchF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MsHI9WT9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kJ4kNA9D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kJ4kNA9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VRYIIFzi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MsHI9WT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8wqEEAWf, 1, m, &cIf_8wqEEAWf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WrFVq0ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8n6Ar0zd, 0, m, &cIf_8n6Ar0zd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YJqWzXRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8n6Ar0zd, 1, m, &cIf_8n6Ar0zd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JlyBD85Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uM6usdJm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6eisjk8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uM6usdJm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fCcuUyjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kPnG4EIl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yhEjJnZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_acefl0pY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_42h7oReo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7wfL3q1J_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7wfL3q1J_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TCB62GxI, 1, m, &cDelay_TCB62GxI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f9vtaiP2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TCB62GxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TCB62GxI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fCcuUyjP, 0, m, &cIf_fCcuUyjP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7wfL3q1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TCB62GxI, 0, m, &cDelay_TCB62GxI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f9vtaiP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TCB62GxI, 0, m, &cDelay_TCB62GxI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jBOQOtTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PecQ2zrN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Vimb9F0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0cSbeKNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bN6pYZWU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aXrUpC6e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aXrUpC6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_42h7oReo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bN6pYZWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fCcuUyjP, 1, m, &cIf_fCcuUyjP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Vimb9F0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yhEjJnZ2, 0, m, &cIf_yhEjJnZ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PecQ2zrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yhEjJnZ2, 1, m, &cIf_yhEjJnZ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_acefl0pY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n554y7lO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kPnG4EIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n554y7lO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_12Y21FE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cYfYYztr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ccb0KF52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WDzNZK87_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Y5bHEFpO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SAq8sXlU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SAq8sXlU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AKMq3mJO, 1, m, &cDelay_AKMq3mJO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zNWV5jy5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AKMq3mJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AKMq3mJO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_12Y21FE5, 0, m, &cIf_12Y21FE5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SAq8sXlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AKMq3mJO, 0, m, &cDelay_AKMq3mJO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zNWV5jy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AKMq3mJO, 0, m, &cDelay_AKMq3mJO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ecE82Ssq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZpDQJuVW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dtgGUaoz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cOItQbup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Zxgpi91_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CCdtvWVH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CCdtvWVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Y5bHEFpO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6Zxgpi91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_12Y21FE5, 1, m, &cIf_12Y21FE5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dtgGUaoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ccb0KF52, 0, m, &cIf_ccb0KF52_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZpDQJuVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ccb0KF52, 1, m, &cIf_ccb0KF52_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WDzNZK87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rpFfDlhd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cYfYYztr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rpFfDlhd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UFvWeG5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9Q5GQvFQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uVXwVoEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sZQ9glRe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AOPH1ZMG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IzniAwLc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IzniAwLc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Bq3ycesv, 1, m, &cDelay_Bq3ycesv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j2UjezHy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Bq3ycesv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Bq3ycesv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UFvWeG5V, 0, m, &cIf_UFvWeG5V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IzniAwLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bq3ycesv, 0, m, &cDelay_Bq3ycesv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j2UjezHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bq3ycesv, 0, m, &cDelay_Bq3ycesv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sc4DtaQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SaCw5xzu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uyhR4zul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PlCh4cLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HiSNXck5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0L8kQGrU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0L8kQGrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AOPH1ZMG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HiSNXck5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UFvWeG5V, 1, m, &cIf_UFvWeG5V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uyhR4zul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uVXwVoEr, 0, m, &cIf_uVXwVoEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SaCw5xzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uVXwVoEr, 1, m, &cIf_uVXwVoEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sZQ9glRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jle1DMzk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9Q5GQvFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jle1DMzk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nlzsEzgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_m4CtaiQZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2Fe4MFCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RaLoJUGk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fFo51Hph_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4DX4ogmc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4DX4ogmc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nQUEuVFi, 1, m, &cDelay_nQUEuVFi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FLDsY9TN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nQUEuVFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nQUEuVFi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nlzsEzgB, 0, m, &cIf_nlzsEzgB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4DX4ogmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nQUEuVFi, 0, m, &cDelay_nQUEuVFi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FLDsY9TN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nQUEuVFi, 0, m, &cDelay_nQUEuVFi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_75TxMyTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vfMGJ6TB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bUXmkPYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xHeLjotr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KNLrIJJM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SzlbL4XT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SzlbL4XT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fFo51Hph_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KNLrIJJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nlzsEzgB, 1, m, &cIf_nlzsEzgB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vfMGJ6TB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2Fe4MFCE, 1, m, &cIf_2Fe4MFCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bUXmkPYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2Fe4MFCE, 0, m, &cIf_2Fe4MFCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RaLoJUGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WrgAvrwU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_m4CtaiQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WrgAvrwU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZqQ7wp0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cAeOoFsg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_G4iQ9Qd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ufxi2ok3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_unNf22SI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_A0gXLPX3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_A0gXLPX3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dsBjtt49, 1, m, &cDelay_dsBjtt49_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5RWcMpPw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dsBjtt49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dsBjtt49, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZqQ7wp0S, 0, m, &cIf_ZqQ7wp0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A0gXLPX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dsBjtt49, 0, m, &cDelay_dsBjtt49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5RWcMpPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dsBjtt49, 0, m, &cDelay_dsBjtt49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NFoSYsdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oRSFDlV9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cT4WLB9L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3kpPQ990_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kPSrxKxR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JRHQOjnm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kPSrxKxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZqQ7wp0S, 1, m, &cIf_ZqQ7wp0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JRHQOjnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_unNf22SI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cT4WLB9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G4iQ9Qd5, 0, m, &cIf_G4iQ9Qd5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oRSFDlV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G4iQ9Qd5, 1, m, &cIf_G4iQ9Qd5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ufxi2ok3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zZHQPpp9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cAeOoFsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zZHQPpp9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sQhm5gsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5We2ZvMa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Hrq8GsV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NKxDgR4c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JIHx0I6j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bzMzvf1Q_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bzMzvf1Q_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uLdYUEZf, 1, m, &cDelay_uLdYUEZf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rxj19Zie_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uLdYUEZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uLdYUEZf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sQhm5gsP, 0, m, &cIf_sQhm5gsP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bzMzvf1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uLdYUEZf, 0, m, &cDelay_uLdYUEZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rxj19Zie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uLdYUEZf, 0, m, &cDelay_uLdYUEZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5w2ejPlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mWnYk6gI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aTh1RiWL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5J9mgYVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VaBYOpp6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZnKsF4Qi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZnKsF4Qi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JIHx0I6j_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VaBYOpp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sQhm5gsP, 1, m, &cIf_sQhm5gsP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aTh1RiWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hrq8GsV5, 0, m, &cIf_Hrq8GsV5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mWnYk6gI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hrq8GsV5, 1, m, &cIf_Hrq8GsV5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NKxDgR4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kn3Jy30w, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5We2ZvMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kn3Jy30w, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_X6IkASV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LKI9QSbN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bqoERYQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wvABKX56_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Sb5YffFC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xYWuGUdz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xYWuGUdz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lFv572Bp, 1, m, &cDelay_lFv572Bp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xqZn7TkT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lFv572Bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lFv572Bp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_X6IkASV9, 0, m, &cIf_X6IkASV9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xYWuGUdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lFv572Bp, 0, m, &cDelay_lFv572Bp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xqZn7TkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lFv572Bp, 0, m, &cDelay_lFv572Bp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nFfRp5FH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XFBtP1by_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cbkBAxCb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hVqBhTc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cApdLr3Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9FCdy4xU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9FCdy4xU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Sb5YffFC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cApdLr3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X6IkASV9, 1, m, &cIf_X6IkASV9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XFBtP1by_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bqoERYQS, 1, m, &cIf_bqoERYQS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cbkBAxCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bqoERYQS, 0, m, &cIf_bqoERYQS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wvABKX56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F7RRw1P1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LKI9QSbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F7RRw1P1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_F4BBTS8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_3w63eM0N_sendMessage(_c, 0, m);
  cMsg_LmTNkgGN_sendMessage(_c, 0, m);
  cMsg_OGfBsHkM_sendMessage(_c, 0, m);
  cMsg_aU9xrJwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_D3KRlDrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_3w63eM0N_sendMessage(_c, 0, m);
  cMsg_Umktsdbz_sendMessage(_c, 0, m);
  cMsg_GcYOxo3O_sendMessage(_c, 0, m);
  cMsg_ihldvYQ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_F8rdYyfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_vo5RBiGl_sendMessage(_c, 0, m);
  cMsg_Umktsdbz_sendMessage(_c, 0, m);
  cMsg_aU9xrJwt_sendMessage(_c, 0, m);
  cMsg_vDxQZKGw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nqfzoeVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_vo5RBiGl_sendMessage(_c, 0, m);
  cMsg_nWTDiYn0_sendMessage(_c, 0, m);
  cMsg_OGfBsHkM_sendMessage(_c, 0, m);
  cMsg_kQ3W7Sxh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_h4uIy9xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_OQK2XK5B_sendMessage(_c, 0, m);
  cMsg_ihldvYQ8_sendMessage(_c, 0, m);
  cMsg_ER46jd5n_sendMessage(_c, 0, m);
  cMsg_OGfBsHkM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dynPr3Qj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_OQK2XK5B_sendMessage(_c, 0, m);
  cMsg_kQ3W7Sxh_sendMessage(_c, 0, m);
  cMsg_Umktsdbz_sendMessage(_c, 0, m);
  cMsg_8Oof0JrZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nvlC42wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lJKYLPba_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m0LzDyNM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4F8Y5ikA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lJKYLPba_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m0LzDyNM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ds9u6z5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_r4l8CwVx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oG0xzaqx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fErIT7Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_r4l8CwVx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oG0xzaqx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TgWpnt4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hFL1EDpH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qiBDS6jk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kDObYG9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hFL1EDpH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qiBDS6jk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3w63eM0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_nvlC42wH_sendMessage(_c, 0, m);
  cMsg_fErIT7Nw_sendMessage(_c, 0, m);
  cMsg_kDObYG9I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vo5RBiGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_4F8Y5ikA_sendMessage(_c, 0, m);
  cMsg_ds9u6z5h_sendMessage(_c, 0, m);
  cMsg_kDObYG9I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OQK2XK5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_4F8Y5ikA_sendMessage(_c, 0, m);
  cMsg_fErIT7Nw_sendMessage(_c, 0, m);
  cMsg_TgWpnt4v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KjKdy0Uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DuuGy1XR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sLOPDhxR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6ery8gF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DuuGy1XR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sLOPDhxR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2fR3F8kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xc69lchF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QqLwVuT9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sold01A8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xc69lchF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QqLwVuT9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fpAKMhpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0cSbeKNM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jBOQOtTm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zCrgOTwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0cSbeKNM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jBOQOtTm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Umktsdbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_6ery8gF8_sendMessage(_c, 0, m);
  cMsg_Sold01A8_sendMessage(_c, 0, m);
  cMsg_zCrgOTwr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LmTNkgGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_6ery8gF8_sendMessage(_c, 0, m);
  cMsg_2fR3F8kn_sendMessage(_c, 0, m);
  cMsg_fpAKMhpK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nWTDiYn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_KjKdy0Uh_sendMessage(_c, 0, m);
  cMsg_Sold01A8_sendMessage(_c, 0, m);
  cMsg_fpAKMhpK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VYSfdNpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3kpPQ990_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NFoSYsdZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H6ls3lCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3kpPQ990_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NFoSYsdZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h8JLKxKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5J9mgYVQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5w2ejPlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lB22n0fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5J9mgYVQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5w2ejPlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oSqu44EI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hVqBhTc8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nFfRp5FH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xORG0dbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hVqBhTc8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nFfRp5FH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kQ3W7Sxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_VYSfdNpY_sendMessage(_c, 0, m);
  cMsg_lB22n0fi_sendMessage(_c, 0, m);
  cMsg_xORG0dbT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ihldvYQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_H6ls3lCG_sendMessage(_c, 0, m);
  cMsg_h8JLKxKC_sendMessage(_c, 0, m);
  cMsg_xORG0dbT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aU9xrJwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_H6ls3lCG_sendMessage(_c, 0, m);
  cMsg_lB22n0fi_sendMessage(_c, 0, m);
  cMsg_oSqu44EI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fJ1f3kkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cOItQbup_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ecE82Ssq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IgRDhrli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cOItQbup_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ecE82Ssq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_36CWliqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PlCh4cLR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sc4DtaQW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KpixEGCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PlCh4cLR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sc4DtaQW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ERO1216G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xHeLjotr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_75TxMyTk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wCjHz1RV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xHeLjotr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_75TxMyTk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OGfBsHkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_IgRDhrli_sendMessage(_c, 0, m);
  cMsg_KpixEGCY_sendMessage(_c, 0, m);
  cMsg_wCjHz1RV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GcYOxo3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_IgRDhrli_sendMessage(_c, 0, m);
  cMsg_36CWliqz_sendMessage(_c, 0, m);
  cMsg_ERO1216G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8Oof0JrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_fJ1f3kkH_sendMessage(_c, 0, m);
  cMsg_36CWliqz_sendMessage(_c, 0, m);
  cMsg_wCjHz1RV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ER46jd5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_KjKdy0Uh_sendMessage(_c, 0, m);
  cMsg_2fR3F8kn_sendMessage(_c, 0, m);
  cMsg_zCrgOTwr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vDxQZKGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_fJ1f3kkH_sendMessage(_c, 0, m);
  cMsg_KpixEGCY_sendMessage(_c, 0, m);
  cMsg_ERO1216G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_BJRwzgNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KSuXCI44_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nwU7lqZj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Fu7YuB9N, 0, m, &cSlice_Fu7YuB9N_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PrOK88Y9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Fu7YuB9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nqoStzv5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nqoStzv5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dvWYryum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nqoStzv5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_nqoStzv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PiVvO9R2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NZYxGsn2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fhs44sRu, 0, m, &cSlice_fhs44sRu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5K6XTbx1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_fhs44sRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_k58Hq1Bd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_k58Hq1Bd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dTjDptag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_k58Hq1Bd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_k58Hq1Bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KRUHAEVX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5K6XTbx1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0pPuG6wO, 0, m, &cSlice_0pPuG6wO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nwU7lqZj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0pPuG6wO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aZjv3qL8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aZjv3qL8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xm7S5azb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aZjv3qL8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aZjv3qL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Dv9YKxQ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PrOK88Y9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XxgfxTPk, 0, m, &cSlice_XxgfxTPk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cOE9YGM2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XxgfxTPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fjWYy0UI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fjWYy0UI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QZ3Q5RES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fjWYy0UI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fjWYy0UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dXLND0jC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cOE9YGM2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TixoLtwW, 0, m, &cSlice_TixoLtwW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_h4sPO9gF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_TixoLtwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0zni5tVC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0zni5tVC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_VZq7JZsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0zni5tVC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0zni5tVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JcCwX2OS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kvUWNWPo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8nFtS7KL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8nFtS7KL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dDSOvZKx, 1, m, &cDelay_dDSOvZKx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w2IdVKX4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dDSOvZKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dDSOvZKx, m);
  cMsg_FsBFf3XA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8nFtS7KL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dDSOvZKx, 0, m, &cDelay_dDSOvZKx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w2IdVKX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dDSOvZKx, 0, m, &cDelay_dDSOvZKx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_vtTJSks5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_28FNxgcY, HV_BINOP_SUBTRACT, 0, m, &cBinop_28FNxgcY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_xwmhBxjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L63m6oI1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fs05aNuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L63m6oI1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_zLDVwawI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vtTJSks5, 0, m, &cVar_vtTJSks5_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_2EiBb1eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kIIPqYka_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NEtjC2LX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KtJJLeu9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_28FNxgcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GK4bKebx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GK4bKebx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sCmoSiFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sCmoSiFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gx5dqy7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_chKn55zR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bXzUsiTm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tbak8qKR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tbak8qKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6W9MDJOk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bXzUsiTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xwmhBxjC, 1, m, &cIf_xwmhBxjC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zs8T3DkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fs05aNuX, 1, m, &cIf_fs05aNuX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6W9MDJOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_xwmhBxjC, 0, m, &cIf_xwmhBxjC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gx5dqy7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fs05aNuX, 0, m, &cIf_fs05aNuX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kIIPqYka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_NEtjC2LX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_28FNxgcY, HV_BINOP_SUBTRACT, 1, m, &cBinop_28FNxgcY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KtJJLeu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vtTJSks5, 0, m, &cVar_vtTJSks5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L63m6oI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sq5qjv7d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_h4sPO9gF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_20OMpLjw, 0, m, &cSlice_20OMpLjw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_20OMpLjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JTmFTUWu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JTmFTUWu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_4MzSIZa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JTmFTUWu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JTmFTUWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H5heWyZC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Wiz8oCLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dvkEuKQR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_d8JlXwEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YVgf8AWf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_qvxsQHlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tdcizj8Q, 0, m, &cVar_tdcizj8Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KSuXCI44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HXKJy1pH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cSucEW8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z28tSQDd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4pKyJ7Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kvUWNWPo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FsBFf3XA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YWzoMHmf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Z28tSQDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YWzoMHmf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_d0BgYzGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_PYGXmu6F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PYGXmu6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2yZdNPeS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2yZdNPeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_loqEuMpz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_enUw6KZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Th6AEHuJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_EjEnVDol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GrNZxGzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gNML9OM0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lq5I5Lg4_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Iwf8MAOi_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8kTtxccW_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wPDYSzWO_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NyRjeQqO_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jIepsrOe_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_lq5I5Lg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g1yctJ34_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Iwf8MAOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LJLcbevB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8kTtxccW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yVZnhTeJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_wPDYSzWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dz8ed2mb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_NyRjeQqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_No6jCVx9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jIepsrOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3uM3YTI1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_bOVnMnce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_alEGKIsP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WrZSx7fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_N4jF1eg1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xflop37o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_m5wrHCWf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_m5wrHCWf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7A1lmN7d, 1, m, &cDelay_7A1lmN7d_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XVrCsyqQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7A1lmN7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7A1lmN7d, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bOVnMnce, 0, m, &cIf_bOVnMnce_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m5wrHCWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7A1lmN7d, 0, m, &cDelay_7A1lmN7d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XVrCsyqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7A1lmN7d, 0, m, &cDelay_7A1lmN7d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LENNoANP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SV6SfjAq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aryRpQp5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K0X9Q35m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kxDnBLWm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4c512JJW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kxDnBLWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bOVnMnce, 1, m, &cIf_bOVnMnce_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4c512JJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xflop37o_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SV6SfjAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WrZSx7fe, 1, m, &cIf_WrZSx7fe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aryRpQp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WrZSx7fe, 0, m, &cIf_WrZSx7fe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N4jF1eg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9AePYHWf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_alEGKIsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9AePYHWf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vnJ29WXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Qqvynz1C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bV7uiKWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UXdFsuUi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pRzDsetV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Vp2hkFON_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Vp2hkFON_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D1lmdYOh, 1, m, &cDelay_D1lmdYOh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RWfVGU3d_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D1lmdYOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D1lmdYOh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vnJ29WXb, 0, m, &cIf_vnJ29WXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vp2hkFON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D1lmdYOh, 0, m, &cDelay_D1lmdYOh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RWfVGU3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D1lmdYOh, 0, m, &cDelay_D1lmdYOh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LhEN3Vxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IcpgUBzh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rt9At28V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6WSc850m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZgXsq3eT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nzY52Rzx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZgXsq3eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vnJ29WXb, 1, m, &cIf_vnJ29WXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nzY52Rzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pRzDsetV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IcpgUBzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bV7uiKWD, 1, m, &cIf_bV7uiKWD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rt9At28V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bV7uiKWD, 0, m, &cIf_bV7uiKWD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UXdFsuUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0I8k0jgu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Qqvynz1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0I8k0jgu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0Ta0qrRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xSeiHw8B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tpYcyjps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s6i0uDVH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YxiBJQSk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dviqZTEy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dviqZTEy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hgPXD9jK, 1, m, &cDelay_hgPXD9jK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Andh8G0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hgPXD9jK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hgPXD9jK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0Ta0qrRq, 0, m, &cIf_0Ta0qrRq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dviqZTEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hgPXD9jK, 0, m, &cDelay_hgPXD9jK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3Andh8G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hgPXD9jK, 0, m, &cDelay_hgPXD9jK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gpoyAHtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b4oKfL24_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WtKvexE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_apoXE5UG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BoJvLZgO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pj9VAH0t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pj9VAH0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YxiBJQSk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BoJvLZgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Ta0qrRq, 1, m, &cIf_0Ta0qrRq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b4oKfL24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tpYcyjps, 1, m, &cIf_tpYcyjps_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WtKvexE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tpYcyjps, 0, m, &cIf_tpYcyjps_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_s6i0uDVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_89CneFbQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xSeiHw8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_89CneFbQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_G3qvllkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OZAGwZKO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bC6xrJhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kchDj4qp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ugxmk43L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_o5c483A3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_o5c483A3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_17zpDdeE, 1, m, &cDelay_17zpDdeE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NVcEVyvK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_17zpDdeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_17zpDdeE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_G3qvllkm, 0, m, &cIf_G3qvllkm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o5c483A3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_17zpDdeE, 0, m, &cDelay_17zpDdeE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NVcEVyvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_17zpDdeE, 0, m, &cDelay_17zpDdeE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NwZCDPMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SiMouJQU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZMrXG6BD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rDYRkC0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OMqwKPQL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QvZ6lmOP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QvZ6lmOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ugxmk43L_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OMqwKPQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G3qvllkm, 1, m, &cIf_G3qvllkm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZMrXG6BD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bC6xrJhD, 0, m, &cIf_bC6xrJhD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SiMouJQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bC6xrJhD, 1, m, &cIf_bC6xrJhD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kchDj4qp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iyNutQ0q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OZAGwZKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iyNutQ0q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_N22xcEWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xeP7OQzE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YLWWRlYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RyFfBsyI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zQg3KDMr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KF9H5Ij1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KF9H5Ij1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bZ5zY2Qt, 1, m, &cDelay_bZ5zY2Qt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8wByAVAK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bZ5zY2Qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bZ5zY2Qt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_N22xcEWq, 0, m, &cIf_N22xcEWq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KF9H5Ij1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bZ5zY2Qt, 0, m, &cDelay_bZ5zY2Qt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8wByAVAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bZ5zY2Qt, 0, m, &cDelay_bZ5zY2Qt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BtgOUWr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AhxkES8z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ygnBh8Sa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IjhhRlRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WPYnhKs3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zEp3oLJv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WPYnhKs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N22xcEWq, 1, m, &cIf_N22xcEWq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zEp3oLJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zQg3KDMr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ygnBh8Sa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YLWWRlYN, 0, m, &cIf_YLWWRlYN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AhxkES8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YLWWRlYN, 1, m, &cIf_YLWWRlYN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RyFfBsyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xzxMSL8N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xeP7OQzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xzxMSL8N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yDlX55ds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_F5LPtZ64_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EpydXbxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q0t30xD7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NEVrUuqt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MbI4jM2r_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MbI4jM2r_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_h0KpvwXn, 1, m, &cDelay_h0KpvwXn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rLpZ8Q9e_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_h0KpvwXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h0KpvwXn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yDlX55ds, 0, m, &cIf_yDlX55ds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MbI4jM2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0KpvwXn, 0, m, &cDelay_h0KpvwXn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rLpZ8Q9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0KpvwXn, 0, m, &cDelay_h0KpvwXn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oldzNuTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jiQFPQLb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jDJW692L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i2ilf9r4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_baphI9v0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b0qMv0NO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b0qMv0NO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NEVrUuqt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_baphI9v0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yDlX55ds, 1, m, &cIf_yDlX55ds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jiQFPQLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EpydXbxY, 1, m, &cIf_EpydXbxY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jDJW692L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EpydXbxY, 0, m, &cIf_EpydXbxY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Q0t30xD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6arohPpk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_F5LPtZ64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6arohPpk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sBvBkQsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Enof5ead_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eyZxRV3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UZE82goG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0E1eD32N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oCbkn7RM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oCbkn7RM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AwfHFXeZ, 1, m, &cDelay_AwfHFXeZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1w3WflUX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AwfHFXeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AwfHFXeZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sBvBkQsn, 0, m, &cIf_sBvBkQsn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oCbkn7RM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AwfHFXeZ, 0, m, &cDelay_AwfHFXeZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1w3WflUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AwfHFXeZ, 0, m, &cDelay_AwfHFXeZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NeW73gzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qb29TEci_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yithAkBY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nOnfTCUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aTdK1uiB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YMNfiMck_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aTdK1uiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sBvBkQsn, 1, m, &cIf_sBvBkQsn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YMNfiMck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0E1eD32N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yithAkBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eyZxRV3s, 0, m, &cIf_eyZxRV3s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qb29TEci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eyZxRV3s, 1, m, &cIf_eyZxRV3s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UZE82goG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6DHhF9e0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Enof5ead_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6DHhF9e0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PoRoGLvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w3gb25GX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yPKIx9Wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4rKhbg5K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Kuw3sCQM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DvRrat4a_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DvRrat4a_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fji8EhzB, 1, m, &cDelay_fji8EhzB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y40kdVEC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fji8EhzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fji8EhzB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PoRoGLvE, 0, m, &cIf_PoRoGLvE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DvRrat4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fji8EhzB, 0, m, &cDelay_fji8EhzB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y40kdVEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fji8EhzB, 0, m, &cDelay_fji8EhzB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D6keWFCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mVWLSvsh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y6ZEOjJ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FS8QVTte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GBgoZbPK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ulpLR6hG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ulpLR6hG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Kuw3sCQM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GBgoZbPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PoRoGLvE, 1, m, &cIf_PoRoGLvE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y6ZEOjJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yPKIx9Wm, 0, m, &cIf_yPKIx9Wm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mVWLSvsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yPKIx9Wm, 1, m, &cIf_yPKIx9Wm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4rKhbg5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JSCHm5Xo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_w3gb25GX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JSCHm5Xo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_c6PU8Khx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ggkyYiiF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_juHI2nm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3d0uTg32_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qTMdJwZK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FI5Stpg3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FI5Stpg3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oblwzla2, 1, m, &cDelay_oblwzla2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6jPzOPoI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oblwzla2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oblwzla2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_c6PU8Khx, 0, m, &cIf_c6PU8Khx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FI5Stpg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oblwzla2, 0, m, &cDelay_oblwzla2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6jPzOPoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oblwzla2, 0, m, &cDelay_oblwzla2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N514miTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lhoeja8d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GyLpcBi8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kOAigupP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2pZbxIcV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RAw0WFOY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RAw0WFOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qTMdJwZK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2pZbxIcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c6PU8Khx, 1, m, &cIf_c6PU8Khx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GyLpcBi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_juHI2nm0, 0, m, &cIf_juHI2nm0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lhoeja8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_juHI2nm0, 1, m, &cIf_juHI2nm0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3d0uTg32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qshJ9co9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ggkyYiiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qshJ9co9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_og6zGwPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H034VkAX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rDzwZV32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_q8tUhRYM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_c2QHniCT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YRFx1dwS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YRFx1dwS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cnF3yr31, 1, m, &cDelay_cnF3yr31_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_srio2dmG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cnF3yr31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cnF3yr31, m);
  cIf_onMessage(_c, &Context(_c)->cIf_og6zGwPR, 0, m, &cIf_og6zGwPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YRFx1dwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cnF3yr31, 0, m, &cDelay_cnF3yr31_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_srio2dmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cnF3yr31, 0, m, &cDelay_cnF3yr31_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uxFwnf9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VuM83UWZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LYmU2Q4b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jlWLp3p9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ae76TlPd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xlJQLdSC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ae76TlPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_og6zGwPR, 1, m, &cIf_og6zGwPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xlJQLdSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_c2QHniCT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VuM83UWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rDzwZV32, 1, m, &cIf_rDzwZV32_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LYmU2Q4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rDzwZV32, 0, m, &cIf_rDzwZV32_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q8tUhRYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bve1KrZg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H034VkAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bve1KrZg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7uWzJWJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LZXYdXnS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RoLpwPaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OSXwNEUv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pDxLVeR3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DIZvB0SM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DIZvB0SM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KuoejI63, 1, m, &cDelay_KuoejI63_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d8lvxXuN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KuoejI63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KuoejI63, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7uWzJWJa, 0, m, &cIf_7uWzJWJa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DIZvB0SM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KuoejI63, 0, m, &cDelay_KuoejI63_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d8lvxXuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KuoejI63, 0, m, &cDelay_KuoejI63_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CkWiuudJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k5SKisZ2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CIb160j2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k1v43him_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GBYQ7Bdd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9LGFO1bA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9LGFO1bA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pDxLVeR3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GBYQ7Bdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7uWzJWJa, 1, m, &cIf_7uWzJWJa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k5SKisZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RoLpwPaP, 1, m, &cIf_RoLpwPaP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CIb160j2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RoLpwPaP, 0, m, &cIf_RoLpwPaP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OSXwNEUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_znuoyzzm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LZXYdXnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_znuoyzzm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9Gw7bdyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4SyfgRrf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_aEbampFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nuAFRzEK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2esOFNxQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yJnYUL1k_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yJnYUL1k_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pT5yQww9, 1, m, &cDelay_pT5yQww9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_REWJmnVg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_pT5yQww9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pT5yQww9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9Gw7bdyk, 0, m, &cIf_9Gw7bdyk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yJnYUL1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pT5yQww9, 0, m, &cDelay_pT5yQww9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_REWJmnVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pT5yQww9, 0, m, &cDelay_pT5yQww9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VQG0CaqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D9Rv0ngL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OZIvahZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bgM6zMpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_31drg7HQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m1tWSMPP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m1tWSMPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2esOFNxQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_31drg7HQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Gw7bdyk, 1, m, &cIf_9Gw7bdyk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OZIvahZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aEbampFM, 0, m, &cIf_aEbampFM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D9Rv0ngL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aEbampFM, 1, m, &cIf_aEbampFM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nuAFRzEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ibunc3Qs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4SyfgRrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ibunc3Qs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g1yctJ34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_StGCpqRm_sendMessage(_c, 0, m);
  cMsg_bbaUoNjr_sendMessage(_c, 0, m);
  cMsg_FPYEP6aD_sendMessage(_c, 0, m);
  cMsg_W6gzj3r7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LJLcbevB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_StGCpqRm_sendMessage(_c, 0, m);
  cMsg_anrZ7Z61_sendMessage(_c, 0, m);
  cMsg_p2orK9b2_sendMessage(_c, 0, m);
  cMsg_CKpqpB65_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yVZnhTeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_EoAhwAlJ_sendMessage(_c, 0, m);
  cMsg_anrZ7Z61_sendMessage(_c, 0, m);
  cMsg_W6gzj3r7_sendMessage(_c, 0, m);
  cMsg_31EGhwLg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Dz8ed2mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_EoAhwAlJ_sendMessage(_c, 0, m);
  cMsg_YYTE4zH0_sendMessage(_c, 0, m);
  cMsg_FPYEP6aD_sendMessage(_c, 0, m);
  cMsg_lqfK90In_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_No6jCVx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_7kZuBwWw_sendMessage(_c, 0, m);
  cMsg_CKpqpB65_sendMessage(_c, 0, m);
  cMsg_uovXWyeb_sendMessage(_c, 0, m);
  cMsg_FPYEP6aD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3uM3YTI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_7kZuBwWw_sendMessage(_c, 0, m);
  cMsg_lqfK90In_sendMessage(_c, 0, m);
  cMsg_anrZ7Z61_sendMessage(_c, 0, m);
  cMsg_k4omRyKq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gjuT9nI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K0X9Q35m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LENNoANP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YNlkrarW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K0X9Q35m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LENNoANP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PmBKCBnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6WSc850m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LhEN3Vxn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9qDsYmHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6WSc850m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LhEN3Vxn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BZaDyLAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_apoXE5UG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gpoyAHtO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mELJBpae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_apoXE5UG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gpoyAHtO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_StGCpqRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_gjuT9nI7_sendMessage(_c, 0, m);
  cMsg_9qDsYmHy_sendMessage(_c, 0, m);
  cMsg_mELJBpae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EoAhwAlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_YNlkrarW_sendMessage(_c, 0, m);
  cMsg_PmBKCBnI_sendMessage(_c, 0, m);
  cMsg_mELJBpae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7kZuBwWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_YNlkrarW_sendMessage(_c, 0, m);
  cMsg_9qDsYmHy_sendMessage(_c, 0, m);
  cMsg_BZaDyLAR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QSJxesep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rDYRkC0Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NwZCDPMU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZkAd0Xp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rDYRkC0Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NwZCDPMU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vz0ysXdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IjhhRlRs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BtgOUWr2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RQIMNSUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IjhhRlRs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BtgOUWr2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PeRFTAwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i2ilf9r4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oldzNuTI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QxewCwFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i2ilf9r4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oldzNuTI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_anrZ7Z61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ZkAd0Xp0_sendMessage(_c, 0, m);
  cMsg_RQIMNSUi_sendMessage(_c, 0, m);
  cMsg_QxewCwFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bbaUoNjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ZkAd0Xp0_sendMessage(_c, 0, m);
  cMsg_Vz0ysXdz_sendMessage(_c, 0, m);
  cMsg_PeRFTAwA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YYTE4zH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_QSJxesep_sendMessage(_c, 0, m);
  cMsg_RQIMNSUi_sendMessage(_c, 0, m);
  cMsg_PeRFTAwA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QctFCgrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jlWLp3p9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uxFwnf9H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wmuyqd5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jlWLp3p9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uxFwnf9H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VFSSx6lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k1v43him_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CkWiuudJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hG7uSswz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k1v43him_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CkWiuudJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ldHyVSKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bgM6zMpK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VQG0CaqA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n46hVCEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bgM6zMpK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VQG0CaqA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lqfK90In_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_QctFCgrI_sendMessage(_c, 0, m);
  cMsg_hG7uSswz_sendMessage(_c, 0, m);
  cMsg_n46hVCEI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CKpqpB65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Wmuyqd5C_sendMessage(_c, 0, m);
  cMsg_VFSSx6lr_sendMessage(_c, 0, m);
  cMsg_n46hVCEI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W6gzj3r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Wmuyqd5C_sendMessage(_c, 0, m);
  cMsg_hG7uSswz_sendMessage(_c, 0, m);
  cMsg_ldHyVSKL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_36v6raiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nOnfTCUN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NeW73gzr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Fs5Sn52e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nOnfTCUN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NeW73gzr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sSDd9nX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FS8QVTte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_D6keWFCH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AyiDv1Zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FS8QVTte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_D6keWFCH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7c2Dhe7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kOAigupP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_N514miTh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Kp3ArEQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kOAigupP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_N514miTh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FPYEP6aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Fs5Sn52e_sendMessage(_c, 0, m);
  cMsg_AyiDv1Zd_sendMessage(_c, 0, m);
  cMsg_Kp3ArEQO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p2orK9b2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Fs5Sn52e_sendMessage(_c, 0, m);
  cMsg_sSDd9nX5_sendMessage(_c, 0, m);
  cMsg_7c2Dhe7c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_k4omRyKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_36v6raiz_sendMessage(_c, 0, m);
  cMsg_sSDd9nX5_sendMessage(_c, 0, m);
  cMsg_Kp3ArEQO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uovXWyeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_QSJxesep_sendMessage(_c, 0, m);
  cMsg_Vz0ysXdz_sendMessage(_c, 0, m);
  cMsg_QxewCwFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_31EGhwLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_36v6raiz_sendMessage(_c, 0, m);
  cMsg_AyiDv1Zd_sendMessage(_c, 0, m);
  cMsg_7c2Dhe7c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YX3muswt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bheKyYL8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zCa665da_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_N68sRGwp, 0, m, &cSlice_N68sRGwp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PnnvaCUu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_N68sRGwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xytz2SYY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xytz2SYY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_q501eY8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xytz2SYY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xytz2SYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jqUfix2y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rBk8vOVz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sjr8Mvc3, 0, m, &cSlice_sjr8Mvc3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GV0EUnrK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sjr8Mvc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_akzm974T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_akzm974T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qVEpltkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_akzm974T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_akzm974T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DAoh08TB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GV0EUnrK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zjATFap3, 0, m, &cSlice_zjATFap3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zCa665da_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_zjATFap3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yZUiceS7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yZUiceS7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_pBDKKbjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yZUiceS7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yZUiceS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XXxaVavE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PnnvaCUu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_brAKNH7o, 0, m, &cSlice_brAKNH7o_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WB57aK5L_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_brAKNH7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mbqUocwb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mbqUocwb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_HQspAra7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mbqUocwb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mbqUocwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DiC3Wy4s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WB57aK5L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fvDGUM59, 0, m, &cSlice_fvDGUM59_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9UBk7R55_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_fvDGUM59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eU3eq8Ou_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eU3eq8Ou_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ORCXS8oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eU3eq8Ou_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eU3eq8Ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lRqht7Jz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LopjKTmQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Y9qw8C6Y_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Y9qw8C6Y_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WFS9R8EI, 1, m, &cDelay_WFS9R8EI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sHbU1XQL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WFS9R8EI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WFS9R8EI, m);
  cMsg_16PmpB8x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y9qw8C6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WFS9R8EI, 0, m, &cDelay_WFS9R8EI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sHbU1XQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WFS9R8EI, 0, m, &cDelay_WFS9R8EI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_d27ZQFHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mzEbEjix, HV_BINOP_SUBTRACT, 0, m, &cBinop_mzEbEjix_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_cd7L11GN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pk3R1Kmk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wqaifqTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pk3R1Kmk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_7NeQ0RBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d27ZQFHS, 0, m, &cVar_d27ZQFHS_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_1QlvBTcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lTjMBY6X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lpBKyRnL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tZmpbVDv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mzEbEjix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K1fxJlx1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_K1fxJlx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Lp8oLgfr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lp8oLgfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kmmLtwcC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MOAyW1vN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X1EcgYDz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wPUsiXNG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X1EcgYDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cd7L11GN, 1, m, &cIf_cd7L11GN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wPUsiXNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CIGFmtwv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kAT0PJGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wqaifqTy, 1, m, &cIf_wqaifqTy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CIGFmtwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_cd7L11GN, 0, m, &cIf_cd7L11GN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kmmLtwcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wqaifqTy, 0, m, &cIf_wqaifqTy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tZmpbVDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d27ZQFHS, 0, m, &cVar_d27ZQFHS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lTjMBY6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_lpBKyRnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mzEbEjix, HV_BINOP_SUBTRACT, 1, m, &cBinop_mzEbEjix_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pk3R1Kmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oLlIb9UZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9UBk7R55_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WP6zTl7u, 0, m, &cSlice_WP6zTl7u_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_WP6zTl7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AHzCDDlV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AHzCDDlV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Sk6q1OTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AHzCDDlV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AHzCDDlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cWYD5d16_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Th6AEHuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_32UeUc6W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GrNZxGzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jg0EXJWU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_nMYVd3j5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EjEnVDol, 0, m, &cVar_EjEnVDol_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bheKyYL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zKknb96U, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_V6sH2B3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LopjKTmQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_X8uCpRmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_to7dYW6A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_16PmpB8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UTqZcKrj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_to7dYW6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UTqZcKrj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ox34eHVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_XGVlYGLP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XGVlYGLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3P4QTaKT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3P4QTaKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6Eh65mx0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_rlZkuS3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J1d53Pha_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_n9rCAxEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rhrRtUSb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2HcDxVFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SUguuqmU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_I3OOVIaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZA5yGdMN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_OsXpFhd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jtb6AYZl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pzEDCEt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MXP48BBQ_sendMessage);
  cMsg_iYWJwgXX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MXP48BBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pzEDCEt2, 1, m, &cVar_pzEDCEt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NMKtWl1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e0IyznHc_sendMessage(_c, 0, m);
  cMsg_U7q6PW8G_sendMessage(_c, 0, m);
  cMsg_ihCUS5IU_sendMessage(_c, 0, m);
  cMsg_nGjMbXlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_a4jhg63G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HulEsavT, 0, m, &cSlice_HulEsavT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_HulEsavT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZG91qr3J_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZG91qr3J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_mJTSq7eC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZG91qr3J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ZG91qr3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RgT6FIuu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1ovzAW3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UzxMwjv2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UzxMwjv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_jmMAfuvQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jmMAfuvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FDqmTOgj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FDqmTOgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gaoUcbWL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bVxMeMCl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gaoUcbWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RolSHRU5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bVxMeMCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jx6mvYvb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RolSHRU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kQsQz9wJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Jx6mvYvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HylLCdGf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HylLCdGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hgjz0tET_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kQsQz9wJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1rOHPfGq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_hgjz0tET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TWkRp1tc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1rOHPfGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ic5AmThW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TWkRp1tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sKiXTPn8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_DivKFkWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u1mN1j54_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_snTdr4ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oQPZRIR8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VZ0gp8wN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xz20Up9r_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z1yvvhve_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WeOUFYwG_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8KnRPQYm_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1UVW3Pf1_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ecKC8LFq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_xz20Up9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_djxP3U1o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_z1yvvhve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lJMD5Tz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WeOUFYwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SdUTAZeu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8KnRPQYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uxhGu8r5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1UVW3Pf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LX7PgnAP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ecKC8LFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7gf2SoVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_uPt5QEQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MyfyJg8U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KVxR44GY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vLmSRcXK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0VnHwCCf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5XJix8C4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5XJix8C4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vO6BPrfb, 1, m, &cDelay_vO6BPrfb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D44kWD1b_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vO6BPrfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vO6BPrfb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uPt5QEQY, 0, m, &cIf_uPt5QEQY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5XJix8C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vO6BPrfb, 0, m, &cDelay_vO6BPrfb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D44kWD1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vO6BPrfb, 0, m, &cDelay_vO6BPrfb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6rkn9f4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bAMTGKPP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TrODKheE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BSFtGUjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DNY1cK2K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6CLC0SjN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DNY1cK2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uPt5QEQY, 1, m, &cIf_uPt5QEQY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6CLC0SjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0VnHwCCf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TrODKheE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KVxR44GY, 0, m, &cIf_KVxR44GY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bAMTGKPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KVxR44GY, 1, m, &cIf_KVxR44GY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vLmSRcXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dDG5ncca, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MyfyJg8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dDG5ncca, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yHMpvhNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hWUULsXN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jHtTczmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WqlIkB4u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3jR8YwKr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CRspUUb5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CRspUUb5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HXHMLiOn, 1, m, &cDelay_HXHMLiOn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M8Rtt0et_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HXHMLiOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HXHMLiOn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yHMpvhNy, 0, m, &cIf_yHMpvhNy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CRspUUb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HXHMLiOn, 0, m, &cDelay_HXHMLiOn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M8Rtt0et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HXHMLiOn, 0, m, &cDelay_HXHMLiOn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dDaNAsqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7s2hyjqo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fPfAm5xO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FGgtK9wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Ciuy5EM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Laq1YaN6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0Ciuy5EM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yHMpvhNy, 1, m, &cIf_yHMpvhNy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Laq1YaN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3jR8YwKr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fPfAm5xO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHtTczmD, 0, m, &cIf_jHtTczmD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7s2hyjqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHtTczmD, 1, m, &cIf_jHtTczmD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WqlIkB4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bVhgf0RF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hWUULsXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bVhgf0RF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ejh7ZZzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SvJ43ygB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sGDjgbYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ozXJZLQN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WEbAzWpQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WsAzjwPR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WsAzjwPR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_A4SrYndN, 1, m, &cDelay_A4SrYndN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_110atmdD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_A4SrYndN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_A4SrYndN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ejh7ZZzV, 0, m, &cIf_Ejh7ZZzV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WsAzjwPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_A4SrYndN, 0, m, &cDelay_A4SrYndN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_110atmdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_A4SrYndN, 0, m, &cDelay_A4SrYndN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eyx89gEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VHk2ez3z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rQmQGe6p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CoHoaJYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OpeIW4K1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9YlzRwGr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OpeIW4K1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ejh7ZZzV, 1, m, &cIf_Ejh7ZZzV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9YlzRwGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WEbAzWpQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rQmQGe6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sGDjgbYv, 0, m, &cIf_sGDjgbYv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VHk2ez3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sGDjgbYv, 1, m, &cIf_sGDjgbYv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ozXJZLQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X02XD68H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SvJ43ygB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X02XD68H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NMqhUPCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aCxCEVwe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_akOIqdjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YmWnFrU7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lBit2s0S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CisRm3Ax_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CisRm3Ax_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_biV0Mux5, 1, m, &cDelay_biV0Mux5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LmX0ETvI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_biV0Mux5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_biV0Mux5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NMqhUPCG, 0, m, &cIf_NMqhUPCG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CisRm3Ax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_biV0Mux5, 0, m, &cDelay_biV0Mux5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LmX0ETvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_biV0Mux5, 0, m, &cDelay_biV0Mux5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KeoqKq0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SngEnvQL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rkhduAxo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rzmdZQmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jK1ctguv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w0dIEGUa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w0dIEGUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lBit2s0S_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jK1ctguv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NMqhUPCG, 1, m, &cIf_NMqhUPCG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rkhduAxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_akOIqdjY, 0, m, &cIf_akOIqdjY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SngEnvQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_akOIqdjY, 1, m, &cIf_akOIqdjY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YmWnFrU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pKo7AR0N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aCxCEVwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pKo7AR0N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vtwNaqwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vaxC8zje_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kWvryE5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_poJBDKWr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_X9Y1t4gQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CJDgRB7I_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CJDgRB7I_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZjNE1O1w, 1, m, &cDelay_ZjNE1O1w_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mt5KVsUX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZjNE1O1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZjNE1O1w, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vtwNaqwV, 0, m, &cIf_vtwNaqwV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CJDgRB7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZjNE1O1w, 0, m, &cDelay_ZjNE1O1w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Mt5KVsUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZjNE1O1w, 0, m, &cDelay_ZjNE1O1w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ay5hTLbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K1I6V7iI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_weuZrfmy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zW9nb1CP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TqiPytMu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O3yeM6Ho_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O3yeM6Ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_X9Y1t4gQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TqiPytMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vtwNaqwV, 1, m, &cIf_vtwNaqwV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_weuZrfmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kWvryE5h, 0, m, &cIf_kWvryE5h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K1I6V7iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kWvryE5h, 1, m, &cIf_kWvryE5h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_poJBDKWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iAQHkcJh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vaxC8zje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iAQHkcJh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_C3UP4FmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_09qZL2bU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Yni61l0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_J4RSZpc7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mMX1eD4v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_n8Go5Gzn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_n8Go5Gzn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uLh6eh11, 1, m, &cDelay_uLh6eh11_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_glWzrkIx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uLh6eh11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uLh6eh11, m);
  cIf_onMessage(_c, &Context(_c)->cIf_C3UP4FmA, 0, m, &cIf_C3UP4FmA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n8Go5Gzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uLh6eh11, 0, m, &cDelay_uLh6eh11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_glWzrkIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uLh6eh11, 0, m, &cDelay_uLh6eh11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O7ODyMLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EKvh2bDE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ZWA794o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wgbwuR9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KjAOEZBZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bGAA3ewj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bGAA3ewj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mMX1eD4v_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KjAOEZBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C3UP4FmA, 1, m, &cIf_C3UP4FmA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4ZWA794o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yni61l0w, 0, m, &cIf_Yni61l0w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EKvh2bDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yni61l0w, 1, m, &cIf_Yni61l0w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J4RSZpc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CuTqOQqe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_09qZL2bU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CuTqOQqe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_X86bD3fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VFHjTQKS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jHuKTI4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MOAQPnIn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Pq6evBU0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2fM3b6Rg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2fM3b6Rg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EfbF7VAb, 1, m, &cDelay_EfbF7VAb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WFMQTZ1f_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EfbF7VAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EfbF7VAb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_X86bD3fz, 0, m, &cIf_X86bD3fz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2fM3b6Rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EfbF7VAb, 0, m, &cDelay_EfbF7VAb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WFMQTZ1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EfbF7VAb, 0, m, &cDelay_EfbF7VAb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VOMbbaFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ciJi1Km8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3GytSSqC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fr6c6byR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kAFC441P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rYme0ZD6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kAFC441P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X86bD3fz, 1, m, &cIf_X86bD3fz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rYme0ZD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Pq6evBU0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ciJi1Km8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHuKTI4S, 1, m, &cIf_jHuKTI4S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3GytSSqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHuKTI4S, 0, m, &cIf_jHuKTI4S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MOAQPnIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rIeDG1HR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VFHjTQKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rIeDG1HR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CcdGaDaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DSXJuJm7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IAekMEoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7tp4JAVQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YaVn5Swh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_x2frSGtQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_x2frSGtQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Q3XB1HAI, 1, m, &cDelay_Q3XB1HAI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7X6PlPpH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Q3XB1HAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q3XB1HAI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CcdGaDaZ, 0, m, &cIf_CcdGaDaZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x2frSGtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q3XB1HAI, 0, m, &cDelay_Q3XB1HAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7X6PlPpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q3XB1HAI, 0, m, &cDelay_Q3XB1HAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cz9mFmVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xeJYUCwO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QHIHGSmv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ba1bEPNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4off8QoR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xzth6Dsu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xzth6Dsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YaVn5Swh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4off8QoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CcdGaDaZ, 1, m, &cIf_CcdGaDaZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QHIHGSmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAekMEoh, 0, m, &cIf_IAekMEoh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xeJYUCwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAekMEoh, 1, m, &cIf_IAekMEoh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7tp4JAVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZMsTmAVF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DSXJuJm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZMsTmAVF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_z5Aqd6hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UUBTgU4P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NFN8BZFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i4tcRNzr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gQj2eJL5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cqjLHG5X_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cqjLHG5X_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_B2Q3FB6b, 1, m, &cDelay_B2Q3FB6b_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yohQximn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_B2Q3FB6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B2Q3FB6b, m);
  cIf_onMessage(_c, &Context(_c)->cIf_z5Aqd6hE, 0, m, &cIf_z5Aqd6hE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cqjLHG5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_B2Q3FB6b, 0, m, &cDelay_B2Q3FB6b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yohQximn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B2Q3FB6b, 0, m, &cDelay_B2Q3FB6b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u5d67zIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yDJPPB3R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AWH76OUc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EwKYHbNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lVY7NESa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cbCFU4Ib_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cbCFU4Ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gQj2eJL5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lVY7NESa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z5Aqd6hE, 1, m, &cIf_z5Aqd6hE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yDJPPB3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NFN8BZFs, 1, m, &cIf_NFN8BZFs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AWH76OUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NFN8BZFs, 0, m, &cIf_NFN8BZFs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i4tcRNzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_697RZfxs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UUBTgU4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_697RZfxs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_piGntQ2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uc4b6A64_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MKS0TGMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6Z5CXYVM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LeeGnkKO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MCeGhQC3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MCeGhQC3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ida2N7ti, 1, m, &cDelay_Ida2N7ti_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E6xSfLea_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ida2N7ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ida2N7ti, m);
  cIf_onMessage(_c, &Context(_c)->cIf_piGntQ2L, 0, m, &cIf_piGntQ2L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MCeGhQC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ida2N7ti, 0, m, &cDelay_Ida2N7ti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E6xSfLea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ida2N7ti, 0, m, &cDelay_Ida2N7ti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7DAMcDFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3GXdAGD5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rSNjzF2P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TGPhQGXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DciYGBRO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KESmkHFk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KESmkHFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LeeGnkKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DciYGBRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_piGntQ2L, 1, m, &cIf_piGntQ2L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3GXdAGD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MKS0TGMr, 1, m, &cIf_MKS0TGMr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rSNjzF2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MKS0TGMr, 0, m, &cIf_MKS0TGMr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6Z5CXYVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oZSL2aM7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uc4b6A64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oZSL2aM7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ttlv18N8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3KO9V8FP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AYohgUe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Oi0P6TcK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jnO6vKDC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GGBm4XI0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GGBm4XI0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8valU1d6, 1, m, &cDelay_8valU1d6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HoUxwu7j_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8valU1d6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8valU1d6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ttlv18N8, 0, m, &cIf_Ttlv18N8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GGBm4XI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8valU1d6, 0, m, &cDelay_8valU1d6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HoUxwu7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8valU1d6, 0, m, &cDelay_8valU1d6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dtsFlAmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5DHZsJHV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Irhlgttz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VimLiMYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hfCWySc3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iv3S8892_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hfCWySc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ttlv18N8, 1, m, &cIf_Ttlv18N8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iv3S8892_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jnO6vKDC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Irhlgttz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AYohgUe9, 0, m, &cIf_AYohgUe9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5DHZsJHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AYohgUe9, 1, m, &cIf_AYohgUe9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Oi0P6TcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cQhjgn19, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3KO9V8FP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cQhjgn19, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1zVIXUnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rX8TsYgX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vxCF7Kn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sp9plUg7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gNY66Myt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pyF1Ws24_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pyF1Ws24_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_V04NALlZ, 1, m, &cDelay_V04NALlZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ciRYlFOw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_V04NALlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V04NALlZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1zVIXUnh, 0, m, &cIf_1zVIXUnh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pyF1Ws24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_V04NALlZ, 0, m, &cDelay_V04NALlZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ciRYlFOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_V04NALlZ, 0, m, &cDelay_V04NALlZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pNw22BDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1cSp35rf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4FNW678e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jDnhyafj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Ou8KX0A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OvP7sW30_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OvP7sW30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gNY66Myt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7Ou8KX0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1zVIXUnh, 1, m, &cIf_1zVIXUnh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4FNW678e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vxCF7Kn8, 0, m, &cIf_vxCF7Kn8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1cSp35rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vxCF7Kn8, 1, m, &cIf_vxCF7Kn8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sp9plUg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cYP4wZkU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rX8TsYgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cYP4wZkU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_djxP3U1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Pg9P8QrU_sendMessage(_c, 0, m);
  cMsg_an03v3h3_sendMessage(_c, 0, m);
  cMsg_kEHxFZqz_sendMessage(_c, 0, m);
  cMsg_aGMNXqe5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lJMD5Tz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Pg9P8QrU_sendMessage(_c, 0, m);
  cMsg_IsSjOknC_sendMessage(_c, 0, m);
  cMsg_ZgCNlyEy_sendMessage(_c, 0, m);
  cMsg_LqgG5SLU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SdUTAZeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_sjzH8UrJ_sendMessage(_c, 0, m);
  cMsg_IsSjOknC_sendMessage(_c, 0, m);
  cMsg_aGMNXqe5_sendMessage(_c, 0, m);
  cMsg_Rw6q20dY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uxhGu8r5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_sjzH8UrJ_sendMessage(_c, 0, m);
  cMsg_s627tnmM_sendMessage(_c, 0, m);
  cMsg_kEHxFZqz_sendMessage(_c, 0, m);
  cMsg_cRqRKRc1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LX7PgnAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_t0bjTEcV_sendMessage(_c, 0, m);
  cMsg_LqgG5SLU_sendMessage(_c, 0, m);
  cMsg_Hxb05kc2_sendMessage(_c, 0, m);
  cMsg_kEHxFZqz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7gf2SoVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_t0bjTEcV_sendMessage(_c, 0, m);
  cMsg_cRqRKRc1_sendMessage(_c, 0, m);
  cMsg_IsSjOknC_sendMessage(_c, 0, m);
  cMsg_1i88psH3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WzVXckNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BSFtGUjF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6rkn9f4l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U3zkzzzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BSFtGUjF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6rkn9f4l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ykjiIFhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FGgtK9wp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dDaNAsqo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Xa2aTdqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FGgtK9wp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dDaNAsqo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GIAhppAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CoHoaJYm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eyx89gEg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K6ZPcB06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CoHoaJYm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eyx89gEg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Pg9P8QrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_WzVXckNd_sendMessage(_c, 0, m);
  cMsg_Xa2aTdqk_sendMessage(_c, 0, m);
  cMsg_K6ZPcB06_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sjzH8UrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_U3zkzzzm_sendMessage(_c, 0, m);
  cMsg_ykjiIFhT_sendMessage(_c, 0, m);
  cMsg_K6ZPcB06_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_t0bjTEcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_U3zkzzzm_sendMessage(_c, 0, m);
  cMsg_Xa2aTdqk_sendMessage(_c, 0, m);
  cMsg_GIAhppAB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lZ8xueVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rzmdZQmX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KeoqKq0m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WtnHweOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rzmdZQmX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KeoqKq0m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lq8lTTx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zW9nb1CP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ay5hTLbK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zfxMp16Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zW9nb1CP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ay5hTLbK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HOZ2Bm2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wgbwuR9l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O7ODyMLA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aL0WWFIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wgbwuR9l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O7ODyMLA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IsSjOknC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_WtnHweOn_sendMessage(_c, 0, m);
  cMsg_zfxMp16Q_sendMessage(_c, 0, m);
  cMsg_aL0WWFIJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_an03v3h3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_WtnHweOn_sendMessage(_c, 0, m);
  cMsg_lq8lTTx6_sendMessage(_c, 0, m);
  cMsg_HOZ2Bm2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s627tnmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_lZ8xueVs_sendMessage(_c, 0, m);
  cMsg_zfxMp16Q_sendMessage(_c, 0, m);
  cMsg_HOZ2Bm2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SJQEqt7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TGPhQGXf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7DAMcDFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oMb9Wlpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TGPhQGXf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7DAMcDFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O92cmFY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VimLiMYc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dtsFlAmA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_INQbR42c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VimLiMYc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dtsFlAmA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hmQ6mn24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jDnhyafj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pNw22BDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y2rgkoNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jDnhyafj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pNw22BDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cRqRKRc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_SJQEqt7f_sendMessage(_c, 0, m);
  cMsg_INQbR42c_sendMessage(_c, 0, m);
  cMsg_y2rgkoNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LqgG5SLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_oMb9Wlpw_sendMessage(_c, 0, m);
  cMsg_O92cmFY6_sendMessage(_c, 0, m);
  cMsg_y2rgkoNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aGMNXqe5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_oMb9Wlpw_sendMessage(_c, 0, m);
  cMsg_INQbR42c_sendMessage(_c, 0, m);
  cMsg_hmQ6mn24_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nS7KWbNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fr6c6byR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VOMbbaFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rf7HzPPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fr6c6byR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VOMbbaFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kVOge3TT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ba1bEPNq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cz9mFmVx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TILoLx8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ba1bEPNq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cz9mFmVx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0F9uWBh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EwKYHbNh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u5d67zIB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cQ054Ndt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EwKYHbNh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u5d67zIB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kEHxFZqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_rf7HzPPH_sendMessage(_c, 0, m);
  cMsg_TILoLx8H_sendMessage(_c, 0, m);
  cMsg_cQ054Ndt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZgCNlyEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_rf7HzPPH_sendMessage(_c, 0, m);
  cMsg_kVOge3TT_sendMessage(_c, 0, m);
  cMsg_0F9uWBh1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1i88psH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_nS7KWbNS_sendMessage(_c, 0, m);
  cMsg_kVOge3TT_sendMessage(_c, 0, m);
  cMsg_cQ054Ndt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Hxb05kc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_lZ8xueVs_sendMessage(_c, 0, m);
  cMsg_lq8lTTx6_sendMessage(_c, 0, m);
  cMsg_aL0WWFIJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Rw6q20dY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_nS7KWbNS_sendMessage(_c, 0, m);
  cMsg_TILoLx8H_sendMessage(_c, 0, m);
  cMsg_0F9uWBh1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_kIyjiGlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NM7zV4vD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dLOmu0gz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ToJ5aCid, 0, m, &cSlice_ToJ5aCid_sendMessage);
      break;
    }
    default: {
      cSwitchcase_R495cGb8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ToJ5aCid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CBFDUEnx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CBFDUEnx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_6GDTp1m1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CBFDUEnx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_CBFDUEnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hlT5SKJd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_avc5pWaH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PFnVmDPE, 0, m, &cSlice_PFnVmDPE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JG1SJCtQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PFnVmDPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FAMCY4OP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FAMCY4OP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_FuMcJKOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FAMCY4OP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FAMCY4OP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6lDKUyeM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JG1SJCtQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oCAcLKFw, 0, m, &cSlice_oCAcLKFw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dLOmu0gz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_oCAcLKFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7JEboJde_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7JEboJde_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qaqTNx04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7JEboJde_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7JEboJde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qXeag0Eq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_R495cGb8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MIdRCAp6, 0, m, &cSlice_MIdRCAp6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vPPFnmHJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MIdRCAp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GybFOou4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GybFOou4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_W3zFU6iE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GybFOou4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GybFOou4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AU8ErtJN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vPPFnmHJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qc1hboAC, 0, m, &cSlice_qc1hboAC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_r31ln2QN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_qc1hboAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GfiuaQlS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GfiuaQlS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Gu1m2UCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GfiuaQlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GfiuaQlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NLc7I43P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9M85ZgK3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tn7svclz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tn7svclz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AjlnmyPR, 1, m, &cDelay_AjlnmyPR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d3ZCiLif_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AjlnmyPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AjlnmyPR, m);
  cMsg_Nnc4wXLs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tn7svclz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AjlnmyPR, 0, m, &cDelay_AjlnmyPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d3ZCiLif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AjlnmyPR, 0, m, &cDelay_AjlnmyPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_TUIrSszk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_02RJcUZr, HV_BINOP_SUBTRACT, 0, m, &cBinop_02RJcUZr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_B8M11LBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VtYUZotu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UFHq4qPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VtYUZotu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_SY12gz7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TUIrSszk, 0, m, &cVar_TUIrSszk_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_jDExts0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R2UEKwlV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h6JW1xYB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TJ6ibwzc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_02RJcUZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VoE1srho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VoE1srho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4eB0wExN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4eB0wExN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5abzd4ya_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iYHO6HZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pn3UzyJK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IWnVgxl8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pn3UzyJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B8M11LBj, 1, m, &cIf_B8M11LBj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IWnVgxl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9ckOanKr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_csSq5gTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UFHq4qPp, 1, m, &cIf_UFHq4qPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9ckOanKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_B8M11LBj, 0, m, &cIf_B8M11LBj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5abzd4ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UFHq4qPp, 0, m, &cIf_UFHq4qPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h6JW1xYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_02RJcUZr, HV_BINOP_SUBTRACT, 1, m, &cBinop_02RJcUZr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TJ6ibwzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TUIrSszk, 0, m, &cVar_TUIrSszk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R2UEKwlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_VtYUZotu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vHCDWKqO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_r31ln2QN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FkyCQCSw, 0, m, &cSlice_FkyCQCSw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_FkyCQCSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_p47v7ZdD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_p47v7ZdD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PhlwJ69w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p47v7ZdD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_p47v7ZdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ATJlbvfV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_u1mN1j54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5qxvIXRp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oQPZRIR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_437reUKh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_eomH5oFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_snTdr4ob, 0, m, &cVar_snTdr4ob_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NM7zV4vD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_atFpJ6pP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WBLlQ1s6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M6ZnRB88_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zkSkTSnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9M85ZgK3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Nnc4wXLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Utq8XKz3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_M6ZnRB88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Utq8XKz3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JB3FBLOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_5P3JITo8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5P3JITo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QS5DggnN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QS5DggnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KdpQ0IPK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_89b6V4Wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kWqOXIr4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_XbMoisTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BamYZbOi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7SoEcvHI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G0L71XCX_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cVGsCU3k_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zdmvcRmB_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cbNwEdoi_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ghoeKW3o_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LbHRv6j3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_G0L71XCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_flKKY9zQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cVGsCU3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zg1jgKUc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zdmvcRmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kbqlwszk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cbNwEdoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qAi0yvb5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ghoeKW3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mxgQPSMU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_LbHRv6j3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yUUGDDET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_AzUlpyxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WpCRzUZP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SCkafVnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MHE8UyCK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fkJwT74K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eWeMzuGY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eWeMzuGY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8GAgr6qd, 1, m, &cDelay_8GAgr6qd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ITjMxGMu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8GAgr6qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8GAgr6qd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AzUlpyxe, 0, m, &cIf_AzUlpyxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eWeMzuGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8GAgr6qd, 0, m, &cDelay_8GAgr6qd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ITjMxGMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8GAgr6qd, 0, m, &cDelay_8GAgr6qd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VFANcKYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RTYJ44dN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lRJmALRe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_peD6iKJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WO2C7Iec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PPlXH6Z1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WO2C7Iec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AzUlpyxe, 1, m, &cIf_AzUlpyxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PPlXH6Z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fkJwT74K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lRJmALRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SCkafVnG, 0, m, &cIf_SCkafVnG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RTYJ44dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SCkafVnG, 1, m, &cIf_SCkafVnG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MHE8UyCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7oT9XRIn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WpCRzUZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7oT9XRIn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3XAObkMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ctk2RLy3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MiWOVS7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LWn7hmqG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1day0Y2I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Wdu8qBwm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Wdu8qBwm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_k3R776qk, 1, m, &cDelay_k3R776qk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IWcSG2CF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_k3R776qk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_k3R776qk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3XAObkMf, 0, m, &cIf_3XAObkMf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wdu8qBwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_k3R776qk, 0, m, &cDelay_k3R776qk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IWcSG2CF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_k3R776qk, 0, m, &cDelay_k3R776qk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XRzNUBg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YwyRZL4D_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xkJ1FwVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vrAAq4OF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ROFjaNKj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rnJnjFTt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rnJnjFTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1day0Y2I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ROFjaNKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3XAObkMf, 1, m, &cIf_3XAObkMf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YwyRZL4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MiWOVS7B, 1, m, &cIf_MiWOVS7B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xkJ1FwVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MiWOVS7B, 0, m, &cIf_MiWOVS7B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LWn7hmqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Do1PprZl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ctk2RLy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Do1PprZl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LPONnUTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WT3h7eKG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7TErtxiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_STkmNCf7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JkyIJeyH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FHs87mbl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FHs87mbl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5afVokx6, 1, m, &cDelay_5afVokx6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MUO9PYHS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5afVokx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5afVokx6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LPONnUTF, 0, m, &cIf_LPONnUTF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FHs87mbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5afVokx6, 0, m, &cDelay_5afVokx6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MUO9PYHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5afVokx6, 0, m, &cDelay_5afVokx6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PGmQVytA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z7aOxk3n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vjc0n8ew_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PZ3l9jHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yQdcwFUK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vk0Lze6q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vk0Lze6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JkyIJeyH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yQdcwFUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LPONnUTF, 1, m, &cIf_LPONnUTF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vjc0n8ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7TErtxiP, 0, m, &cIf_7TErtxiP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z7aOxk3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7TErtxiP, 1, m, &cIf_7TErtxiP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_STkmNCf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_80Q0YBJ3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WT3h7eKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_80Q0YBJ3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZinwuPV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nKSX5E0b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_g0xdyBcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HKMoNefe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KQfIU4iG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9CljOvdG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9CljOvdG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gj9bWYue, 1, m, &cDelay_gj9bWYue_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W8WqB6l4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gj9bWYue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gj9bWYue, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZinwuPV5, 0, m, &cIf_ZinwuPV5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9CljOvdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gj9bWYue, 0, m, &cDelay_gj9bWYue_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W8WqB6l4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gj9bWYue, 0, m, &cDelay_gj9bWYue_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oKQqnppL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8cNaIhYx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wBFvsI7j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bleCZKTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FGpkVCLa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mhqJpIWG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mhqJpIWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KQfIU4iG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FGpkVCLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZinwuPV5, 1, m, &cIf_ZinwuPV5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wBFvsI7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g0xdyBcb, 0, m, &cIf_g0xdyBcb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8cNaIhYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g0xdyBcb, 1, m, &cIf_g0xdyBcb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HKMoNefe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3GMQoHhD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nKSX5E0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3GMQoHhD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RCqhnOAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p6WvJykW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_w3Ln88PI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EBeeu8Ja_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_54wGcPpa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dZuyDJ2A_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dZuyDJ2A_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GKd435pd, 1, m, &cDelay_GKd435pd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DISumt7g_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GKd435pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GKd435pd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RCqhnOAB, 0, m, &cIf_RCqhnOAB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dZuyDJ2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GKd435pd, 0, m, &cDelay_GKd435pd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DISumt7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GKd435pd, 0, m, &cDelay_GKd435pd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TeSuUn8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qfV5B7hm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4rAeetCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IjReVJiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_spOdh5PN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_miWQLVXs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_miWQLVXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_54wGcPpa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_spOdh5PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RCqhnOAB, 1, m, &cIf_RCqhnOAB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4rAeetCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w3Ln88PI, 0, m, &cIf_w3Ln88PI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qfV5B7hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w3Ln88PI, 1, m, &cIf_w3Ln88PI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EBeeu8Ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TGAgCWH6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_p6WvJykW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TGAgCWH6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Mpp3WoPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_quHCKcYI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zFZCiVMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sLnP1SzY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ilP2UX5T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cACbofwN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cACbofwN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gH8mFP4R, 1, m, &cDelay_gH8mFP4R_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Px95iD0c_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gH8mFP4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gH8mFP4R, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Mpp3WoPD, 0, m, &cIf_Mpp3WoPD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cACbofwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gH8mFP4R, 0, m, &cDelay_gH8mFP4R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Px95iD0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gH8mFP4R, 0, m, &cDelay_gH8mFP4R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AIhHeICT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZG4KfW4K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MgYVzGMY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C1z8b0Cd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LPM08zyR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DdQ10nif_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DdQ10nif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ilP2UX5T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LPM08zyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mpp3WoPD, 1, m, &cIf_Mpp3WoPD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MgYVzGMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zFZCiVMe, 0, m, &cIf_zFZCiVMe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZG4KfW4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zFZCiVMe, 1, m, &cIf_zFZCiVMe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sLnP1SzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iu3UFZLb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_quHCKcYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iu3UFZLb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7Om71J8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aLWDW7Vv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Hboh3g4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SW41a4fu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oQiiqhX1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_agtDALZb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_agtDALZb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_46OPqJmy, 1, m, &cDelay_46OPqJmy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_euaafu6a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_46OPqJmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_46OPqJmy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7Om71J8w, 0, m, &cIf_7Om71J8w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_agtDALZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_46OPqJmy, 0, m, &cDelay_46OPqJmy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_euaafu6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_46OPqJmy, 0, m, &cDelay_46OPqJmy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QtKAB1bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8dsx1TvM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OW1nlclX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eDDUzPfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jUywygld_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JoCaOatV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JoCaOatV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oQiiqhX1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jUywygld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Om71J8w, 1, m, &cIf_7Om71J8w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OW1nlclX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hboh3g4M, 0, m, &cIf_Hboh3g4M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8dsx1TvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hboh3g4M, 1, m, &cIf_Hboh3g4M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SW41a4fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZNBt1xzZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aLWDW7Vv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZNBt1xzZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zHkNqilJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xics0d4b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DQsxCCjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YzgG7WrU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rbUlj8E7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KKM2AwT4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KKM2AwT4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7id9Xx5O, 1, m, &cDelay_7id9Xx5O_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X6GJJRjP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7id9Xx5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7id9Xx5O, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zHkNqilJ, 0, m, &cIf_zHkNqilJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KKM2AwT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7id9Xx5O, 0, m, &cDelay_7id9Xx5O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X6GJJRjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7id9Xx5O, 0, m, &cDelay_7id9Xx5O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Wv7B9P55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xLed4nSR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ikOQTNZq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a9eJuqwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VTUFE3o1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IqKIbeJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IqKIbeJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rbUlj8E7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VTUFE3o1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zHkNqilJ, 1, m, &cIf_zHkNqilJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xLed4nSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DQsxCCjn, 1, m, &cIf_DQsxCCjn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ikOQTNZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DQsxCCjn, 0, m, &cIf_DQsxCCjn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YzgG7WrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gMhx1TNK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xics0d4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gMhx1TNK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jojNwumh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tYYhEM5L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_heKdytTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rWAcZmNW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_owGAWX2h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4sx6zSQX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4sx6zSQX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6cKYspO4, 1, m, &cDelay_6cKYspO4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yI0Me2oT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6cKYspO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6cKYspO4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jojNwumh, 0, m, &cIf_jojNwumh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4sx6zSQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6cKYspO4, 0, m, &cDelay_6cKYspO4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yI0Me2oT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6cKYspO4, 0, m, &cDelay_6cKYspO4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9TvratWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gYD2FqDp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t1a3B3WB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bISvqrgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jf16LQRA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mGAr8ZSW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jf16LQRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jojNwumh, 1, m, &cIf_jojNwumh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mGAr8ZSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_owGAWX2h_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_t1a3B3WB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_heKdytTq, 0, m, &cIf_heKdytTq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gYD2FqDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_heKdytTq, 1, m, &cIf_heKdytTq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rWAcZmNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jdwCWkUT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tYYhEM5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jdwCWkUT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7RBHWbAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GHGc1DLi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NVN54kNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HdxlCfs1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eg9jVGSf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hiyT8VQI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hiyT8VQI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9tM7tZ03, 1, m, &cDelay_9tM7tZ03_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n1YEEtQ7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9tM7tZ03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9tM7tZ03, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7RBHWbAu, 0, m, &cIf_7RBHWbAu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hiyT8VQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9tM7tZ03, 0, m, &cDelay_9tM7tZ03_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n1YEEtQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9tM7tZ03, 0, m, &cDelay_9tM7tZ03_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HpFbWPgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q8Qk4tKE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5zwO9AXc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vKnfJ156_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zV9g7ipT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F1F36q1S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zV9g7ipT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7RBHWbAu, 1, m, &cIf_7RBHWbAu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F1F36q1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eg9jVGSf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Q8Qk4tKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NVN54kNd, 1, m, &cIf_NVN54kNd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5zwO9AXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NVN54kNd, 0, m, &cIf_NVN54kNd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HdxlCfs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b2XZguzf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GHGc1DLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b2XZguzf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6I3rAhzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sfbMboR6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QMFw6dlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_z9X1bCNR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AZ7XyJT4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MKnJ0jma_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MKnJ0jma_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SGb8ycfX, 1, m, &cDelay_SGb8ycfX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_64j8uqtI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SGb8ycfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SGb8ycfX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6I3rAhzR, 0, m, &cIf_6I3rAhzR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MKnJ0jma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SGb8ycfX, 0, m, &cDelay_SGb8ycfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_64j8uqtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SGb8ycfX, 0, m, &cDelay_SGb8ycfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OHLk4XYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eYivSyhf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gwwGKrrG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sTBb8S1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GISQjz9r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NyJ7OSX3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NyJ7OSX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AZ7XyJT4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GISQjz9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6I3rAhzR, 1, m, &cIf_6I3rAhzR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gwwGKrrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QMFw6dlk, 0, m, &cIf_QMFw6dlk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eYivSyhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QMFw6dlk, 1, m, &cIf_QMFw6dlk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z9X1bCNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F7H8akTa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sfbMboR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F7H8akTa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xdQhgdfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7Eq8dMJu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gMtWYIDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fhuX8Igp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BiXfMiYN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YvJiEl4n_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YvJiEl4n_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D5LZnr1W, 1, m, &cDelay_D5LZnr1W_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dQrVSeJP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D5LZnr1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D5LZnr1W, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xdQhgdfq, 0, m, &cIf_xdQhgdfq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YvJiEl4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D5LZnr1W, 0, m, &cDelay_D5LZnr1W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dQrVSeJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D5LZnr1W, 0, m, &cDelay_D5LZnr1W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JEut1ijy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FNTBDOG2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FDXhbPnx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zjfV8GsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6rFYrOmo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JN9QHNuG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JN9QHNuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BiXfMiYN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6rFYrOmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xdQhgdfq, 1, m, &cIf_xdQhgdfq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FNTBDOG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gMtWYIDo, 1, m, &cIf_gMtWYIDo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FDXhbPnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gMtWYIDo, 0, m, &cIf_gMtWYIDo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fhuX8Igp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y5Xq0spG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7Eq8dMJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y5Xq0spG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_flKKY9zQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_U3kmjx3T_sendMessage(_c, 0, m);
  cMsg_dEAmC14d_sendMessage(_c, 0, m);
  cMsg_GuPMcI7O_sendMessage(_c, 0, m);
  cMsg_3Hjjk80Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zg1jgKUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_U3kmjx3T_sendMessage(_c, 0, m);
  cMsg_MbVtqOBx_sendMessage(_c, 0, m);
  cMsg_FPpJXvvs_sendMessage(_c, 0, m);
  cMsg_cRP3E7IU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kbqlwszk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_1u7MNzKs_sendMessage(_c, 0, m);
  cMsg_MbVtqOBx_sendMessage(_c, 0, m);
  cMsg_3Hjjk80Z_sendMessage(_c, 0, m);
  cMsg_WaHJcmne_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qAi0yvb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_1u7MNzKs_sendMessage(_c, 0, m);
  cMsg_vJCCJngT_sendMessage(_c, 0, m);
  cMsg_GuPMcI7O_sendMessage(_c, 0, m);
  cMsg_hHDstEvM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mxgQPSMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_nXOFqtxL_sendMessage(_c, 0, m);
  cMsg_cRP3E7IU_sendMessage(_c, 0, m);
  cMsg_2klc5YL1_sendMessage(_c, 0, m);
  cMsg_GuPMcI7O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yUUGDDET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_nXOFqtxL_sendMessage(_c, 0, m);
  cMsg_hHDstEvM_sendMessage(_c, 0, m);
  cMsg_MbVtqOBx_sendMessage(_c, 0, m);
  cMsg_siHGhHrK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ST2Z1rR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_peD6iKJA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VFANcKYv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lO0gCIeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_peD6iKJA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VFANcKYv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dfrr3MQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vrAAq4OF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XRzNUBg6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GuqHaSIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vrAAq4OF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XRzNUBg6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MT1NjBwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PZ3l9jHM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PGmQVytA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ulot9Qrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PZ3l9jHM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PGmQVytA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U3kmjx3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ST2Z1rR3_sendMessage(_c, 0, m);
  cMsg_GuqHaSIu_sendMessage(_c, 0, m);
  cMsg_ulot9Qrd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1u7MNzKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_lO0gCIeu_sendMessage(_c, 0, m);
  cMsg_Dfrr3MQD_sendMessage(_c, 0, m);
  cMsg_ulot9Qrd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nXOFqtxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_lO0gCIeu_sendMessage(_c, 0, m);
  cMsg_GuqHaSIu_sendMessage(_c, 0, m);
  cMsg_MT1NjBwa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CFIZtDcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bleCZKTg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oKQqnppL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1cLOrZwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bleCZKTg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oKQqnppL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fFQ9K79E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IjReVJiM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TeSuUn8j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hBMWuHkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IjReVJiM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TeSuUn8j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fNoSzAbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C1z8b0Cd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AIhHeICT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zF6Phob5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C1z8b0Cd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AIhHeICT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MbVtqOBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_1cLOrZwT_sendMessage(_c, 0, m);
  cMsg_hBMWuHkE_sendMessage(_c, 0, m);
  cMsg_zF6Phob5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dEAmC14d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_1cLOrZwT_sendMessage(_c, 0, m);
  cMsg_fFQ9K79E_sendMessage(_c, 0, m);
  cMsg_fNoSzAbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vJCCJngT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_CFIZtDcQ_sendMessage(_c, 0, m);
  cMsg_hBMWuHkE_sendMessage(_c, 0, m);
  cMsg_fNoSzAbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_67y8folr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vKnfJ156_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HpFbWPgn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C4yEuvPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vKnfJ156_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HpFbWPgn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YDOAzeFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sTBb8S1i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OHLk4XYD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D4SDyZkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sTBb8S1i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OHLk4XYD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_huhYIf83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zjfV8GsM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JEut1ijy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rdqZUOq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zjfV8GsM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JEut1ijy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hHDstEvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_67y8folr_sendMessage(_c, 0, m);
  cMsg_D4SDyZkn_sendMessage(_c, 0, m);
  cMsg_rdqZUOq5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cRP3E7IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_C4yEuvPr_sendMessage(_c, 0, m);
  cMsg_YDOAzeFS_sendMessage(_c, 0, m);
  cMsg_rdqZUOq5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3Hjjk80Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_C4yEuvPr_sendMessage(_c, 0, m);
  cMsg_D4SDyZkn_sendMessage(_c, 0, m);
  cMsg_huhYIf83_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qvSsd54s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eDDUzPfX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QtKAB1bd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y4ysVACM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eDDUzPfX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QtKAB1bd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f0w4PvyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_a9eJuqwK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Wv7B9P55_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gQzjV11e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_a9eJuqwK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Wv7B9P55_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_baRVhYaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bISvqrgt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9TvratWr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0m66tScX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bISvqrgt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9TvratWr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GuPMcI7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Y4ysVACM_sendMessage(_c, 0, m);
  cMsg_gQzjV11e_sendMessage(_c, 0, m);
  cMsg_0m66tScX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FPpJXvvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Y4ysVACM_sendMessage(_c, 0, m);
  cMsg_f0w4PvyH_sendMessage(_c, 0, m);
  cMsg_baRVhYaL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_siHGhHrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_qvSsd54s_sendMessage(_c, 0, m);
  cMsg_f0w4PvyH_sendMessage(_c, 0, m);
  cMsg_0m66tScX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2klc5YL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_CFIZtDcQ_sendMessage(_c, 0, m);
  cMsg_fFQ9K79E_sendMessage(_c, 0, m);
  cMsg_zF6Phob5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WaHJcmne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_qvSsd54s_sendMessage(_c, 0, m);
  cMsg_gQzjV11e_sendMessage(_c, 0, m);
  cMsg_baRVhYaL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_90rJ79IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5iKM5faE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pfmX1Hr0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8ewa7VB8, 0, m, &cSlice_8ewa7VB8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5RoZ8Kro_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_8ewa7VB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5Kxi9P90_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5Kxi9P90_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_uwYqbbN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5Kxi9P90_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5Kxi9P90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3FxnoMMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1uyJMkKO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rugARe6l, 0, m, &cSlice_rugARe6l_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eWfhiIAu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_rugARe6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oeDBYzgw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oeDBYzgw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_REKvqRRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oeDBYzgw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_oeDBYzgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3nzgPwBj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eWfhiIAu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LxGPuC3s, 0, m, &cSlice_LxGPuC3s_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pfmX1Hr0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_LxGPuC3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WfAihdo1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WfAihdo1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xv8A8Grq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WfAihdo1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WfAihdo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RJv65QbJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5RoZ8Kro_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oqzrv2vl, 0, m, &cSlice_oqzrv2vl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_l3dQ9Rjz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_oqzrv2vl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BjQcRfCv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BjQcRfCv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_N8eL02bx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BjQcRfCv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BjQcRfCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bxi2PiIc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_l3dQ9Rjz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BhPMzkRq, 0, m, &cSlice_BhPMzkRq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1X5ABlil_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BhPMzkRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_G64xLOcP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_G64xLOcP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ke7xYud5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G64xLOcP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_G64xLOcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vE4xyyPE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4McTTsqJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_roXALb71_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_roXALb71_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lpu53rD1, 1, m, &cDelay_lpu53rD1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7lvG3x3X_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lpu53rD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lpu53rD1, m);
  cMsg_wxunojlc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_roXALb71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lpu53rD1, 0, m, &cDelay_lpu53rD1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7lvG3x3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lpu53rD1, 0, m, &cDelay_lpu53rD1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_RwBd3ku2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xKJN6Ejj, HV_BINOP_SUBTRACT, 0, m, &cBinop_xKJN6Ejj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ldvHUE9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_70dnktqm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gtt8wOds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_70dnktqm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_PAZXA9GP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RwBd3ku2, 0, m, &cVar_RwBd3ku2_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_XylMPm8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sm0gPdu3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0yGDM1n7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6xQ7kROb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xKJN6Ejj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7CrOI1v2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7CrOI1v2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_X9U5whTm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X9U5whTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_O4lcxJ8O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mgJu15m8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XVwOLOqb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bKLND9IJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bKLND9IJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EIRdUfjO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XVwOLOqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ldvHUE9L, 1, m, &cIf_ldvHUE9L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dFmPvzJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gtt8wOds, 1, m, &cIf_gtt8wOds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EIRdUfjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ldvHUE9L, 0, m, &cIf_ldvHUE9L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O4lcxJ8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gtt8wOds, 0, m, &cIf_gtt8wOds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sm0gPdu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_6xQ7kROb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RwBd3ku2, 0, m, &cVar_RwBd3ku2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0yGDM1n7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xKJN6Ejj, HV_BINOP_SUBTRACT, 1, m, &cBinop_xKJN6Ejj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_70dnktqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DkBbnTK8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1X5ABlil_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_24bE5T0C, 0, m, &cSlice_24bE5T0C_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_24bE5T0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wuOhSLmB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wuOhSLmB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_hAcrP4WY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wuOhSLmB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wuOhSLmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PsPIY5QE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kWqOXIr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4xynoio9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BamYZbOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2DoQoPeQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_eAiGCOdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XbMoisTd, 0, m, &cVar_XbMoisTd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5iKM5faE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_buHo4FCx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_D9cH5gqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4McTTsqJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5r1poKne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Sg2WDBG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wxunojlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_doLlf3wp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9Sg2WDBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_doLlf3wp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UzPHhvIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_VAJYW2L3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VAJYW2L3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_09nCF2wX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_09nCF2wX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7ln59XO8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_LdjpvYvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8BOXo61x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_iqlRrcji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LlZFSUEI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Wdw2jHaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZEwLZq8G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hWNSCJco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_juF9BdYo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2i8GwX2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0RddlVkv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_IQWrYaQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1qdnzMss_sendMessage);
  cMsg_JLCHno3R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1qdnzMss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IQWrYaQd, 1, m, &cVar_IQWrYaQd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2WKurABC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_95mYehuX_sendMessage(_c, 0, m);
  cMsg_eCt2VkOZ_sendMessage(_c, 0, m);
  cMsg_9xjyaYMu_sendMessage(_c, 0, m);
  cMsg_9KZZcrAG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8Amqfwy2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wgyOGuEn, 0, m, &cSlice_wgyOGuEn_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_wgyOGuEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QZRfirzL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QZRfirzL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ArfHi8Ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QZRfirzL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QZRfirzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vFlTtgEH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BHFbXCU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KSUlOq8a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KSUlOq8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_zaj7RIwa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zaj7RIwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_TkYZY6Wm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TkYZY6Wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yqB35cBd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_53O7RWa0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_53O7RWa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZWDXDeJb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yqB35cBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ZK6KBhvb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZK6KBhvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YDQyPPIl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZWDXDeJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iSR0ZLoE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iSR0ZLoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RuJ7RgCD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YDQyPPIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PsrS2SKF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RuJ7RgCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1OiPRQuV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PsrS2SKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pyETpYpH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1OiPRQuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cW0vTDwM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_jVQghEQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MqV5y9CX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_tSRXPz1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zhLCCTN5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CfzOFqv4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IY35vrK8_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cv3xT6nS_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9jUFGzwg_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sacqFyKg_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkL67P6u_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jbJv2U07_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_IY35vrK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RNEtdfPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cv3xT6nS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tkhWYA3g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9jUFGzwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LidRGKGk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_sacqFyKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8CWMl8k2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_nkL67P6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sbywILhc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jbJv2U07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tmrPx7Jk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Em2wy5aO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MBfoyHcA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9fsqlxVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_arldy2Ba_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mwTROOiH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3QnSK22Z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3QnSK22Z_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_M1uCR1Xm, 1, m, &cDelay_M1uCR1Xm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bUJuLSqO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_M1uCR1Xm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M1uCR1Xm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Em2wy5aO, 0, m, &cIf_Em2wy5aO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3QnSK22Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_M1uCR1Xm, 0, m, &cDelay_M1uCR1Xm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bUJuLSqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M1uCR1Xm, 0, m, &cDelay_M1uCR1Xm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_brzE6CCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B9t4CZmx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sLL2jZvw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jabU4wSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EueZWK3l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tulW8MPH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tulW8MPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mwTROOiH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EueZWK3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Em2wy5aO, 1, m, &cIf_Em2wy5aO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sLL2jZvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9fsqlxVg, 0, m, &cIf_9fsqlxVg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B9t4CZmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9fsqlxVg, 1, m, &cIf_9fsqlxVg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_arldy2Ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vgvj2WU1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MBfoyHcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vgvj2WU1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ymf6y1MA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jutmcfBV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yH0hhCbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TBQPJgpu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_07L08TMT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zJZObznn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zJZObznn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wUXERC2F, 1, m, &cDelay_wUXERC2F_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UF8zQ82S_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wUXERC2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wUXERC2F, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ymf6y1MA, 0, m, &cIf_Ymf6y1MA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zJZObznn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wUXERC2F, 0, m, &cDelay_wUXERC2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UF8zQ82S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wUXERC2F, 0, m, &cDelay_wUXERC2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IH7R8wyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XIzaOA1S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yb2GZ0no_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qx48SvQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7try82jt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O1aYsWYy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O1aYsWYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_07L08TMT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7try82jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ymf6y1MA, 1, m, &cIf_Ymf6y1MA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yb2GZ0no_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yH0hhCbn, 0, m, &cIf_yH0hhCbn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XIzaOA1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yH0hhCbn, 1, m, &cIf_yH0hhCbn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TBQPJgpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kU9ftPuY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jutmcfBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kU9ftPuY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pDH9y4BZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lqqE6hIi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AqGvQFFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xLsnTQ9m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IiULhkqJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LPGttwsb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LPGttwsb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_drNeuftk, 1, m, &cDelay_drNeuftk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o660AxYk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_drNeuftk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_drNeuftk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pDH9y4BZ, 0, m, &cIf_pDH9y4BZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LPGttwsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_drNeuftk, 0, m, &cDelay_drNeuftk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o660AxYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_drNeuftk, 0, m, &cDelay_drNeuftk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WqFOgziv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vHKFCHDv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zvyALnbw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P1AdPTyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q13xWU91_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X6lg6eWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X6lg6eWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IiULhkqJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_q13xWU91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pDH9y4BZ, 1, m, &cIf_pDH9y4BZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zvyALnbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AqGvQFFL, 0, m, &cIf_AqGvQFFL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vHKFCHDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AqGvQFFL, 1, m, &cIf_AqGvQFFL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xLsnTQ9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r0v8DbXH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lqqE6hIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r0v8DbXH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zkX1zJ5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Pw26thu6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Vde1sDDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KVqDO1UT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yMZyoOC9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qPxg6LsI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qPxg6LsI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gU2NxYap, 1, m, &cDelay_gU2NxYap_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CYcQhccy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gU2NxYap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gU2NxYap, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zkX1zJ5Y, 0, m, &cIf_zkX1zJ5Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qPxg6LsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gU2NxYap, 0, m, &cDelay_gU2NxYap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CYcQhccy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gU2NxYap, 0, m, &cDelay_gU2NxYap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vy9nXAw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oUya7Klo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H2dMxlEL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JUA01GB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9p41fZY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i9sfQxnh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n9p41fZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zkX1zJ5Y, 1, m, &cIf_zkX1zJ5Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i9sfQxnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yMZyoOC9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_H2dMxlEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vde1sDDt, 0, m, &cIf_Vde1sDDt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oUya7Klo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vde1sDDt, 1, m, &cIf_Vde1sDDt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KVqDO1UT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Da93oSHm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Pw26thu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Da93oSHm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5LIVuSfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ou7p1Kdc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_X3jaBvrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xXHghiFa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YACZ4egn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OigMnVGt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OigMnVGt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HX6rg2ow, 1, m, &cDelay_HX6rg2ow_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jMaHTDS7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HX6rg2ow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HX6rg2ow, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5LIVuSfd, 0, m, &cIf_5LIVuSfd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OigMnVGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HX6rg2ow, 0, m, &cDelay_HX6rg2ow_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jMaHTDS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HX6rg2ow, 0, m, &cDelay_HX6rg2ow_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VJ9IFckO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sVifaXeU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XKfQ5OhH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e3NasAl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zXJV7uTp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zicpt7Ul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zicpt7Ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YACZ4egn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zXJV7uTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5LIVuSfd, 1, m, &cIf_5LIVuSfd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sVifaXeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X3jaBvrm, 1, m, &cIf_X3jaBvrm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XKfQ5OhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X3jaBvrm, 0, m, &cIf_X3jaBvrm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xXHghiFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UzpjxxIJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ou7p1Kdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UzpjxxIJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TKNKFF3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4sq3x9dl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lQHjloqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JOFGlGt5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZGRsoPVc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UxHWI1Mf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UxHWI1Mf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1ipi8gPz, 1, m, &cDelay_1ipi8gPz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mNCvfbaw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1ipi8gPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1ipi8gPz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TKNKFF3Z, 0, m, &cIf_TKNKFF3Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UxHWI1Mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1ipi8gPz, 0, m, &cDelay_1ipi8gPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mNCvfbaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1ipi8gPz, 0, m, &cDelay_1ipi8gPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nttNwYT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wv3KxHYX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fLN4uUhx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Jlms9stE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U6dZrea7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oE7aYxZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oE7aYxZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZGRsoPVc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_U6dZrea7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TKNKFF3Z, 1, m, &cIf_TKNKFF3Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wv3KxHYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lQHjloqM, 1, m, &cIf_lQHjloqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fLN4uUhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lQHjloqM, 0, m, &cIf_lQHjloqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JOFGlGt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rFxrUNpS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4sq3x9dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rFxrUNpS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UvoeNYll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3arLst9U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_K4dAnCDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WcXE6pa4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HOpkFCVR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9W7Q8Dlp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9W7Q8Dlp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tSHdi8Y9, 1, m, &cDelay_tSHdi8Y9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SqBuIREZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tSHdi8Y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tSHdi8Y9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UvoeNYll, 0, m, &cIf_UvoeNYll_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9W7Q8Dlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tSHdi8Y9, 0, m, &cDelay_tSHdi8Y9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SqBuIREZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tSHdi8Y9, 0, m, &cDelay_tSHdi8Y9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4NMvzYS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rCWRsMGl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KGr3V2gu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d6DKxY2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fq2sRC30_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Uj0P6Gwi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Uj0P6Gwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HOpkFCVR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Fq2sRC30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UvoeNYll, 1, m, &cIf_UvoeNYll_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KGr3V2gu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4dAnCDH, 0, m, &cIf_K4dAnCDH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rCWRsMGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4dAnCDH, 1, m, &cIf_K4dAnCDH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WcXE6pa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rBKIB9gT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3arLst9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rBKIB9gT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_g360a9vd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7pb5rSEv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3ifF4GQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BIabCZkC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xrnO0qlj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UtLYbLlu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UtLYbLlu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jQQcnsmm, 1, m, &cDelay_jQQcnsmm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aoe3COIk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jQQcnsmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jQQcnsmm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_g360a9vd, 0, m, &cIf_g360a9vd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UtLYbLlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jQQcnsmm, 0, m, &cDelay_jQQcnsmm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aoe3COIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jQQcnsmm, 0, m, &cDelay_jQQcnsmm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F5Avirnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o8Vkus0T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WodkUv1z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QwjLz3U9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dB7mytoq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PZ5sIvDo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dB7mytoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g360a9vd, 1, m, &cIf_g360a9vd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PZ5sIvDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xrnO0qlj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_o8Vkus0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3ifF4GQY, 1, m, &cIf_3ifF4GQY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WodkUv1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3ifF4GQY, 0, m, &cIf_3ifF4GQY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BIabCZkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yr8CGxwx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7pb5rSEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yr8CGxwx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_o3kUmM3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YSNKgeng_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4wo8OVbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2kjY7RY2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HGswojYs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_J4RXE0Cf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_J4RXE0Cf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ceC0FJRM, 1, m, &cDelay_ceC0FJRM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q3ySqusP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ceC0FJRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ceC0FJRM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_o3kUmM3S, 0, m, &cIf_o3kUmM3S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J4RXE0Cf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ceC0FJRM, 0, m, &cDelay_ceC0FJRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q3ySqusP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ceC0FJRM, 0, m, &cDelay_ceC0FJRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KueV7y7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_blZ8lQb5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PlbBIO4d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jNPuJT3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D3KIPyMY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DeMS0P0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DeMS0P0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HGswojYs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_D3KIPyMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o3kUmM3S, 1, m, &cIf_o3kUmM3S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PlbBIO4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4wo8OVbk, 0, m, &cIf_4wo8OVbk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_blZ8lQb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4wo8OVbk, 1, m, &cIf_4wo8OVbk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2kjY7RY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6P7mfQci, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YSNKgeng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6P7mfQci, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LuumfMPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1ohCsaJo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IAjHy3SN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YIjCq5Si_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VNqhAQ0b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_g36ZUHft_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_g36ZUHft_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PQOiacAI, 1, m, &cDelay_PQOiacAI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fh0ELzSH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_PQOiacAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PQOiacAI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LuumfMPp, 0, m, &cIf_LuumfMPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g36ZUHft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PQOiacAI, 0, m, &cDelay_PQOiacAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fh0ELzSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PQOiacAI, 0, m, &cDelay_PQOiacAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1MnsfyDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQ9VdI6G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4r7HaAAc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DvW1f4BQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JCxq7q9b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vS4ulkKf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JCxq7q9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LuumfMPp, 1, m, &cIf_LuumfMPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vS4ulkKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VNqhAQ0b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4r7HaAAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAjHy3SN, 0, m, &cIf_IAjHy3SN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FQ9VdI6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAjHy3SN, 1, m, &cIf_IAjHy3SN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YIjCq5Si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nqp06mEX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1ohCsaJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nqp06mEX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Fqa6cMTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gVSYEY0F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bjezbu1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RLRhgtgv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tQYgBwmR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SL4v9nQh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SL4v9nQh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zOlK1iqD, 1, m, &cDelay_zOlK1iqD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d8mNu6sW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zOlK1iqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zOlK1iqD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Fqa6cMTn, 0, m, &cIf_Fqa6cMTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SL4v9nQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zOlK1iqD, 0, m, &cDelay_zOlK1iqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d8mNu6sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zOlK1iqD, 0, m, &cDelay_zOlK1iqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O8aS24fV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_heEovyvr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_syiRShhE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fb2WUX2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MfaJu8eW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ApUsDXI5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ApUsDXI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tQYgBwmR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MfaJu8eW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fqa6cMTn, 1, m, &cIf_Fqa6cMTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_syiRShhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bjezbu1Q, 0, m, &cIf_bjezbu1Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_heEovyvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bjezbu1Q, 1, m, &cIf_bjezbu1Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RLRhgtgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9wZ9S0QN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gVSYEY0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9wZ9S0QN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZiWxzy49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vkezFFXw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IzmKMtMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ddIc90xF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_W1AHxT9s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NRtJaBKe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NRtJaBKe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SyMEleSh, 1, m, &cDelay_SyMEleSh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EjHNK1dU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SyMEleSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SyMEleSh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZiWxzy49, 0, m, &cIf_ZiWxzy49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NRtJaBKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SyMEleSh, 0, m, &cDelay_SyMEleSh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EjHNK1dU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SyMEleSh, 0, m, &cDelay_SyMEleSh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HmCAySYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F8WKTDmK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FgM4Esfq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KU6p05be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rMxNaipQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gLXfjlYe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gLXfjlYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_W1AHxT9s_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rMxNaipQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZiWxzy49, 1, m, &cIf_ZiWxzy49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F8WKTDmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IzmKMtMK, 1, m, &cIf_IzmKMtMK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FgM4Esfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IzmKMtMK, 0, m, &cIf_IzmKMtMK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ddIc90xF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oIDw1F9X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vkezFFXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oIDw1F9X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RNEtdfPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_2v9eKOjt_sendMessage(_c, 0, m);
  cMsg_v0k3WUA2_sendMessage(_c, 0, m);
  cMsg_9iA6dObB_sendMessage(_c, 0, m);
  cMsg_Wbc9pwZ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tkhWYA3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_2v9eKOjt_sendMessage(_c, 0, m);
  cMsg_wcEry87k_sendMessage(_c, 0, m);
  cMsg_8vubth5o_sendMessage(_c, 0, m);
  cMsg_oYPT5S1s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LidRGKGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_DG3hXgOd_sendMessage(_c, 0, m);
  cMsg_wcEry87k_sendMessage(_c, 0, m);
  cMsg_Wbc9pwZ1_sendMessage(_c, 0, m);
  cMsg_Y7bHJEr6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8CWMl8k2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_DG3hXgOd_sendMessage(_c, 0, m);
  cMsg_q6rrRUqP_sendMessage(_c, 0, m);
  cMsg_9iA6dObB_sendMessage(_c, 0, m);
  cMsg_bcvXukpg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sbywILhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_ZQgcibf6_sendMessage(_c, 0, m);
  cMsg_oYPT5S1s_sendMessage(_c, 0, m);
  cMsg_CmtzDamL_sendMessage(_c, 0, m);
  cMsg_9iA6dObB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tmrPx7Jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_ZQgcibf6_sendMessage(_c, 0, m);
  cMsg_bcvXukpg_sendMessage(_c, 0, m);
  cMsg_wcEry87k_sendMessage(_c, 0, m);
  cMsg_3Axf3kyR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jICYIJsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jabU4wSZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_brzE6CCS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VRntjkMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jabU4wSZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_brzE6CCS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iZgZzWHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qx48SvQ6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IH7R8wyY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p6DYCDwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qx48SvQ6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IH7R8wyY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UWQqJAz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_P1AdPTyk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WqFOgziv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vRardUR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_P1AdPTyk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WqFOgziv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2v9eKOjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_jICYIJsi_sendMessage(_c, 0, m);
  cMsg_p6DYCDwo_sendMessage(_c, 0, m);
  cMsg_vRardUR7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DG3hXgOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_VRntjkMf_sendMessage(_c, 0, m);
  cMsg_iZgZzWHN_sendMessage(_c, 0, m);
  cMsg_vRardUR7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZQgcibf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_VRntjkMf_sendMessage(_c, 0, m);
  cMsg_p6DYCDwo_sendMessage(_c, 0, m);
  cMsg_UWQqJAz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PWwmHB9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JUA01GB2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Vy9nXAw4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XmDKoFir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JUA01GB2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Vy9nXAw4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OxCG3CqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_e3NasAl8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VJ9IFckO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ymr7rjV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_e3NasAl8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VJ9IFckO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wp2Barj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Jlms9stE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nttNwYT4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MvZeWr6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Jlms9stE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nttNwYT4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wcEry87k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_XmDKoFir_sendMessage(_c, 0, m);
  cMsg_ymr7rjV4_sendMessage(_c, 0, m);
  cMsg_MvZeWr6G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v0k3WUA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_XmDKoFir_sendMessage(_c, 0, m);
  cMsg_OxCG3CqA_sendMessage(_c, 0, m);
  cMsg_wp2Barj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_q6rrRUqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_PWwmHB9n_sendMessage(_c, 0, m);
  cMsg_ymr7rjV4_sendMessage(_c, 0, m);
  cMsg_wp2Barj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lqFQuU9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DvW1f4BQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1MnsfyDB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7a5IgGHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DvW1f4BQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1MnsfyDB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ITqMN1wI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fb2WUX2v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O8aS24fV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zGZGMEw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fb2WUX2v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O8aS24fV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jykbCSEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KU6p05be_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HmCAySYz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nbn56J5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KU6p05be_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HmCAySYz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bcvXukpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_lqFQuU9y_sendMessage(_c, 0, m);
  cMsg_zGZGMEw6_sendMessage(_c, 0, m);
  cMsg_nbn56J5u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oYPT5S1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_7a5IgGHw_sendMessage(_c, 0, m);
  cMsg_ITqMN1wI_sendMessage(_c, 0, m);
  cMsg_nbn56J5u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Wbc9pwZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_7a5IgGHw_sendMessage(_c, 0, m);
  cMsg_zGZGMEw6_sendMessage(_c, 0, m);
  cMsg_jykbCSEC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4xpV3wvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_d6DKxY2U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4NMvzYS8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_neg9fidZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_d6DKxY2U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4NMvzYS8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ehSyBujR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QwjLz3U9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_F5Avirnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y9PHfOIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QwjLz3U9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_F5Avirnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WqTm8KFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jNPuJT3q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KueV7y7o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OP9YvlN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jNPuJT3q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KueV7y7o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9iA6dObB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_neg9fidZ_sendMessage(_c, 0, m);
  cMsg_Y9PHfOIa_sendMessage(_c, 0, m);
  cMsg_OP9YvlN2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8vubth5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_neg9fidZ_sendMessage(_c, 0, m);
  cMsg_ehSyBujR_sendMessage(_c, 0, m);
  cMsg_WqTm8KFy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3Axf3kyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_4xpV3wvl_sendMessage(_c, 0, m);
  cMsg_ehSyBujR_sendMessage(_c, 0, m);
  cMsg_OP9YvlN2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CmtzDamL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_PWwmHB9n_sendMessage(_c, 0, m);
  cMsg_OxCG3CqA_sendMessage(_c, 0, m);
  cMsg_MvZeWr6G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y7bHJEr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_4xpV3wvl_sendMessage(_c, 0, m);
  cMsg_Y9PHfOIa_sendMessage(_c, 0, m);
  cMsg_WqTm8KFy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_clFUn20z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5TNisCks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UuovqMk1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sp4rDjxW, 0, m, &cSlice_sp4rDjxW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zTYydTH4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sp4rDjxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P14xNA3W_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P14xNA3W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Y6Cyzolu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P14xNA3W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_P14xNA3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_teMssqs3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rKBpADWX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_llxxVGOx, 0, m, &cSlice_llxxVGOx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OIdNDm6P_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_llxxVGOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JKpz3NBM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JKpz3NBM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_36Qywm8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JKpz3NBM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JKpz3NBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KuSxU9nE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OIdNDm6P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DQNMqJgL, 0, m, &cSlice_DQNMqJgL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UuovqMk1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_DQNMqJgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UL0cHwsL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UL0cHwsL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lBRYDJNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UL0cHwsL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UL0cHwsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7GgI84L1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zTYydTH4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XN4TNroN, 0, m, &cSlice_XN4TNroN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Pm837LS0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XN4TNroN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6P1p6bhB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6P1p6bhB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_KrzHOY0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6P1p6bhB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6P1p6bhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5ZCHUIlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Pm837LS0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Utr1U9PW, 0, m, &cSlice_Utr1U9PW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_u5xR0206_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Utr1U9PW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_M2eYvhlN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_M2eYvhlN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dG1Pl05v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M2eYvhlN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_M2eYvhlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QrVXDLKo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RTGuwRm8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Li4ZsTOu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Li4ZsTOu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZXLH5e2B, 1, m, &cDelay_ZXLH5e2B_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Fn4IKBW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZXLH5e2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZXLH5e2B, m);
  cMsg_oLguqUEP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Li4ZsTOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZXLH5e2B, 0, m, &cDelay_ZXLH5e2B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Fn4IKBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZXLH5e2B, 0, m, &cDelay_ZXLH5e2B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_KXJ5mdLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2gptacAZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_2gptacAZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_68cGjj1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rJh42zlK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Lgeb0mml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rJh42zlK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_1QBcg3pU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KXJ5mdLL, 0, m, &cVar_KXJ5mdLL_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_TFbjhG3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pByci9KU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DT7pUlwb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r9AWOn8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2gptacAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CEAtgzyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CEAtgzyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vUvOPIuq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vUvOPIuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vUL45SIx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Tqh4d4Xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JU3qs6Zc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZhNMia9G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZhNMia9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_itawsvTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JU3qs6Zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_68cGjj1T, 1, m, &cIf_68cGjj1T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kVTs4Yw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lgeb0mml, 1, m, &cIf_Lgeb0mml_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_itawsvTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_68cGjj1T, 0, m, &cIf_68cGjj1T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vUL45SIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lgeb0mml, 0, m, &cIf_Lgeb0mml_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pByci9KU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_DT7pUlwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2gptacAZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_2gptacAZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r9AWOn8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KXJ5mdLL, 0, m, &cVar_KXJ5mdLL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rJh42zlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_95PxunAK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_u5xR0206_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_85IR79SJ, 0, m, &cSlice_85IR79SJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_85IR79SJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_a8ZTipaN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_a8ZTipaN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qETx4TzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a8ZTipaN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_a8ZTipaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nB5GHuTr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MqV5y9CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SyPZQEyl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zhLCCTN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WrZv58pH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_tTQJK3UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tSRXPz1d, 0, m, &cVar_tSRXPz1d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5TNisCks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R7kXE3MS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_q4DpybaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RTGuwRm8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CK6yLD0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Spu3XuvP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oLguqUEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qQrJurmf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Spu3XuvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qQrJurmf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8EyOtuFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_injZATk6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_injZATk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ykhAiJ57_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ykhAiJ57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gkCK2LX5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_3KWxYa8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BlsnKKy6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_T0QXT5jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zOWS0XfZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OmKVIqcc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GqoehMxH_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ebXMg0au_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_golmV2jT_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5j9zdMFY_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uIHK5YBW_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dLkKkmbA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_GqoehMxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sxWl9klb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ebXMg0au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jBNuR2KP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_golmV2jT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yxdmpeZ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_5j9zdMFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E7G9yubr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_uIHK5YBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4b2dC3jW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dLkKkmbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pxBQoIur_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_PoQg9oCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sVslkiBf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2SOtnocG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zxCwmk45_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BfAGtCUF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DK0IrmNF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DK0IrmNF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kVXYQ1KM, 1, m, &cDelay_kVXYQ1KM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Es8Uwstv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kVXYQ1KM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kVXYQ1KM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PoQg9oCA, 0, m, &cIf_PoQg9oCA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DK0IrmNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVXYQ1KM, 0, m, &cDelay_kVXYQ1KM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Es8Uwstv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVXYQ1KM, 0, m, &cDelay_kVXYQ1KM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E3gymsi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nvJQUihD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L5eSxPhq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qqiyEFhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5zMzcP3H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CHSJ3kQu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CHSJ3kQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BfAGtCUF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5zMzcP3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PoQg9oCA, 1, m, &cIf_PoQg9oCA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L5eSxPhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2SOtnocG, 0, m, &cIf_2SOtnocG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nvJQUihD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2SOtnocG, 1, m, &cIf_2SOtnocG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zxCwmk45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6fPUhATE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sVslkiBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6fPUhATE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gVmiUfLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GzOnI40B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_r2WLkzHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gcqsMcgc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VcToL9G4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_W0GK2r1s_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_W0GK2r1s_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Sj8ft5Ti, 1, m, &cDelay_Sj8ft5Ti_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ixANtH8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Sj8ft5Ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Sj8ft5Ti, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gVmiUfLs, 0, m, &cIf_gVmiUfLs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W0GK2r1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sj8ft5Ti, 0, m, &cDelay_Sj8ft5Ti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4ixANtH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sj8ft5Ti, 0, m, &cDelay_Sj8ft5Ti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cX6gkAW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQN5MfaV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qgtMtAil_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5YcbyG9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ULNLKNeF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EKW4jBFw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EKW4jBFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VcToL9G4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ULNLKNeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gVmiUfLs, 1, m, &cIf_gVmiUfLs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FQN5MfaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r2WLkzHs, 1, m, &cIf_r2WLkzHs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qgtMtAil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r2WLkzHs, 0, m, &cIf_r2WLkzHs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gcqsMcgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qm79nA72, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GzOnI40B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qm79nA72, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_e3qAjpJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ry8r6TWN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_D2wISGkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_x4k1P090_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KRGUM0cz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fdCsMH13_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fdCsMH13_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zHz4YEOp, 1, m, &cDelay_zHz4YEOp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QKmXEEZy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zHz4YEOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zHz4YEOp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_e3qAjpJB, 0, m, &cIf_e3qAjpJB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fdCsMH13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zHz4YEOp, 0, m, &cDelay_zHz4YEOp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QKmXEEZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zHz4YEOp, 0, m, &cDelay_zHz4YEOp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2K1JEGAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bDojhWi8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ozrxl015_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mCpS9Q7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UsGsrwlb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HVRmSi8Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UsGsrwlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e3qAjpJB, 1, m, &cIf_e3qAjpJB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HVRmSi8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KRGUM0cz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ozrxl015_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D2wISGkY, 0, m, &cIf_D2wISGkY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bDojhWi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D2wISGkY, 1, m, &cIf_D2wISGkY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x4k1P090_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yykr1ZQH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ry8r6TWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yykr1ZQH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_76m4CZmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qfkuFWyn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0pW6Dw8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vVS8Js63_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4P5QD3rL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_E5zlQdOT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_E5zlQdOT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9GCz53Vk, 1, m, &cDelay_9GCz53Vk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0rzIMDSS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9GCz53Vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9GCz53Vk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_76m4CZmK, 0, m, &cIf_76m4CZmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E5zlQdOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9GCz53Vk, 0, m, &cDelay_9GCz53Vk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0rzIMDSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9GCz53Vk, 0, m, &cDelay_9GCz53Vk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_81rxNB5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7srpODiS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NPbEw2n0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9HPccvk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fsinPYnl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mog70rS3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Mog70rS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4P5QD3rL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fsinPYnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_76m4CZmK, 1, m, &cIf_76m4CZmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7srpODiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0pW6Dw8C, 1, m, &cIf_0pW6Dw8C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NPbEw2n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0pW6Dw8C, 0, m, &cIf_0pW6Dw8C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vVS8Js63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ez22xjdk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qfkuFWyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ez22xjdk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CnOczbCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EcPJMtmE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_haDR28jZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_a4O2Lz7l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nWFPiK3N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hy92jVtC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hy92jVtC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1tqBEOTD, 1, m, &cDelay_1tqBEOTD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N5tkquZt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1tqBEOTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1tqBEOTD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CnOczbCh, 0, m, &cIf_CnOczbCh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hy92jVtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1tqBEOTD, 0, m, &cDelay_1tqBEOTD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N5tkquZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1tqBEOTD, 0, m, &cDelay_1tqBEOTD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SFmO4WKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_85suBeOm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eQ63B71j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K9dl25Ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_950Ir4K5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vEA0Af5k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vEA0Af5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nWFPiK3N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_950Ir4K5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CnOczbCh, 1, m, &cIf_CnOczbCh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eQ63B71j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_haDR28jZ, 0, m, &cIf_haDR28jZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_85suBeOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_haDR28jZ, 1, m, &cIf_haDR28jZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a4O2Lz7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZhEO0GXK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EcPJMtmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZhEO0GXK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KMOMdVlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Itc0id08_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qa6iQ6nZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lukY4m7P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_G8ppav2t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CRZD1c6R_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CRZD1c6R_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RMDoZxwy, 1, m, &cDelay_RMDoZxwy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_974pUNBv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RMDoZxwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RMDoZxwy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KMOMdVlY, 0, m, &cIf_KMOMdVlY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CRZD1c6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RMDoZxwy, 0, m, &cDelay_RMDoZxwy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_974pUNBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RMDoZxwy, 0, m, &cDelay_RMDoZxwy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VIjJHQvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_upLONLTs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uAdFFwN3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fUl8UI90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2lYKKFsb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X5lIwiEt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X5lIwiEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_G8ppav2t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2lYKKFsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KMOMdVlY, 1, m, &cIf_KMOMdVlY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_upLONLTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qa6iQ6nZ, 1, m, &cIf_qa6iQ6nZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uAdFFwN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qa6iQ6nZ, 0, m, &cIf_qa6iQ6nZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lukY4m7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PMGWo95G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Itc0id08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PMGWo95G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_soko0hyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CfciqNqI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MmYyPUpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Mkn3hTjQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kkgWBh2p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SMyfeSS6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SMyfeSS6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jNAhdrUi, 1, m, &cDelay_jNAhdrUi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uONVNKEB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jNAhdrUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jNAhdrUi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_soko0hyJ, 0, m, &cIf_soko0hyJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SMyfeSS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jNAhdrUi, 0, m, &cDelay_jNAhdrUi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uONVNKEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jNAhdrUi, 0, m, &cDelay_jNAhdrUi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NC6wVJzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mlStDHg9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fp7zypuR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xK3Aenkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ObmHjeM2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s8d2rwM6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ObmHjeM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_soko0hyJ, 1, m, &cIf_soko0hyJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s8d2rwM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kkgWBh2p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Fp7zypuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MmYyPUpd, 0, m, &cIf_MmYyPUpd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mlStDHg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MmYyPUpd, 1, m, &cIf_MmYyPUpd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mkn3hTjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e2AL18ww, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CfciqNqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e2AL18ww, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Qg1c0y36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TYSuoFQQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qpjEca76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2XdmtPGR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gYeCABtt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4erfd3yt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4erfd3yt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BJ0Knutl, 1, m, &cDelay_BJ0Knutl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jNawkmOt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BJ0Knutl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BJ0Knutl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Qg1c0y36, 0, m, &cIf_Qg1c0y36_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4erfd3yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BJ0Knutl, 0, m, &cDelay_BJ0Knutl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jNawkmOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BJ0Knutl, 0, m, &cDelay_BJ0Knutl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZykkJkzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZHkZDPmP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZkWeW4HZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f7JOYZu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E3iQ2HW6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DKrgCZi4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DKrgCZi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gYeCABtt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_E3iQ2HW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qg1c0y36, 1, m, &cIf_Qg1c0y36_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZHkZDPmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qpjEca76, 1, m, &cIf_qpjEca76_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZkWeW4HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qpjEca76, 0, m, &cIf_qpjEca76_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2XdmtPGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3Pp4NNHh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TYSuoFQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3Pp4NNHh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4JupDeD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2K6CgDSB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KUFekH4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MmX7ADYc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3Y5DcxcG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_A5y2FUf3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_A5y2FUf3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WPGm4PSA, 1, m, &cDelay_WPGm4PSA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PJR6ZN1t_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WPGm4PSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WPGm4PSA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4JupDeD3, 0, m, &cIf_4JupDeD3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A5y2FUf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WPGm4PSA, 0, m, &cDelay_WPGm4PSA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PJR6ZN1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WPGm4PSA, 0, m, &cDelay_WPGm4PSA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O19BrHru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OiMKffTz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A9YhonWW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7WFdlQCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9f6Z5ex6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3KHpL9un_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3KHpL9un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3Y5DcxcG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9f6Z5ex6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4JupDeD3, 1, m, &cIf_4JupDeD3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OiMKffTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KUFekH4e, 1, m, &cIf_KUFekH4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A9YhonWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KUFekH4e, 0, m, &cIf_KUFekH4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MmX7ADYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7Zk3RFVL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2K6CgDSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7Zk3RFVL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6w7k0BOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w2OXXco7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5qLtIPAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_idmqUOGQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_D9Hvs4Hb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_44T47dKk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_44T47dKk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fcyueZm4, 1, m, &cDelay_fcyueZm4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fbj9rSx7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fcyueZm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fcyueZm4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6w7k0BOX, 0, m, &cIf_6w7k0BOX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_44T47dKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fcyueZm4, 0, m, &cDelay_fcyueZm4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Fbj9rSx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fcyueZm4, 0, m, &cDelay_fcyueZm4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hJBunZa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G2RCKbrH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WJahbvAT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lfcqpaWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uEsfsDOv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DKK8yL96_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uEsfsDOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6w7k0BOX, 1, m, &cIf_6w7k0BOX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DKK8yL96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_D9Hvs4Hb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_G2RCKbrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5qLtIPAc, 1, m, &cIf_5qLtIPAc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WJahbvAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5qLtIPAc, 0, m, &cIf_5qLtIPAc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_idmqUOGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KmM3g40A, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_w2OXXco7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KmM3g40A, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VTPhv9xT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_V7Z9mK0L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_x7iqEpLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RTL0I5v8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xkp2RVxM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_txpLmbbW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_txpLmbbW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LPrCAiM2, 1, m, &cDelay_LPrCAiM2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SHR7Ke7S_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_LPrCAiM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LPrCAiM2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VTPhv9xT, 0, m, &cIf_VTPhv9xT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_txpLmbbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LPrCAiM2, 0, m, &cDelay_LPrCAiM2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SHR7Ke7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LPrCAiM2, 0, m, &cDelay_LPrCAiM2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eZ6QdtRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yagckQth_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UKdKh60y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bX1xAJVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I3Lnt9Ai_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AvUfjvOK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I3Lnt9Ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VTPhv9xT, 1, m, &cIf_VTPhv9xT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AvUfjvOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xkp2RVxM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yagckQth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x7iqEpLs, 1, m, &cIf_x7iqEpLs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UKdKh60y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x7iqEpLs, 0, m, &cIf_x7iqEpLs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RTL0I5v8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xlfmz2An, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_V7Z9mK0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xlfmz2An, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_t6NheE4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_D0cmYFqZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Fg2p5bL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OONNtwM0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ym1F6vTn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SMOnNLSp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SMOnNLSp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jAtHT5yu, 1, m, &cDelay_jAtHT5yu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8pE1xt5Z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jAtHT5yu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jAtHT5yu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_t6NheE4b, 0, m, &cIf_t6NheE4b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SMOnNLSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jAtHT5yu, 0, m, &cDelay_jAtHT5yu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8pE1xt5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jAtHT5yu, 0, m, &cDelay_jAtHT5yu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uMKXYMIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kFvKLQUD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jy15YAxl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u5wutfZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BT0q4iRV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ww6YaEt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ww6YaEt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ym1F6vTn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BT0q4iRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t6NheE4b, 1, m, &cIf_t6NheE4b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kFvKLQUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fg2p5bL7, 1, m, &cIf_Fg2p5bL7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jy15YAxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fg2p5bL7, 0, m, &cIf_Fg2p5bL7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OONNtwM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aFAtuYXI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_D0cmYFqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aFAtuYXI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sxWl9klb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Vvm5vAzc_sendMessage(_c, 0, m);
  cMsg_wH8j3tin_sendMessage(_c, 0, m);
  cMsg_LY8QFPoI_sendMessage(_c, 0, m);
  cMsg_VGNR9EqT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jBNuR2KP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Vvm5vAzc_sendMessage(_c, 0, m);
  cMsg_1GIGUwA0_sendMessage(_c, 0, m);
  cMsg_Xbf2uR78_sendMessage(_c, 0, m);
  cMsg_VY4CeqN5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yxdmpeZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_Y4sFs2Cg_sendMessage(_c, 0, m);
  cMsg_1GIGUwA0_sendMessage(_c, 0, m);
  cMsg_VGNR9EqT_sendMessage(_c, 0, m);
  cMsg_1CgDSaDC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_E7G9yubr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_Y4sFs2Cg_sendMessage(_c, 0, m);
  cMsg_7ga8H0BK_sendMessage(_c, 0, m);
  cMsg_LY8QFPoI_sendMessage(_c, 0, m);
  cMsg_Fgna3GhO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4b2dC3jW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_ukAHLChJ_sendMessage(_c, 0, m);
  cMsg_VY4CeqN5_sendMessage(_c, 0, m);
  cMsg_TWK5OrbK_sendMessage(_c, 0, m);
  cMsg_LY8QFPoI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pxBQoIur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_ukAHLChJ_sendMessage(_c, 0, m);
  cMsg_Fgna3GhO_sendMessage(_c, 0, m);
  cMsg_1GIGUwA0_sendMessage(_c, 0, m);
  cMsg_bZJRVrWY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eFOn23Hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qqiyEFhx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E3gymsi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eAJbsKgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qqiyEFhx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E3gymsi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UOq4xTZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5YcbyG9u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cX6gkAW5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SJPs8qwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5YcbyG9u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cX6gkAW5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jC939j3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mCpS9Q7q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2K1JEGAl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sii7W5Ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mCpS9Q7q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2K1JEGAl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vvm5vAzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_eFOn23Hl_sendMessage(_c, 0, m);
  cMsg_SJPs8qwd_sendMessage(_c, 0, m);
  cMsg_Sii7W5Ry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y4sFs2Cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_eAJbsKgC_sendMessage(_c, 0, m);
  cMsg_UOq4xTZO_sendMessage(_c, 0, m);
  cMsg_Sii7W5Ry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ukAHLChJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_eAJbsKgC_sendMessage(_c, 0, m);
  cMsg_SJPs8qwd_sendMessage(_c, 0, m);
  cMsg_jC939j3n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cbKvIuyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9HPccvk9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_81rxNB5x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LvfMOo5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9HPccvk9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_81rxNB5x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nmBL6Dy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K9dl25Ie_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SFmO4WKS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ELofjh7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K9dl25Ie_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SFmO4WKS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7YJWyEba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fUl8UI90_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VIjJHQvU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DURhUfMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fUl8UI90_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VIjJHQvU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1GIGUwA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_LvfMOo5r_sendMessage(_c, 0, m);
  cMsg_ELofjh7L_sendMessage(_c, 0, m);
  cMsg_DURhUfMe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wH8j3tin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_LvfMOo5r_sendMessage(_c, 0, m);
  cMsg_nmBL6Dy1_sendMessage(_c, 0, m);
  cMsg_7YJWyEba_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7ga8H0BK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_cbKvIuyS_sendMessage(_c, 0, m);
  cMsg_ELofjh7L_sendMessage(_c, 0, m);
  cMsg_7YJWyEba_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PDyVcBYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lfcqpaWS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hJBunZa2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eNYKmaxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lfcqpaWS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hJBunZa2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aEZrKALQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bX1xAJVK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eZ6QdtRS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YTElz6k5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bX1xAJVK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eZ6QdtRS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Tn1Lrqwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u5wutfZG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uMKXYMIE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AQnPv2Ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u5wutfZG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uMKXYMIE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Fgna3GhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_PDyVcBYW_sendMessage(_c, 0, m);
  cMsg_YTElz6k5_sendMessage(_c, 0, m);
  cMsg_AQnPv2Ce_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VY4CeqN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_eNYKmaxI_sendMessage(_c, 0, m);
  cMsg_aEZrKALQ_sendMessage(_c, 0, m);
  cMsg_AQnPv2Ce_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VGNR9EqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_eNYKmaxI_sendMessage(_c, 0, m);
  cMsg_YTElz6k5_sendMessage(_c, 0, m);
  cMsg_Tn1Lrqwb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ztIOwG5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xK3Aenkp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NC6wVJzQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kwM7G4M8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xK3Aenkp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NC6wVJzQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JqYlITE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_f7JOYZu4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZykkJkzz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9DMsNJQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_f7JOYZu4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZykkJkzz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f2pzYtAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7WFdlQCL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O19BrHru_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_69ZXJ5Vy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7WFdlQCL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O19BrHru_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LY8QFPoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_kwM7G4M8_sendMessage(_c, 0, m);
  cMsg_9DMsNJQH_sendMessage(_c, 0, m);
  cMsg_69ZXJ5Vy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Xbf2uR78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_kwM7G4M8_sendMessage(_c, 0, m);
  cMsg_JqYlITE1_sendMessage(_c, 0, m);
  cMsg_f2pzYtAk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bZJRVrWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_ztIOwG5n_sendMessage(_c, 0, m);
  cMsg_JqYlITE1_sendMessage(_c, 0, m);
  cMsg_69ZXJ5Vy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TWK5OrbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_cbKvIuyS_sendMessage(_c, 0, m);
  cMsg_nmBL6Dy1_sendMessage(_c, 0, m);
  cMsg_DURhUfMe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1CgDSaDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_ztIOwG5n_sendMessage(_c, 0, m);
  cMsg_9DMsNJQH_sendMessage(_c, 0, m);
  cMsg_f2pzYtAk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_JtRoF6eR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hEzGsIAT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hLx0Dqfh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KRKfSQrL, 0, m, &cSlice_KRKfSQrL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GSq377Is_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_KRKfSQrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OThMn0Us_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OThMn0Us_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_81rYNbBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OThMn0Us_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OThMn0Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c5aygQwE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3avTvLqy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1aXn90TA, 0, m, &cSlice_1aXn90TA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0WU8eSNF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1aXn90TA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hPxKNUij_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hPxKNUij_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TwowjwL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hPxKNUij_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hPxKNUij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZLIzro8W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0WU8eSNF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fSpBy3ez, 0, m, &cSlice_fSpBy3ez_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hLx0Dqfh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_fSpBy3ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VSIN2oaF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VSIN2oaF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_IEaZF1VE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VSIN2oaF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_VSIN2oaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F64CTdUi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GSq377Is_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fS8zk4m8, 0, m, &cSlice_fS8zk4m8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_A90rWm8V_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_fS8zk4m8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XnlxbloU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XnlxbloU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xQbgujgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XnlxbloU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XnlxbloU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fOgXJmk6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_A90rWm8V_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6xfV5Hkf, 0, m, &cSlice_6xfV5Hkf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3Cp2NgOY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_6xfV5Hkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7oreHKRM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7oreHKRM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7w8vrf15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7oreHKRM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7oreHKRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hU4Rr4oa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zH2dOrCd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_D9j91gNm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_D9j91gNm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_e0IumkXG, 1, m, &cDelay_e0IumkXG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q7wz01wx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_e0IumkXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_e0IumkXG, m);
  cMsg_yqgLg3jO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_D9j91gNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_e0IumkXG, 0, m, &cDelay_e0IumkXG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q7wz01wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_e0IumkXG, 0, m, &cDelay_e0IumkXG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_CYcsRqY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u1tRBHau, HV_BINOP_SUBTRACT, 0, m, &cBinop_u1tRBHau_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_XOynIrxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pp5oiymR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1OA9KRIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pp5oiymR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_am78oFU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CYcsRqY6, 0, m, &cVar_CYcsRqY6_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_7NH7aC1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wmNCaRjI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ekIk51iI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NgC9eZqN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u1tRBHau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JPZ2BY3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JPZ2BY3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_L45xO1iQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L45xO1iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1dMIq1tE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TBbGC19M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c8g3yYFz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zRV07EoO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c8g3yYFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XOynIrxU, 1, m, &cIf_XOynIrxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zRV07EoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m5MOjcWk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_nDge41ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1OA9KRIg, 1, m, &cIf_1OA9KRIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m5MOjcWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_XOynIrxU, 0, m, &cIf_XOynIrxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1dMIq1tE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1OA9KRIg, 0, m, &cIf_1OA9KRIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NgC9eZqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CYcsRqY6, 0, m, &cVar_CYcsRqY6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ekIk51iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u1tRBHau, HV_BINOP_SUBTRACT, 1, m, &cBinop_u1tRBHau_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wmNCaRjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_pp5oiymR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fXOzPx4w, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3Cp2NgOY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bDWlfh7w, 0, m, &cSlice_bDWlfh7w_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bDWlfh7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yFpgQjrZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yFpgQjrZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TvmPJYyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yFpgQjrZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yFpgQjrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O3mDvtjo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BlsnKKy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7JAayOZY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zOWS0XfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0YDPudcp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_xAtEL8C7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T0QXT5jr, 0, m, &cVar_T0QXT5jr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hEzGsIAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HJjVRkiU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_V4xfvKu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zH2dOrCd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MTPjFqWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AGzIj6dD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yqgLg3jO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Uf5HUkoa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AGzIj6dD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Uf5HUkoa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kNQeUQgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_n8iVdNsn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n8iVdNsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vvVeuCjJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vvVeuCjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JBLV9CLU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_gSuMmycC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0n4hhDNI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4NoTwRjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BLIyb3Js_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_VSJpsS1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_55rpXHyN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KkPZXhA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTpEc3R3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NZYxGsn2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rBk8vOVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uMkvWHVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTpEc3R3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NZYxGsn2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rBk8vOVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_LbU4cU3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rj7tnILw, 0, m, &cVar_Rj7tnILw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sWmgvwB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTpEc3R3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NZYxGsn2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rBk8vOVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hFamjJwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTpEc3R3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NZYxGsn2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rBk8vOVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gE76WJnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTpEc3R3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NZYxGsn2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rBk8vOVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Cz1L0RHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_lu4dtifa, 0, m, &cVar_lu4dtifa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_My9zdjmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_SzHITrZK, 0, m, &cVar_SzHITrZK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kTPEs7MR, 0, m, &cVar_kTPEs7MR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_53JS3zDW, 0, m, &cVar_53JS3zDW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IcoIc7Dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_LbU4cU3B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NCG9OzV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Kf8Myr32_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_13U97vWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ov6s04bQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Kf8Myr32_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_13U97vWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4CusQt90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Kf8Myr32_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_13U97vWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_liAlzato_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Kf8Myr32_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_13U97vWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_N29eJUQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Kf8Myr32_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_13U97vWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OG7bKeml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_CfMjb1eN, 0, m, &cVar_CfMjb1eN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PukSgpSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ytGTKzt9, 0, m, &cVar_ytGTKzt9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QwGLpB3R, 0, m, &cVar_QwGLpB3R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sKs6u6eT, 0, m, &cVar_sKs6u6eT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oxY1cdip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTpEc3R3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NZYxGsn2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rBk8vOVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_J1d53Pha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_a4jhg63G_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_avc5pWaH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_1uyJMkKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZA5yGdMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_a4jhg63G_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_avc5pWaH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_1uyJMkKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_SIJyjpsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n9rCAxEB, 0, m, &cVar_n9rCAxEB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SUguuqmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_a4jhg63G_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_avc5pWaH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_1uyJMkKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jtb6AYZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_a4jhg63G_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_avc5pWaH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_1uyJMkKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iYWJwgXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_a4jhg63G_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_avc5pWaH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_1uyJMkKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_e0IyznHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_I3OOVIaW, 0, m, &cVar_I3OOVIaW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U7q6PW8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_2HcDxVFE, 0, m, &cVar_2HcDxVFE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OsXpFhd2, 0, m, &cVar_OsXpFhd2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pzEDCEt2, 0, m, &cVar_pzEDCEt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ihCUS5IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SIJyjpsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rhrRtUSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_a4jhg63G_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_avc5pWaH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_1uyJMkKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8BOXo61x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Amqfwy2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rKBpADWX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3avTvLqy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_juF9BdYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Amqfwy2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rKBpADWX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3avTvLqy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_LnW8nC7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iqlRrcji, 0, m, &cVar_iqlRrcji_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZEwLZq8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Amqfwy2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rKBpADWX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3avTvLqy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0RddlVkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Amqfwy2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rKBpADWX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3avTvLqy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JLCHno3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Amqfwy2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rKBpADWX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3avTvLqy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_95mYehuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_hWNSCJco, 0, m, &cVar_hWNSCJco_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eCt2VkOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Wdw2jHaN, 0, m, &cVar_Wdw2jHaN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2i8GwX2F, 0, m, &cVar_2i8GwX2F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IQWrYaQd, 0, m, &cVar_IQWrYaQd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9xjyaYMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_LnW8nC7W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LlZFSUEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Amqfwy2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rKBpADWX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3avTvLqy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5Szkwunz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_gSuMmycC, 0, m, &cVar_gSuMmycC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0n4hhDNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTpEc3R3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NZYxGsn2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rBk8vOVz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nGjMbXlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_4NoTwRjY, 0, m, &cVar_4NoTwRjY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BLIyb3Js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_a4jhg63G_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_avc5pWaH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_1uyJMkKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9KZZcrAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_VSJpsS1r, 0, m, &cVar_VSJpsS1r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_55rpXHyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8Amqfwy2_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rKBpADWX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3avTvLqy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_1CmJRCoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fJIUFuFG_sendMessage(_c, 0, m);
  cMsg_6fiV1Nvq_sendMessage(_c, 0, m);
  cMsg_G52416Zf_sendMessage(_c, 0, m);
  cMsg_piD7pUiC_sendMessage(_c, 0, m);
  cMsg_zOBqV0ZJ_sendMessage(_c, 0, m);
  cMsg_N8bgB8tD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DM5sWt8z, 0, m, &cVar_DM5sWt8z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4n4Y7sWJ, 0, m, &cVar_4n4Y7sWJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8AI1R92x, 0, m, &cVar_8AI1R92x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GGcuH3NB, 0, m, &cVar_GGcuH3NB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PuaQXFkZ, 0, m, &cVar_PuaQXFkZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TR4ESsf3, 0, m, &cVar_TR4ESsf3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aizPkQ2h, 0, m, &cVar_aizPkQ2h_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QBPEFqVU, 0, m, &cVar_QBPEFqVU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ALVqgkfz, 0, m, &cVar_ALVqgkfz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X80tSDVU, 0, m, &cVar_X80tSDVU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dAF5xBQi, 0, m, &cVar_dAF5xBQi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WznNAspb, 0, m, &cVar_WznNAspb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GJ9sgMP8, 0, m, &cVar_GJ9sgMP8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Os5iHlIt, 0, m, &cVar_Os5iHlIt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bO7p9w1z, 0, m, &cVar_bO7p9w1z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dFZpZODC, 0, m, &cVar_dFZpZODC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wv1TC9M9, 0, m, &cVar_Wv1TC9M9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j41z6TJb, 0, m, &cVar_j41z6TJb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_50HOvzLN, 0, m, &cVar_50HOvzLN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Cbtsgrgo, 0, m, &cVar_Cbtsgrgo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tXzMOoz1, 0, m, &cVar_tXzMOoz1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GbyKatKx, 0, m, &cVar_GbyKatKx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dvWYryum, 0, m, &cVar_dvWYryum_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dTjDptag, 0, m, &cVar_dTjDptag_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xm7S5azb, 0, m, &cVar_xm7S5azb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QZ3Q5RES, 0, m, &cVar_QZ3Q5RES_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VZq7JZsw, 0, m, &cVar_VZq7JZsw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4MzSIZa0, 0, m, &cVar_4MzSIZa0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_q501eY8O, 0, m, &cVar_q501eY8O_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qVEpltkO, 0, m, &cVar_qVEpltkO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pBDKKbjp, 0, m, &cVar_pBDKKbjp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HQspAra7, 0, m, &cVar_HQspAra7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ORCXS8oy, 0, m, &cVar_ORCXS8oy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Sk6q1OTi, 0, m, &cVar_Sk6q1OTi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6GDTp1m1, 0, m, &cVar_6GDTp1m1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FuMcJKOC, 0, m, &cVar_FuMcJKOC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qaqTNx04, 0, m, &cVar_qaqTNx04_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W3zFU6iE, 0, m, &cVar_W3zFU6iE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Gu1m2UCX, 0, m, &cVar_Gu1m2UCX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PhlwJ69w, 0, m, &cVar_PhlwJ69w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uwYqbbN4, 0, m, &cVar_uwYqbbN4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_REKvqRRl, 0, m, &cVar_REKvqRRl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xv8A8Grq, 0, m, &cVar_xv8A8Grq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N8eL02bx, 0, m, &cVar_N8eL02bx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ke7xYud5, 0, m, &cVar_ke7xYud5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hAcrP4WY, 0, m, &cVar_hAcrP4WY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y6Cyzolu, 0, m, &cVar_Y6Cyzolu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_36Qywm8i, 0, m, &cVar_36Qywm8i_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lBRYDJNz, 0, m, &cVar_lBRYDJNz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KrzHOY0J, 0, m, &cVar_KrzHOY0J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dG1Pl05v, 0, m, &cVar_dG1Pl05v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qETx4TzV, 0, m, &cVar_qETx4TzV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_81rYNbBm, 0, m, &cVar_81rYNbBm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TwowjwL1, 0, m, &cVar_TwowjwL1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IEaZF1VE, 0, m, &cVar_IEaZF1VE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xQbgujgR, 0, m, &cVar_xQbgujgR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7w8vrf15, 0, m, &cVar_7w8vrf15_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TvmPJYyt, 0, m, &cVar_TvmPJYyt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8taAqVNy, 0, m, &cVar_8taAqVNy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mJTSq7eC, 0, m, &cVar_mJTSq7eC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ArfHi8Ey, 0, m, &cVar_ArfHi8Ey_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QTvqbgbb_sendMessage);
  cMsg_PukSgpSd_sendMessage(_c, 0, m);
  cMsg_OG7bKeml_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NMKtWl1A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2WKurABC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WihTFts6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ytGTKzt9, 0, m, &cVar_ytGTKzt9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_enOpdziU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QwGLpB3R, 0, m, &cVar_QwGLpB3R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_emutieEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sKs6u6eT, 0, m, &cVar_sKs6u6eT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mt4To4KZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4n4Y7sWJ, 0, m, &cVar_4n4Y7sWJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_EqsVVIWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2sI7uZzm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sNeQOot4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dgmJgGDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_43xgU0i1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ij0Beeya_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KqNGLFCL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PoE5qZwL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3exjPP8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qFxaHwxB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UI1rFsSU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SRhcmby3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XLLE4kN2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_t7NMMFfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zovLmI5h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fT0N9KpI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HXcE0kEK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ArEUJKEW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kK5hO7Do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aNvHMafX, HV_BINOP_MULTIPLY, 0, m, &cBinop_aNvHMafX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6j2sUdt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vTJYPo76_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_87Z4zErr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3KpAmYkD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_kwi5ZvuU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_r4wcbIHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_U7OUdc2M_sendMessage);
  cMsg_HS99XgrI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_yo2nmLMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U6ff0ysv, HV_BINOP_MULTIPLY, 0, m, &cBinop_U6ff0ysv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GMqP0qgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Bt5ywcYh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hWcSwQO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_APqgrrQy, HV_BINOP_MULTIPLY, 1, m, &cBinop_APqgrrQy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0z6rCDg5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3o24Pne7_sendMessage);
  cMsg_VX7YoxKp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_71wOtNgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mYHftNk3, HV_BINOP_MULTIPLY, 0, m, &cBinop_mYHftNk3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_r7NYxABa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7H190g7y_sendMessage(_c, 0, m);
  cMsg_KexEmbPT_sendMessage(_c, 0, m);
  cMsg_rhDI9HPV_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_e8Ai0OS7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SxfKmrve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Tdzr2pzP_sendMessage);
  cMsg_hpQCwn3J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_3HQORtNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PuaQXFkZ, 0, m, &cVar_PuaQXFkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cGdcctZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3bfcHafv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2wBeVxZS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0uf40Jbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iQLfteUl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nAvAeG6G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XPjz8yv1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UINoh1ET_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_D4PeYYu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z7EWzndC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XnCSI7cH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FgNmXPQc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sMsudVsQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8NrX67hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FsVjRQeh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q1M4cVeU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AOBPN6HH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_agqlc0Gm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ySVft9Ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4MZrDiWE, HV_BINOP_MULTIPLY, 0, m, &cBinop_4MZrDiWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_S3Otx0UB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EqoqIpOI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Vohm1Zt6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sV8e1ZWH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_RhLgmLkE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3MpGAlJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_siSGGGIq_sendMessage);
  cMsg_PQglZpkt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_6wrxq3f4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4EizQNac, HV_BINOP_MULTIPLY, 0, m, &cBinop_4EizQNac_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qXjiyziH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_f29TLK8N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DbKsnBaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIwSZAyo, HV_BINOP_MULTIPLY, 1, m, &cBinop_cIwSZAyo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_atlDbwJW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_y5RDWCpv_sendMessage);
  cMsg_C4uIzk3N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_mQKzNcTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wXCBmd3J, HV_BINOP_MULTIPLY, 0, m, &cBinop_wXCBmd3J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_x9wWIMNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I9DWt267_sendMessage(_c, 0, m);
  cMsg_JpSp1cLA_sendMessage(_c, 0, m);
  cMsg_fs0OFSuj_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_LLi0Pd94_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qICl5MWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_egJQ0q6Y_sendMessage);
  cMsg_blgrVszH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_6FwuQIh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CfMjb1eN, 0, m, &cVar_CfMjb1eN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_P4MWbL15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8NvKOekR, 0, m, &cVar_8NvKOekR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_welPhHc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lu4dtifa, 0, m, &cVar_lu4dtifa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TAsTJ6uD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SzHITrZK, 0, m, &cVar_SzHITrZK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4HqatXBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kTPEs7MR, 0, m, &cVar_kTPEs7MR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_umElZp4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_53JS3zDW, 0, m, &cVar_53JS3zDW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HrHk6NE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_LbU4cU3B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LAffqNx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BPVJ75He_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PiVvO9R2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FbmKAo3V, 0, m, &cVar_FbmKAo3V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dXLND0jC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BJRwzgNO, 0, m, &cVar_BJRwzgNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Dv9YKxQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_qvxsQHlD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KRUHAEVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eajETg8t_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cSucEW8o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4pKyJ7Wa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JcCwX2OS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_chKn55zR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Zs8T3DkE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_H5heWyZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d0BgYzGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_jqUfix2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_enUw6KZa, 0, m, &cVar_enUw6KZa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DiC3Wy4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YX3muswt, 0, m, &cVar_YX3muswt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XXxaVavE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_nMYVd3j5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DAoh08TB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gNML9OM0_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X8uCpRmv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V6sH2B3Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lRqht7Jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MOAyW1vN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kAT0PJGx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cWYD5d16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ox34eHVu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_RgT6FIuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1ovzAW3s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hlT5SKJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DivKFkWk, 0, m, &cVar_DivKFkWk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AU8ErtJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kIyjiGlB, 0, m, &cVar_kIyjiGlB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qXeag0Eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_eomH5oFy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6lDKUyeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VZ0gp8wN_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WBLlQ1s6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zkSkTSnr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NLc7I43P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iYHO6HZF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_csSq5gTT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ATJlbvfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JB3FBLOU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_3FxnoMMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_89b6V4Wx, 0, m, &cVar_89b6V4Wx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bxi2PiIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_90rJ79IU, 0, m, &cVar_90rJ79IU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RJv65QbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_eAiGCOdJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3nzgPwBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7SoEcvHI_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5r1poKne_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D9cH5gqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vE4xyyPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mgJu15m8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dFmPvzJ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PsPIY5QE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UzPHhvIi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_hm1bD9EA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rlZkuS3G, 0, m, &cVar_rlZkuS3G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qI6taklH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I3OOVIaW, 0, m, &cVar_I3OOVIaW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qTNV0fpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2HcDxVFE, 0, m, &cVar_2HcDxVFE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ateQRDU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OsXpFhd2, 0, m, &cVar_OsXpFhd2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YBwnbZBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pzEDCEt2, 0, m, &cVar_pzEDCEt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8A1DkR4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SIJyjpsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vFlTtgEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BHFbXCU8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_teMssqs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jVQghEQ2, 0, m, &cVar_jVQghEQ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5ZCHUIlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_clFUn20z, 0, m, &cVar_clFUn20z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7GgI84L1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_tTQJK3UI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KuSxU9nE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CfzOFqv4_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CK6yLD0l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q4DpybaZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QrVXDLKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Tqh4d4Xw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kVTs4Yw4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nB5GHuTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8EyOtuFQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_c5aygQwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3KWxYa8p, 0, m, &cVar_3KWxYa8p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fOgXJmk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JtRoF6eR, 0, m, &cVar_JtRoF6eR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_F64CTdUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_xAtEL8C7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZLIzro8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OmKVIqcc_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MTPjFqWE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V4xfvKu2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hU4Rr4oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TBbGC19M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nDge41ru_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_O3mDvtjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kNQeUQgy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_WQBUMIjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LdjpvYvg, 0, m, &cVar_LdjpvYvg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_POeaQoMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hWNSCJco, 0, m, &cVar_hWNSCJco_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lBpe9NoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wdw2jHaN, 0, m, &cVar_Wdw2jHaN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GnvnXkOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2i8GwX2F, 0, m, &cVar_2i8GwX2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KQjTqT27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IQWrYaQd, 0, m, &cVar_IQWrYaQd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6SaRBhfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_LnW8nC7W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kTFovQnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gSuMmycC, 0, m, &cVar_gSuMmycC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VZyxN0OD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4NoTwRjY, 0, m, &cVar_4NoTwRjY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BJWFa9I6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VSJpsS1r, 0, m, &cVar_VSJpsS1r_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_ayApieKu, VOf(Bf0));
    __hv_line_f(&sLine_lUDjJSmq, VOf(Bf1));
    __hv_line_f(&sLine_l8B68t8B, VOf(Bf2));
    __hv_line_f(&sLine_ETO9yjkT, VOf(Bf3));
    __hv_line_f(&sLine_iI0olTEu, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_uRmc8XGT, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_xohDbwQV, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_1y4j8Cph, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_zqvbervj, VOf(Bf1));
    __hv_line_f(&sLine_Y5qkYfl5, VOf(Bf0));
    __hv_line_f(&sLine_WWBDcxBK, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_aVoSyGlB, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_iEPtty3z, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_n6zZvCIp, VOf(Bf5));
    __hv_line_f(&sLine_PBxqXwcr, VOf(Bf1));
    __hv_line_f(&sLine_ikt9MQMh, VOf(Bf2));
    __hv_line_f(&sLine_zGyLsTVV, VOf(Bf4));
    __hv_line_f(&sLine_6bnwoxYT, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_9OKeEXUN, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_RIhWAM9X, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_7gXC7jlf, VOf(Bf6));
    __hv_line_f(&sLine_U5E6FdQs, VOf(Bf2));
    __hv_line_f(&sLine_550dF0eh, VOf(Bf1));
    __hv_line_f(&sLine_7lteTkDZ, VOf(Bf5));
    __hv_line_f(&sLine_CzW9DeAH, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_HBgbk1YU, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_nfcq5dyA, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_U05SbMx5, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_dnzNNUNZ, VOf(Bf2));
    __hv_line_f(&sLine_DNCZBZUu, VOf(Bf6));
    __hv_line_f(&sLine_uvay57G2, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_SBZP6Eg4, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_lN086ia0, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_yuRKCjBd, VOf(Bf8));
    __hv_line_f(&sLine_dHWZrHS3, VOf(Bf2));
    __hv_line_f(&sLine_CdYcOfes, VOf(Bf1));
    __hv_line_f(&sLine_6yeLxdPO, VOf(Bf7));
    __hv_line_f(&sLine_UJjBoeOw, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_M1nFXiGZ, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_MOZ4xePk, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_DidFDnnm, VIf(Bf0));
    __hv_varwrite_f(&sVarf_fYWHKLOz, VIf(Bf6));
    __hv_varwrite_f(&sVarf_1DYFrgL8, VIf(Bf4));
    __hv_varwrite_f(&sVarf_gocDjaQM, VIf(Bf7));
    __hv_varread_f(&sVarf_ByEgYfh3, VOf(Bf7));
    __hv_varread_f(&sVarf_sqQn8ecp, VOf(Bf4));
    __hv_varread_f(&sVarf_VupZvNqo, VOf(Bf6));
    __hv_varread_f(&sVarf_YY0WGtwG, VOf(Bf0));
    __hv_varread_f(&sVarf_vjOPjWEM, VOf(Bf9));
    __hv_varread_f(&sVarf_EYJ9wNj2, VOf(Bf1));
    __hv_line_f(&sLine_yVSRhsjI, VOf(Bf2));
    __hv_line_f(&sLine_BF41kSTJ, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_VupZvNqo, VIf(Bf7));
    __hv_varwrite_f(&sVarf_vjOPjWEM, VIf(Bf4));
    __hv_varread_f(&sVarf_50LEMYyZ, VOf(Bf2));
    __hv_varread_f(&sVarf_dVQUAEdX, VOf(Bf9));
    __hv_varread_f(&sVarf_OBqgJQWe, VOf(Bf1));
    __hv_varread_f(&sVarf_bjAF79oO, VOf(Bf6));
    __hv_varread_f(&sVarf_l2890Zd7, VOf(Bf10));
    __hv_varread_f(&sVarf_KO5Qp3pN, VOf(Bf11));
    __hv_varread_f(&sVarf_zTwf50ZM, VOf(Bf12));
    __hv_varwrite_f(&sVarf_Q45kJCCv, VIf(Bf7));
    __hv_varread_f(&sVarf_eCE2XnOx, VOf(Bf13));
    __hv_line_f(&sLine_zZHQPpp9, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_SbPsEZpX, VOf(Bf15));
    __hv_line_f(&sLine_kn3Jy30w, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_Ozp2IWgs, VOf(Bf14));
    __hv_line_f(&sLine_F7RRw1P1, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_bjAF79oO, VIf(Bf17));
    __hv_varread_f(&sVarf_Q45kJCCv, VOf(Bf17));
    __hv_line_f(&sLine_PuyMLyvc, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_mKxtp814, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_rpFfDlhd, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_l2890Zd7, VIf(Bf16));
    __hv_line_f(&sLine_P13NYAyJ, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_uM6usdJm, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_jle1DMzk, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_KO5Qp3pN, VIf(Bf16));
    __hv_line_f(&sLine_zVhAAhTZ, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_n554y7lO, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_WrgAvrwU, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_zTwf50ZM, VIf(Bf16));
    __hv_varwrite_f(&sVarf_eCE2XnOx, VIf(Bf2));
    __hv_varwrite_f(&sVarf_SbPsEZpX, VIf(Bf9));
    __hv_varwrite_f(&sVarf_Ozp2IWgs, VIf(Bf1));
    sEnv_process(this, &sEnv_zLDVwawI, VIf(Bf6), &sEnv_zLDVwawI_sendMessage);
    sEnv_process(this, &sEnv_2EiBb1eu, VIf(Bf7), &sEnv_2EiBb1eu_sendMessage);
    __hv_line_f(&sLine_sq5qjv7d, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_YWzoMHmf, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_loqEuMpz, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_QWSyCe6O, VOf(Bf6));
    __hv_line_f(&sLine_YVgf8AWf, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_50LEMYyZ, VIf(Bf9));
    __hv_varwrite_f(&sVarf_QWSyCe6O, VIf(Bf10));
    __hv_varwrite_f(&sVarf_tnxpbdWh, VIf(Bf11));
    __hv_varwrite_f(&sVarf_h0oc3PYz, VIf(Bf12));
    __hv_varread_f(&sVarf_h0oc3PYz, VOf(Bf12));
    __hv_line_f(&sLine_HXKJy1pH, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_OBqgJQWe, VIf(Bf10));
    __hv_varread_f(&sVarf_tnxpbdWh, VOf(Bf10));
    __hv_line_f(&sLine_dvkEuKQR, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_dVQUAEdX, VIf(Bf10));
    __hv_varwrite_f(&sVarf_YY0WGtwG, VIf(Bf7));
    __hv_varread_f(&sVarf_yfnU8CAn, VOf(Bf7));
    __hv_varread_f(&sVarf_rtl8YiPz, VOf(Bf10));
    __hv_varread_f(&sVarf_jhav0PDR, VOf(Bf9));
    __hv_varread_f(&sVarf_OOAaHO6O, VOf(Bf11));
    __hv_varread_f(&sVarf_nAWvkhkv, VOf(Bf6));
    __hv_varread_f(&sVarf_RMcZQvMa, VOf(Bf12));
    __hv_varread_f(&sVarf_F6zvLZjz, VOf(Bf1));
    __hv_varwrite_f(&sVarf_2r2qQAjT, VIf(Bf4));
    __hv_varread_f(&sVarf_EwKfidce, VOf(Bf2));
    __hv_line_f(&sLine_Bve1KrZg, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_C9kwicCv, VOf(Bf17));
    __hv_line_f(&sLine_znuoyzzm, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_FXeniP7C, VOf(Bf16));
    __hv_line_f(&sLine_Ibunc3Qs, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_OOAaHO6O, VIf(Bf15));
    __hv_varread_f(&sVarf_2r2qQAjT, VOf(Bf15));
    __hv_line_f(&sLine_9AePYHWf, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_iyNutQ0q, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_6DHhF9e0, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_nAWvkhkv, VIf(Bf13));
    __hv_line_f(&sLine_0I8k0jgu, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_xzxMSL8N, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_JSCHm5Xo, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_RMcZQvMa, VIf(Bf13));
    __hv_line_f(&sLine_89CneFbQ, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_6arohPpk, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_qshJ9co9, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_F6zvLZjz, VIf(Bf13));
    __hv_varwrite_f(&sVarf_EwKfidce, VIf(Bf7));
    __hv_varwrite_f(&sVarf_C9kwicCv, VIf(Bf10));
    __hv_varwrite_f(&sVarf_FXeniP7C, VIf(Bf9));
    sEnv_process(this, &sEnv_7NeQ0RBN, VIf(Bf11), &sEnv_7NeQ0RBN_sendMessage);
    sEnv_process(this, &sEnv_1QlvBTcf, VIf(Bf4), &sEnv_1QlvBTcf_sendMessage);
    __hv_line_f(&sLine_oLlIb9UZ, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_UTqZcKrj, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_6Eh65mx0, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_nL7pcOuO, VOf(Bf11));
    __hv_line_f(&sLine_Jg0EXJWU, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_yfnU8CAn, VIf(Bf10));
    __hv_varwrite_f(&sVarf_nL7pcOuO, VIf(Bf6));
    __hv_varwrite_f(&sVarf_iAfgFm5v, VIf(Bf12));
    __hv_varwrite_f(&sVarf_75GxLX80, VIf(Bf1));
    __hv_varread_f(&sVarf_75GxLX80, VOf(Bf1));
    __hv_line_f(&sLine_zKknb96U, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_jhav0PDR, VIf(Bf6));
    __hv_varread_f(&sVarf_iAfgFm5v, VOf(Bf6));
    __hv_line_f(&sLine_32UeUc6W, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_rtl8YiPz, VIf(Bf6));
    __hv_varwrite_f(&sVarf_EYJ9wNj2, VIf(Bf4));
    __hv_varwrite_f(&sVarf_nYxPqOEp, VIf(Bf0));
    __hv_varread_f(&sVarf_DidFDnnm, VOf(Bf0));
    __hv_varread_f(&sVarf_fYWHKLOz, VOf(Bf4));
    __hv_varread_f(&sVarf_AiS3EJXr, VOf(Bf6));
    __hv_varread_f(&sVarf_wp0OiIyx, VOf(Bf10));
    __hv_varread_f(&sVarf_2SDKpvzf, VOf(Bf12));
    __hv_varread_f(&sVarf_47IR97SS, VOf(Bf11));
    __hv_line_f(&sLine_sKiXTPn8, VOf(Bf1));
    __hv_line_f(&sLine_Ic5AmThW, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_AiS3EJXr, VIf(Bf0));
    __hv_varwrite_f(&sVarf_2SDKpvzf, VIf(Bf4));
    __hv_varread_f(&sVarf_tYPJErS7, VOf(Bf1));
    __hv_varread_f(&sVarf_ANYCtJq9, VOf(Bf12));
    __hv_varread_f(&sVarf_5SuDooBV, VOf(Bf11));
    __hv_varread_f(&sVarf_Td4pZ0Rm, VOf(Bf6));
    __hv_varread_f(&sVarf_qOwvPoMt, VOf(Bf7));
    __hv_varread_f(&sVarf_siUzsR6r, VOf(Bf13));
    __hv_varread_f(&sVarf_a8qd7ng3, VOf(Bf15));
    __hv_varwrite_f(&sVarf_zqZXaHUR, VIf(Bf0));
    __hv_varread_f(&sVarf_Jyv6I5uE, VOf(Bf2));
    __hv_line_f(&sLine_oZSL2aM7, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_XX2LUsSp, VOf(Bf18));
    __hv_line_f(&sLine_cQhjgn19, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_Icpne3Te, VOf(Bf17));
    __hv_line_f(&sLine_cYP4wZkU, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_Td4pZ0Rm, VIf(Bf14));
    __hv_varread_f(&sVarf_zqZXaHUR, VOf(Bf14));
    __hv_line_f(&sLine_dDG5ncca, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_pKo7AR0N, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_rIeDG1HR, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_qOwvPoMt, VIf(Bf16));
    __hv_line_f(&sLine_bVhgf0RF, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_iAQHkcJh, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_ZMsTmAVF, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_siUzsR6r, VIf(Bf16));
    __hv_line_f(&sLine_X02XD68H, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_CuTqOQqe, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_697RZfxs, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_a8qd7ng3, VIf(Bf16));
    __hv_varwrite_f(&sVarf_Jyv6I5uE, VIf(Bf1));
    __hv_varwrite_f(&sVarf_XX2LUsSp, VIf(Bf12));
    __hv_varwrite_f(&sVarf_Icpne3Te, VIf(Bf11));
    sEnv_process(this, &sEnv_SY12gz7f, VIf(Bf6), &sEnv_SY12gz7f_sendMessage);
    sEnv_process(this, &sEnv_jDExts0p, VIf(Bf0), &sEnv_jDExts0p_sendMessage);
    __hv_line_f(&sLine_vHCDWKqO, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Utq8XKz3, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_KdpQ0IPK, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_OuVyq88U, VOf(Bf6));
    __hv_line_f(&sLine_437reUKh, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_tYPJErS7, VIf(Bf12));
    __hv_varwrite_f(&sVarf_OuVyq88U, VIf(Bf7));
    __hv_varwrite_f(&sVarf_UR8sAgZx, VIf(Bf13));
    __hv_varwrite_f(&sVarf_qvUW9Wdu, VIf(Bf15));
    __hv_varread_f(&sVarf_qvUW9Wdu, VOf(Bf15));
    __hv_line_f(&sLine_atFpJ6pP, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_5SuDooBV, VIf(Bf7));
    __hv_varread_f(&sVarf_UR8sAgZx, VOf(Bf7));
    __hv_line_f(&sLine_5qxvIXRp, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_ANYCtJq9, VIf(Bf7));
    __hv_varwrite_f(&sVarf_wp0OiIyx, VIf(Bf0));
    __hv_varread_f(&sVarf_1tks8Tst, VOf(Bf0));
    __hv_varread_f(&sVarf_KOBn2P4M, VOf(Bf7));
    __hv_varread_f(&sVarf_RNma2y45, VOf(Bf12));
    __hv_varread_f(&sVarf_DHQGoa2O, VOf(Bf13));
    __hv_varread_f(&sVarf_nNsyOa4G, VOf(Bf6));
    __hv_varread_f(&sVarf_AXffnBrl, VOf(Bf15));
    __hv_varread_f(&sVarf_Rbu64Xef, VOf(Bf11));
    __hv_varwrite_f(&sVarf_QAMBTnU6, VIf(Bf4));
    __hv_varread_f(&sVarf_yTyuMD4G, VOf(Bf1));
    __hv_line_f(&sLine_b2XZguzf, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_BTO3pYZK, VOf(Bf14));
    __hv_line_f(&sLine_F7H8akTa, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_V36EK0ba, VOf(Bf16));
    __hv_line_f(&sLine_Y5Xq0spG, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_DHQGoa2O, VIf(Bf18));
    __hv_varread_f(&sVarf_QAMBTnU6, VOf(Bf18));
    __hv_line_f(&sLine_7oT9XRIn, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_3GMQoHhD, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_ZNBt1xzZ, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_nNsyOa4G, VIf(Bf2));
    __hv_line_f(&sLine_Do1PprZl, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_TGAgCWH6, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_gMhx1TNK, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_AXffnBrl, VIf(Bf2));
    __hv_line_f(&sLine_80Q0YBJ3, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_iu3UFZLb, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_jdwCWkUT, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_Rbu64Xef, VIf(Bf2));
    __hv_varwrite_f(&sVarf_yTyuMD4G, VIf(Bf0));
    __hv_varwrite_f(&sVarf_BTO3pYZK, VIf(Bf7));
    __hv_varwrite_f(&sVarf_V36EK0ba, VIf(Bf12));
    sEnv_process(this, &sEnv_PAZXA9GP, VIf(Bf13), &sEnv_PAZXA9GP_sendMessage);
    sEnv_process(this, &sEnv_XylMPm8y, VIf(Bf4), &sEnv_XylMPm8y_sendMessage);
    __hv_line_f(&sLine_DkBbnTK8, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_doLlf3wp, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_7ln59XO8, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_oRYPx20p, VOf(Bf13));
    __hv_line_f(&sLine_2DoQoPeQ, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_1tks8Tst, VIf(Bf7));
    __hv_varwrite_f(&sVarf_oRYPx20p, VIf(Bf6));
    __hv_varwrite_f(&sVarf_mSH68Jqp, VIf(Bf15));
    __hv_varwrite_f(&sVarf_gv4EUtEp, VIf(Bf11));
    __hv_varread_f(&sVarf_gv4EUtEp, VOf(Bf11));
    __hv_line_f(&sLine_buHo4FCx, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_RNma2y45, VIf(Bf6));
    __hv_varread_f(&sVarf_mSH68Jqp, VOf(Bf6));
    __hv_line_f(&sLine_4xynoio9, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_KOBn2P4M, VIf(Bf6));
    __hv_varwrite_f(&sVarf_47IR97SS, VIf(Bf4));
    __hv_varwrite_f(&sVarf_GcmRvqIU, VIf(Bf10));
    __hv_varread_f(&sVarf_1DYFrgL8, VOf(Bf10));
    __hv_varread_f(&sVarf_gocDjaQM, VOf(Bf4));
    __hv_varread_f(&sVarf_CCIMiDbo, VOf(Bf6));
    __hv_varread_f(&sVarf_tD7oLOOT, VOf(Bf7));
    __hv_varread_f(&sVarf_l9vVpzN8, VOf(Bf15));
    __hv_varread_f(&sVarf_fwaiC3uD, VOf(Bf13));
    __hv_line_f(&sLine_cW0vTDwM, VOf(Bf11));
    __hv_line_f(&sLine_pyETpYpH, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_CCIMiDbo, VIf(Bf10));
    __hv_varwrite_f(&sVarf_l9vVpzN8, VIf(Bf4));
    __hv_varread_f(&sVarf_XtqL9cxe, VOf(Bf11));
    __hv_varread_f(&sVarf_g66fSCwY, VOf(Bf15));
    __hv_varread_f(&sVarf_L3x9Fygo, VOf(Bf13));
    __hv_varread_f(&sVarf_CPKBLQfW, VOf(Bf6));
    __hv_varread_f(&sVarf_9jhqEF0X, VOf(Bf0));
    __hv_varread_f(&sVarf_luDdDSJ5, VOf(Bf2));
    __hv_varread_f(&sVarf_Wd96BNMy, VOf(Bf18));
    __hv_varwrite_f(&sVarf_C71EU4To, VIf(Bf10));
    __hv_varread_f(&sVarf_yyJG1VRu, VOf(Bf1));
    __hv_line_f(&sLine_nqp06mEX, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_NXPIpnWB, VOf(Bf19));
    __hv_line_f(&sLine_9wZ9S0QN, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_GQnqSyJp, VOf(Bf14));
    __hv_line_f(&sLine_oIDw1F9X, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_CPKBLQfW, VIf(Bf17));
    __hv_varread_f(&sVarf_C71EU4To, VOf(Bf17));
    __hv_line_f(&sLine_vgvj2WU1, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_Da93oSHm, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_rBKIB9gT, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_9jhqEF0X, VIf(Bf16));
    __hv_line_f(&sLine_kU9ftPuY, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_UzpjxxIJ, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_yr8CGxwx, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_luDdDSJ5, VIf(Bf16));
    __hv_line_f(&sLine_r0v8DbXH, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_rFxrUNpS, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_6P7mfQci, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Wd96BNMy, VIf(Bf16));
    __hv_varwrite_f(&sVarf_yyJG1VRu, VIf(Bf11));
    __hv_varwrite_f(&sVarf_NXPIpnWB, VIf(Bf15));
    __hv_varwrite_f(&sVarf_GQnqSyJp, VIf(Bf13));
    sEnv_process(this, &sEnv_1QBcg3pU, VIf(Bf6), &sEnv_1QBcg3pU_sendMessage);
    sEnv_process(this, &sEnv_TFbjhG3z, VIf(Bf10), &sEnv_TFbjhG3z_sendMessage);
    __hv_line_f(&sLine_95PxunAK, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_qQrJurmf, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_gkCK2LX5, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_yVEpq6Jm, VOf(Bf6));
    __hv_line_f(&sLine_WrZv58pH, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_XtqL9cxe, VIf(Bf15));
    __hv_varwrite_f(&sVarf_yVEpq6Jm, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Wlz8mmQV, VIf(Bf2));
    __hv_varwrite_f(&sVarf_uMR7n2Jd, VIf(Bf18));
    __hv_varread_f(&sVarf_uMR7n2Jd, VOf(Bf18));
    __hv_line_f(&sLine_R7kXE3MS, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_L3x9Fygo, VIf(Bf0));
    __hv_varread_f(&sVarf_Wlz8mmQV, VOf(Bf0));
    __hv_line_f(&sLine_SyPZQEyl, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_g66fSCwY, VIf(Bf0));
    __hv_varwrite_f(&sVarf_tD7oLOOT, VIf(Bf10));
    __hv_varread_f(&sVarf_klPe766a, VOf(Bf10));
    __hv_varread_f(&sVarf_CxV9Bpih, VOf(Bf0));
    __hv_varread_f(&sVarf_4XohRoIu, VOf(Bf15));
    __hv_varread_f(&sVarf_0ZPMBoJe, VOf(Bf2));
    __hv_varread_f(&sVarf_eg1SbnCq, VOf(Bf6));
    __hv_varread_f(&sVarf_n0s6OokT, VOf(Bf18));
    __hv_varread_f(&sVarf_Uj5YDesa, VOf(Bf13));
    __hv_varwrite_f(&sVarf_ukaCxpYc, VIf(Bf4));
    __hv_varread_f(&sVarf_wxfCBmyg, VOf(Bf11));
    __hv_line_f(&sLine_KmM3g40A, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_jH1K6mkb, VOf(Bf17));
    __hv_line_f(&sLine_xlfmz2An, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_aHAATtvX, VOf(Bf16));
    __hv_line_f(&sLine_aFAtuYXI, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_0ZPMBoJe, VIf(Bf19));
    __hv_varread_f(&sVarf_ukaCxpYc, VOf(Bf19));
    __hv_line_f(&sLine_6fPUhATE, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_Ez22xjdk, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_e2AL18ww, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_eg1SbnCq, VIf(Bf1));
    __hv_line_f(&sLine_Qm79nA72, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_ZhEO0GXK, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_3Pp4NNHh, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_n0s6OokT, VIf(Bf1));
    __hv_line_f(&sLine_yykr1ZQH, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_PMGWo95G, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_7Zk3RFVL, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_Uj5YDesa, VIf(Bf1));
    __hv_varwrite_f(&sVarf_wxfCBmyg, VIf(Bf10));
    __hv_varwrite_f(&sVarf_jH1K6mkb, VIf(Bf0));
    __hv_varwrite_f(&sVarf_aHAATtvX, VIf(Bf15));
    sEnv_process(this, &sEnv_am78oFU1, VIf(Bf2), &sEnv_am78oFU1_sendMessage);
    sEnv_process(this, &sEnv_7NH7aC1M, VIf(Bf4), &sEnv_7NH7aC1M_sendMessage);
    __hv_line_f(&sLine_fXOzPx4w, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Uf5HUkoa, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_JBLV9CLU, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_cOO93iTB, VOf(Bf2));
    __hv_line_f(&sLine_0YDPudcp, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_klPe766a, VIf(Bf0));
    __hv_varwrite_f(&sVarf_cOO93iTB, VIf(Bf6));
    __hv_varwrite_f(&sVarf_fVF1sr7r, VIf(Bf18));
    __hv_varwrite_f(&sVarf_i0vUTWHg, VIf(Bf13));
    __hv_varread_f(&sVarf_i0vUTWHg, VOf(Bf13));
    __hv_line_f(&sLine_HJjVRkiU, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_4XohRoIu, VIf(Bf6));
    __hv_varread_f(&sVarf_fVF1sr7r, VOf(Bf6));
    __hv_line_f(&sLine_7JAayOZY, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_CxV9Bpih, VIf(Bf6));
    __hv_varwrite_f(&sVarf_fwaiC3uD, VIf(Bf4));
    __hv_varwrite_f(&sVarf_w9vwsohY, VIf(Bf7));
    __hv_varwrite_f(&sVarf_tPQBK6Km, VIf(Bf8));
    __hv_varwrite_f(&sVarf_1tlJIfWc, VIf(Bf9));
    __hv_varwrite_f(&sVarf_LtC0oEv0, VIf(Bf12));
    __hv_varwrite_f(&sVarf_ByEgYfh3, VIf(Bf3));
    __hv_varwrite_f(&sVarf_sqQn8ecp, VIf(Bf5));
    __hv_varread_f(&sVarf_nYxPqOEp, VOf(Bf5));
    __hv_varread_f(&sVarf_GcmRvqIU, VOf(Bf3));
    __hv_varread_f(&sVarf_w9vwsohY, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_tPQBK6Km, VOf(Bf12));
    __hv_varread_f(&sVarf_1tlJIfWc, VOf(Bf5));
    __hv_varread_f(&sVarf_LtC0oEv0, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
